@@ -164,6 +164,8 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     public static final String ACTION_GET = "get";
 
+    public static final String ACTION_GET_STRUCTURE = "get_structure";
+
     public static final String ACTION_IMAGE = "image";
 
     public static final String ACTION_REPLY = "reply";
@@ -174,6 +176,8 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     public static final String ACTION_MATTACH = "attachment";
 
+    public static final String ACTION_ZIP_MATTACH = "zip_attachments";
+
     public static final String ACTION_MAIL_RECEIPT_ACK = "receipt_ack";
 
     public static final String ACTION_NEW_MSGS = "newmsgs";
@@ -291,6 +295,8 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     public static final String PARAMETER_TIMESTAMP = "timestamp";
 
+    public static final String PARAMETER_TIMEZONE= "timezone";
+
     public static final String PARAMETER_VERSION = "version";
 
     public static final String UPLOAD_FORMFIELD_MAIL = "json_0";
@@ -313,6 +319,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
 
     public static final String PARAMETER_USER = "user";
 
+    public static final String PARAMETER_TEMPLATE = "template";
     /**
      * The content type if the response body contains javascript data. Set it with
      * <code>resp.setContentType(AJAXServlet.CONTENTTYPE_JAVASCRIPT)</code> .
@@ -352,6 +359,7 @@ public abstract class AJAXServlet extends HttpServlet implements UploadRegistry
      * Error message if writing the response fails.
      */
     protected static final String RESPONSE_ERROR = "Error while writing response object.";
+    
 
     /**
      * The service method of HttpServlet is extended to catch bad exceptions and keep the AJP socket alive. Otherwise apache things in a
