@@ -50,6 +50,7 @@
 package com.openexchange.ajax.request;
 
 import static com.openexchange.java.Autoboxing.I;
+import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
 import java.sql.Connection;
 import java.util.ArrayList;
 import java.util.Date;
@@ -98,28 +99,44 @@ import com.openexchange.groupware.userconfiguration.UserConfiguration;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
 import com.openexchange.tools.StringCollection;
+import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.servlet.AjaxException;
 import com.openexchange.tools.servlet.OXJSONException;
 import com.openexchange.tools.session.ServerSession;
 
+/**
+ * {@link ContactRequest} - Handles AJAX requests for contact module.
+ *
+ * @author <a href="mailto:sebastian.kauss@open-xchange.com">Sebastian Kauss</a>
+ * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
+ */
 public class ContactRequest {
 
+    private static final Log LOG = LogFactory.getLog(ContactRequest.class);
+
     public static final String ACTION_GET_USER = "getuser";
 
     public static final String ACTION_LIST_USER = "listuser";
 
-    final ServerSession session;
+    /*-
+     * ++++++++++++++++++++++++++++++ Member section ++++++++++++++++++++++++++++++
+     */
 
-    final TimeZone timeZone;
+    private final ServerSession session;
+
+    private final TimeZone timeZone;
 
     private Date timestamp;
 
-    private static final Log LOG = LogFactory.getLog(ContactRequest.class);
-
+    /**
+     * Gets the time stamp.
+     * 
+     * @return The time stamp
+     */
     public Date getTimestamp() {
-        return timestamp;
+        return timestamp == null ? null : new Date(timestamp.getTime());
     }
 
     /**
@@ -132,7 +149,7 @@ public class ContactRequest {
 
         final String sTimeZone = session.getUser().getTimeZone();
 
-        timeZone = TimeZone.getTimeZone(sTimeZone);
+        timeZone = TimeZoneUtils.getTimeZone(sTimeZone);
         if (LOG.isDebugEnabled()) {
             LOG.debug("use timezone string: " + sTimeZone);
             LOG.debug("use user timezone: " + timeZone);
@@ -221,6 +238,11 @@ public class ContactRequest {
         final String[] sColumns = DataParser.checkString(jsonObj, AJAXServlet.PARAMETER_COLUMNS).split(" *, *");
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtual(columns);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         final Date requestedTimestamp = DataParser.checkDate(jsonObj, AJAXServlet.PARAMETER_TIMESTAMP);
         timestamp = new Date(requestedTimestamp.getTime());
@@ -329,6 +351,11 @@ public class ContactRequest {
                 }
                 oldfolderId = objectIdAndFolderId[0][1];
             }
+            final TimeZone timeZone;
+            {
+                final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+                timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+            }
 
             final int[] internalColumns = checkLastModified(columnsToLoad);
 
@@ -405,6 +432,11 @@ public class ContactRequest {
         for (int a = 0; a < userIdArray.length; a++) {
             userIdArray[a] = jData.getInt(a);
         }
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         final Context ctx = session.getContext();
 
@@ -437,6 +469,11 @@ public class ContactRequest {
         final int folderId = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
         final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         final int leftHandLimit = DataParser.parseInt(jsonObj, AJAXServlet.LEFT_HAND_LIMIT);
         final int rightHandLimit = DataParser.parseInt(jsonObj, AJAXServlet.RIGHT_HAND_LIMIT);
@@ -497,6 +534,11 @@ public class ContactRequest {
     public JSONObject actionGet(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
         final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
         final int inFolder = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_INFOLDER);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class).newContactInterface(
             inFolder,
@@ -517,6 +559,11 @@ public class ContactRequest {
 
     public JSONObject actionGetUser(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
         final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         final Context ctx = session.getContext();
 
@@ -540,6 +587,11 @@ public class ContactRequest {
         final String[] sColumns = DataParser.checkString(jsonObj, AJAXServlet.PARAMETER_COLUMNS).split(" *, *");
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtual(columns);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         timestamp = new Date(0);
 
@@ -577,6 +629,9 @@ public class ContactRequest {
         searchObj.setEmail1(DataParser.parseString(jData, ContactFields.EMAIL1));
         searchObj.setEmail2(DataParser.parseString(jData, ContactFields.EMAIL2));
         searchObj.setEmail3(DataParser.parseString(jData, ContactFields.EMAIL3));
+        searchObj.setDepartment(DataParser.parseString(jData, ContactFields.DEPARTMENT));
+        searchObj.setStreetBusiness(DataParser.parseString(jData, ContactFields.STREET_BUSINESS));
+        searchObj.setCityBusiness(DataParser.parseString(jData, ContactFields.CITY_BUSINESS));
         searchObj.setDynamicSearchField(DataParser.parseJSONIntArray(jData, "dynamicsearchfield"));
         searchObj.setDynamicSearchFieldValue(DataParser.parseJSONStringArray(jData, "dynamicsearchfieldvalue"));
         searchObj.setPrivatePostalCodeRange(DataParser.parseJSONStringArray(jData, "privatepostalcoderange"));
@@ -594,8 +649,8 @@ public class ContactRequest {
 
         final int[] internalColumns = checkLastModified(columnsToLoad);
 
-        ContactSearchMultiplexer multiplexer = new ContactSearchMultiplexer(ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
-        SearchIterator<Contact> it = multiplexer.extendedSearch(session, searchObj, orderBy, orderDir, internalColumns);
+        final ContactSearchMultiplexer multiplexer = new ContactSearchMultiplexer(ServerServiceRegistry.getInstance().getService(ContactInterfaceDiscoveryService.class));
+        final SearchIterator<Contact> it = multiplexer.extendedSearch(session, searchObj, orderBy, orderDir, internalColumns);
         
         final JSONArray jsonResponseArray = new JSONArray();
         try {
