@@ -51,6 +51,7 @@ package com.openexchange.ajax.request;
 
 import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
+import static com.openexchange.tools.TimeZoneUtils.getTimeZone;
 import java.util.ArrayList;
 import java.util.Date;
 import java.util.List;
@@ -84,8 +85,9 @@ import com.openexchange.groupware.container.FolderChildObject;
 import com.openexchange.groupware.container.Participants;
 import com.openexchange.groupware.search.TaskSearchObject;
 import com.openexchange.groupware.tasks.Task;
-import com.openexchange.groupware.tasks.TasksSQLInterfaceImpl;
+import com.openexchange.groupware.tasks.TasksSQLImpl;
 import com.openexchange.tools.StringCollection;
+import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.iterator.SearchIterator;
 import com.openexchange.tools.iterator.SearchIteratorException;
 import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
@@ -140,7 +142,7 @@ public class TaskRequest {
 
         final String sTimeZone = session.getUser().getTimeZone();
 
-        timeZone = TimeZone.getTimeZone(sTimeZone);
+        timeZone = TimeZoneUtils.getTimeZone(sTimeZone);
         if (LOG.isDebugEnabled()) {
             LOG.debug("use timezone string: " + sTimeZone);
             LOG.debug("use user timezone: " + timeZone);
@@ -189,7 +191,7 @@ public class TaskRequest {
         final TaskParser taskParser = new TaskParser(timeZone);
         taskParser.parse(task, jsonobject);
 
-        final TasksSQLInterface sqlinterface = new TasksSQLInterfaceImpl(session);
+        final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
         sqlinterface.insertTaskObject(task);
         timestamp = task.getLastModified();
 
@@ -213,7 +215,7 @@ public class TaskRequest {
 
         task.setObjectID(id);
 
-        final TasksSQLInterface sqlinterface = new TasksSQLInterfaceImpl(session);
+        final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
         sqlinterface.updateTaskObject(task, inFolder, timestamp);
         timestamp = task.getLastModified();
 
@@ -228,6 +230,11 @@ public class TaskRequest {
         timestamp = new Date(requestedTimestamp.getTime());
         final int folderId = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
         String ignore = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_IGNORE);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         if (ignore == null) {
             ignore = "deleted";
@@ -248,7 +255,7 @@ public class TaskRequest {
             System.arraycopy(columnsToLoad, 0, internalColumns, 0, columnsToLoad.length);
             internalColumns[columnsToLoad.length] = DataObject.LAST_MODIFIED;
 
-            final TasksSQLInterface taskssql = new TasksSQLInterfaceImpl(session);
+            final TasksSQLInterface taskssql = new TasksSQLImpl(session);
             final TaskWriter taskWriter = new TaskWriter(timeZone);
 
             it = taskssql.getModifiedTasksInFolder(folderId, internalColumns, requestedTimestamp);
@@ -294,7 +301,7 @@ public class TaskRequest {
         final int inFolder = DataParser.checkInt(jsonobject, AJAXServlet.PARAMETER_INFOLDER);
         timestamp = DataParser.checkDate(jsonObj, AJAXServlet.PARAMETER_TIMESTAMP);
 
-        final TasksSQLInterface sqlinterface = new TasksSQLInterfaceImpl(session);
+        final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
         sqlinterface.deleteTaskObject(id, inFolder, timestamp);
 
         return new JSONArray();
@@ -316,6 +323,12 @@ public class TaskRequest {
             objectIdAndFolderId[a][1] = DataParser.checkInt(jObject, AJAXServlet.PARAMETER_FOLDERID);
         }
 
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
+
         final int[] internalColumns = new int[columnsToLoad.length+1];
         System.arraycopy(columnsToLoad, 0, internalColumns, 0, columnsToLoad.length);
         internalColumns[columnsToLoad.length] = DataObject.LAST_MODIFIED;
@@ -325,7 +338,7 @@ public class TaskRequest {
         final JSONArray jsonResponseArray = new JSONArray();
 
         try {
-            final TasksSQLInterface taskssql = new TasksSQLInterfaceImpl(session);
+            final TasksSQLInterface taskssql = new TasksSQLImpl(session);
             final TaskWriter taskwriter = new TaskWriter(timeZone);
             it = taskssql.getObjectsById(objectIdAndFolderId, internalColumns);
 
@@ -355,6 +368,11 @@ public class TaskRequest {
         final int folderId = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_FOLDERID);
         final int orderBy = DataParser.parseInt(jsonObj, AJAXServlet.PARAMETER_SORT);
         final String orderDir = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_ORDER);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         final int leftHandLimit = DataParser.parseInt(jsonObj, AJAXServlet.LEFT_HAND_LIMIT);
         final int rightHandLimit = DataParser.parseInt(jsonObj, AJAXServlet.RIGHT_HAND_LIMIT);
@@ -373,7 +391,7 @@ public class TaskRequest {
 
             final TaskWriter taskwriter = new TaskWriter(timeZone);
 
-            final TasksSQLInterface taskssql = new TasksSQLInterfaceImpl(session);
+            final TasksSQLInterface taskssql = new TasksSQLImpl(session);
             if (leftHandLimit == 0) {
                 it = taskssql.getTaskList(folderId, leftHandLimit, -1, orderBy, orderDir, internalColumns);
             } else {
@@ -402,10 +420,15 @@ public class TaskRequest {
     public JSONObject actionGet(final JSONObject jsonObj) throws OXMandatoryFieldException, JSONException, OXException, OXJSONException, AjaxException {
         final int id = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_ID);
         final int inFolder = DataParser.checkInt(jsonObj, AJAXServlet.PARAMETER_INFOLDER);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         timestamp = new Date(0);
 
-        final TasksSQLInterface sqlinterface = new TasksSQLInterfaceImpl(session);
+        final TasksSQLInterface sqlinterface = new TasksSQLImpl(session);
         final Task task = sqlinterface.getTaskById(id, inFolder);
         final TaskWriter taskWriter = new TaskWriter(timeZone);
 
@@ -424,9 +447,9 @@ public class TaskRequest {
         final TaskParser taskParser = new TaskParser(timeZone);
         taskParser.parse(taskObj, jData);
 
-        final TasksSQLInterface taskSql = new TasksSQLInterfaceImpl(session);
+        final TasksSQLInterface taskSql = new TasksSQLImpl(session);
 
-        int taskId = (taskObj.containsObjectID()) ? taskObj.getObjectID() : DataParser.checkInt(jsonObj, "id");
+        final int taskId = (taskObj.containsObjectID()) ? taskObj.getObjectID() : DataParser.checkInt(jsonObj, "id");
 
         timestamp = taskSql.setUserConfirmation(taskId, session.getUserId(), taskObj.getConfirm(), taskObj.getConfirmMessage());
 
@@ -438,6 +461,11 @@ public class TaskRequest {
         final int[] columns = StringCollection.convertStringArray2IntArray(sColumns);
         final int[] columnsToLoad = removeVirtualColumns(columns);
         timestamp = new Date(0);
+        final TimeZone timeZone;
+        {
+            final String timeZoneId = DataParser.parseString(jsonObj, AJAXServlet.PARAMETER_TIMEZONE);
+            timeZone = null == timeZoneId ? this.timeZone : getTimeZone(timeZoneId);
+        }
 
         Date lastModified = null;
 
@@ -496,7 +524,7 @@ public class TaskRequest {
         try {
             final TaskWriter taskWriter = new TaskWriter(timeZone);
 
-            final TasksSQLInterface taskssql = new TasksSQLInterfaceImpl(session);
+            final TasksSQLInterface taskssql = new TasksSQLImpl(session);
             it = taskssql.getTasksByExtendedSearch(searchObj, orderBy, orderDir, internalColumns);
 
             while (it.hasNext()) {
@@ -524,7 +552,7 @@ public class TaskRequest {
         final JSONObject jData = DataParser.checkJSONObject(jsonObj, AJAXServlet.PARAMETER_DATA);
         final int folderId = DataParser.checkInt(jData, FolderChildFields.FOLDER_ID);
 
-        final TasksSQLInterface taskInterface = new TasksSQLInterfaceImpl(session);
+        final TasksSQLInterface taskInterface = new TasksSQLImpl(session);
         final Task taskObj = taskInterface.getTaskById(id, inFolder);
         taskObj.removeObjectID();
         taskObj.setParentFolderID(folderId);
@@ -538,9 +566,9 @@ public class TaskRequest {
         return jsonResponseObject;
     }
 
-    private int[] removeVirtualColumns(int[] columns) {
+    private int[] removeVirtualColumns(final int[] columns) {
         final List<Integer> tmp = new ArrayList<Integer>(columns.length);
-        for (int col : columns) {
+        for (final int col : columns) {
             if (col != Task.LAST_MODIFIED_UTC) {
                 tmp.add(I(col));
             }
