@@ -59,11 +59,13 @@ import com.openexchange.ajax.fields.ContactFields;
 import com.openexchange.ajax.fields.DistributionListFields;
 import com.openexchange.conversion.DataArguments;
 import com.openexchange.groupware.contact.datasource.ContactImageDataSource;
+import com.openexchange.groupware.container.CommonObject;
 import com.openexchange.groupware.container.Contact;
 import com.openexchange.groupware.container.DistributionListEntryObject;
 import com.openexchange.groupware.container.LinkEntryObject;
 import com.openexchange.image.ImageService;
 import com.openexchange.server.services.ServerServiceRegistry;
+import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link ContactWriter} - The writer for contacts
@@ -83,7 +85,7 @@ public class ContactWriter extends CommonWriter {
      */
     public ContactWriter(final TimeZone timeZone) {
         super(timeZone, null);
-        utc = TimeZone.getTimeZone("utc");
+        utc = TimeZoneUtils.getTimeZone("utc");
     }
 
     public void writeArray(final Contact contactobject, final int cols[], final JSONArray jsonArray) throws JSONException {
@@ -134,10 +136,11 @@ public class ContactWriter extends CommonWriter {
                         final String[] argsNames = imgSource.getRequiredArguments();
                         args.put(argsNames[0], String.valueOf(contactobject.getParentFolderID()));
                         args.put(argsNames[1], String.valueOf(contactobject.getObjectID()));
-                        imageURL = ServerServiceRegistry.getInstance().getService(ImageService.class).addImageData(
-                            contactobject.getContextId(),
-                            imgSource,
-                            args).getImageURL();
+                        imageURL =
+                            ServerServiceRegistry.getInstance().getService(ImageService.class).addImageData(
+                                contactobject.getContextId(),
+                                imgSource,
+                                args).getImageURL();
                     }
                     writeParameter(ContactFields.IMAGE1_URL, imageURL, jsonObj);
                 }
@@ -588,10 +591,11 @@ public class ContactWriter extends CommonWriter {
                             final String[] argsNames = imgSource.getRequiredArguments();
                             args.put(argsNames[0], String.valueOf(contactObject.getParentFolderID()));
                             args.put(argsNames[1], String.valueOf(contactObject.getObjectID()));
-                            imageURL = ServerServiceRegistry.getInstance().getService(ImageService.class).addImageData(
-                                contactObject.getContextId(),
-                                imgSource,
-                                args).getImageURL();
+                            imageURL =
+                                ServerServiceRegistry.getInstance().getService(ImageService.class).addImageData(
+                                    contactObject.getContextId(),
+                                    imgSource,
+                                    args).getImageURL();
                         }
                         writeValue(imageURL, jsonArray);
                     }
@@ -1070,12 +1074,17 @@ public class ContactWriter extends CommonWriter {
             }
         });
 
-        m.put(Integer.valueOf(Contact.NUMBER_OF_LINKS), new ContactFieldWriter() {
+        {
+            final ContactFieldWriter fieldWriter = new ContactFieldWriter() {
 
-            public void write(final Contact contactObject, final JSONArray jsonArray) {
-                writeValue(contactObject.getNumberOfLinks(), jsonArray, contactObject.containsNumberOfLinks());
-            }
-        });
+                public void write(final Contact contactObject, final JSONArray jsonArray) {
+                    writeValue(contactObject.getNumberOfLinks(), jsonArray, contactObject.containsNumberOfLinks());
+                }
+            };
+
+            m.put(Integer.valueOf(CommonObject.NUMBER_OF_LINKS), fieldWriter);
+            m.put(Integer.valueOf(Contact.NUMBER_OF_LINKS), fieldWriter);
+        }
 
         m.put(Integer.valueOf(Contact.NUMBER_OF_DISTRIBUTIONLIST), new ContactFieldWriter() {
 
