@@ -49,12 +49,12 @@
 
 package com.openexchange.ajp13;
 
+import static com.openexchange.tools.Collections.newHashMap;
 import java.io.IOException;
 import java.io.UnsupportedEncodingException;
 import java.net.URLDecoder;
 import java.util.ArrayList;
 import java.util.Arrays;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
@@ -86,14 +86,17 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
 
     private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(AJPv13ForwardRequest.class);
 
-    private static final String methods[] = {
-        "OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "PROPFIND", "PROPPATCH", "MKCOL", "COPY", "MOVE", "LOCK", "UNLOCK",
-        "ACL", "REPORT", "VERSION-CONTROL", "CHECKIN", "CHECKOUT", "UNCHECKOUT", "SEARCH", "MKWORKSPACE", "UPDATE", "LABEL", "MERGE",
-        "BASELINE_CONTROL", "MKACTIVITY" };
+    private static final boolean DEBUG = LOG.isDebugEnabled();
 
-    private static final Map<Integer, String> httpHeaderMapping = new HashMap<Integer, String>(14);
+    private static final String methods[] =
+        {
+            "OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "PROPFIND", "PROPPATCH", "MKCOL", "COPY", "MOVE", "LOCK", "UNLOCK",
+            "ACL", "REPORT", "VERSION-CONTROL", "CHECKIN", "CHECKOUT", "UNCHECKOUT", "SEARCH", "MKWORKSPACE", "UPDATE", "LABEL", "MERGE",
+            "BASELINE_CONTROL", "MKACTIVITY" };
 
-    private static final Map<Integer, String> attributeMapping = new HashMap<Integer, String>(14);
+    private static final Map<Integer, String> httpHeaderMapping;
+
+    private static final Map<Integer, String> attributeMapping;
 
     /**
      * A "set" to keep track of known JSESSIONIDs
@@ -122,6 +125,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
     private static final int REQUEST_TERMINATOR = 0xFF;
 
     static {
+        httpHeaderMapping = newHashMap(14);
         httpHeaderMapping.put(Integer.valueOf(0x01), "accept");
         httpHeaderMapping.put(Integer.valueOf(0x02), "accept-charset");
         httpHeaderMapping.put(Integer.valueOf(0x03), "accept-encoding");
@@ -136,6 +140,8 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
         httpHeaderMapping.put(Integer.valueOf(0x0c), "pragma");
         httpHeaderMapping.put(Integer.valueOf(0x0d), "referer");
         httpHeaderMapping.put(Integer.valueOf(0x0e), "user-agent");
+
+        attributeMapping = newHashMap(14);
         attributeMapping.put(Integer.valueOf(0x01), "context");
         attributeMapping.put(Integer.valueOf(0x02), "servlet_path");
         attributeMapping.put(Integer.valueOf(0x03), "remote_user");
@@ -204,7 +210,6 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
                 servletRequest.setRequestedSessionIdFromCookie(false);
             }
             servletRequest.setRequestURI(requestURI);
-            servletRequest.setPathInfo(requestURI);
         } catch (final AJPv13Exception e) {
             throw new AJPv13Exception(AJPCode.UNPARSEABLE_HEADER_FIELD, true, e, "req_uri");
         }
@@ -322,29 +327,43 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
          * Create servlet instance dependent on requested URI
          */
         ajpRequestHandler.setServletInstance(requestURI);
-        if (null != ajpRequestHandler.getServletPath()) {
+        /*
+         * Set servlet path and path info
+         */
+        final String servletPath = ajpRequestHandler.getServletPath();
+        if (null != servletPath) {
             /*
-             * Apply the servlet path with leading "/" to the request
+             * Apply the servlet path with leading "/" character
              */
-            if (allPath(ajpRequestHandler.getServletPath())) {
+            final int servletPathLen = servletPath.length();
+            if ((1 == servletPathLen) && ('*' == servletPath.charAt(0))) {
                 /*
                  * Set an empty string ("") if the servlet used to process this request was matched using the "/*" pattern.
                  */
                 servletRequest.setServletPath(STR_EMPTY);
+                /*
+                 * Set complete request URI as path info
+                 */
+                servletRequest.setPathInfo(requestURI);
             } else {
                 /*
                  * The path starts with a "/" character and includes either the servlet name or a path to the servlet, but does not include
                  * any extra path information or a query string.
                  */
-                servletRequest.setServletPath(new StringBuilder().append('/').append(ajpRequestHandler.getServletPath()).toString());
+                servletRequest.setServletPath(servletPath);
+                /*
+                 * Set path info: The extra path information follows the servlet path but precedes the query string and will start with a
+                 * "/" character.
+                 */
+                if ((requestURI.length() > servletPathLen) /* && requestURI.startsWith(servletPath) */) {
+                    servletRequest.setPathInfo(requestURI.substring(servletPathLen));
+                } else {
+                    servletRequest.setPathInfo(null);
+                }
             }
         }
     }
 
-    private static boolean allPath(final String servletPath) {
-        return (servletPath.length() == 1) && (servletPath.charAt(0) == '*');
-    }
-
     private static final java.util.regex.Pattern PATTERN_SPLIT = java.util.regex.Pattern.compile("&");
 
     /**
@@ -376,7 +395,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
             if (paramsNVP.length() > 0) {
                 // Look-up character '='
                 final int pos = paramsNVP.indexOf('=');
-                if (pos > -1) {
+                if (pos >= 0) {
                     servletRequest.setParameter(paramsNVP.substring(0, pos), decodeQueryStringValue(
                         servletRequest.getCharacterEncoding(),
                         paramsNVP.substring(pos + 1)));
@@ -444,7 +463,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
                         version = Integer.parseInt(versionStr);
                     } catch (final NumberFormatException e) {
                         version = 0;
-                        if (LOG.isDebugEnabled()) {
+                        if (DEBUG) {
                             LOG.debug("Version set to 0. No number value in $Version cookie: " + versionStr);
                         }
                     }
@@ -509,7 +528,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
         if ((headerValue.length() > 0) && cookieList.isEmpty()) {
             throw new AJPv13Exception(AJPv13Exception.AJPCode.INVALID_COOKIE_HEADER, true, headerValue);
         }
-        if (LOG.isDebugEnabled()) {
+        if (DEBUG) {
             final StringBuilder sb = new StringBuilder(256).append("Parsed Cookies:\n");
             for (final Cookie cookie : cookieList) {
                 sb.append('\'').append(cookie.getName()).append("'='").append(cookie.getValue()).append("'\n");
@@ -635,7 +654,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
                             /*
                              * Different JVM route detected -> Discard
                              */
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tDifferent JVM route detected. Ignoring JSESSIONID: ").append(id));
                             }
                             break NextCookie;
@@ -648,7 +667,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
                              * Invalid cookie
                              */
                             jsessionids.remove(id);
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: ").append(current.getValue()));
                             }
                             resp.removeCookie(current);
@@ -664,7 +683,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
                             /*
                              * But this host defines a JVM route
                              */
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tMissing JVM route in JESSIONID cookie").append(current.getValue()));
                             }
                             break NextCookie;
@@ -677,7 +696,7 @@ public final class AJPv13ForwardRequest extends AJPv13Request {
                              * Invalid cookie
                              */
                             jsessionids.remove(id);
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: ").append(current.getValue()));
                             }
                             resp.removeCookie(current);
