@@ -210,6 +210,22 @@ public final class AJPv13RequestHandlerImpl implements AJPv13RequestHandler {
         }
     }
 
+    private static final String EAS_URI = "/Microsoft-Server-ActiveSync";
+
+    private static final String EAS_CMD = "Cmd";
+
+    private static final String EAS_PING = "Ping";
+
+    /**
+     * Checks for long-running EAS ping command, that is URI is equal to <code>"/Microsoft-Server-ActiveSync"</code> and request's
+     * <code>"Cmd"</code> parameter equals <code>"Ping"</code>.
+     * 
+     * @return <code>true</code> if EAS ping command is detected; otherwise <code>false</code>
+     */
+    private final boolean isEASPingCommand() {
+        return EAS_URI.equals(request.getRequestURI()) && EAS_PING.equals(request.getParameter(EAS_CMD));
+    }
+
     private void handleForwardRequest(final int dataLength) throws IOException, AJPv13Exception {
         if (AJPv13Config.isLogForwardRequest()) {
             /*
@@ -237,16 +253,16 @@ public final class AJPv13RequestHandlerImpl implements AJPv13RequestHandler {
         /*
          * Check for possible long-running EAS request
          */
-        ajpCon.setLongRunning(("/Microsoft-Server-ActiveSync".equals(request.getRequestURI()) && "Ping".equals(request.getParameter("Cmd"))));
+        ajpCon.setLongRunning(isEASPingCommand());
         /*
          * Handle the important Content-Length header which controls further processing
          */
-        if (contentLength == NOT_SET) {
+        if (NOT_SET == contentLength) {
             /*
              * This condition is reached when no content-length header was present in forward request package (transfer-encoding: chunked)
              */
             request.setData(new byte[0]);
-        } else if (contentLength == 0) {
+        } else if (0 == contentLength) {
             /*
              * This condition is reached when content-length header's value is set to '0'
              */
@@ -259,8 +275,8 @@ public final class AJPv13RequestHandlerImpl implements AJPv13RequestHandler {
             /*
              * We got a following request body package.
              */
-            final int bodyRequestDataLength = ajpCon.readInitialBytes(false);
-            ajpRequest = new AJPv13RequestBody(ajpCon.getPayloadData(bodyRequestDataLength, true));
+            final int len = ajpCon.readInitialBytes(false);
+            ajpRequest = new AJPv13RequestBody(ajpCon.getPayloadData(len, true));
             ajpRequest.processRequest(this);
         }
     }
@@ -389,35 +405,45 @@ public final class AJPv13RequestHandlerImpl implements AJPv13RequestHandler {
     /**
      * Sets this request hander's servlet reference to the one bound to given path argument
      * 
-     * @param pathArg The request path
+     * @param requestURI The request URI
      */
-    public void setServletInstance(final String pathArg) {
+    public void setServletInstance(final String requestURI) {
         /*
          * Remove leading slash character
          */
-        final String path = preparePath(pathArg);
+        final String path = removeFromPath(requestURI, '/');
         /*
          * Lookup path in available servlet paths
          */
         if (servletId.length() > 0) {
             servletId.setLength(0);
         }
-        HttpServlet servletInst = HttpServletManager.getServlet(path, servletId);
-        if (servletInst == null) {
-            servletInst = new HttpErrorServlet("No servlet bound to path/alias: " + path);
+        HttpServlet servlet = HttpServletManager.getServlet(path, servletId);
+        if (servlet == null) {
+            servlet = new HttpErrorServlet("No servlet bound to path/alias: " + requestURI);
         }
-        servlet = servletInst;
+        this.servlet = servlet;
         // servletId = pathStorage.length() > 0 ? pathStorage.toString() : null;
         if (servletId.length() > 0) {
-            servletPath = servletId.toString().replaceFirst("\\*", ""); // path;
+            servletPath = removeFromPath(servletId.toString(), '*');
         }
         supplyRequestWrapperWithServlet();
     }
 
-    private static String preparePath(final String path) {
-        final int start = path.charAt(0) == '/' ? 1 : 0;
-        final int end = path.charAt(path.length() - 1) == '/' ? path.length() - 1 : path.length();
-        return path.substring(start, end);
+    /**
+     * Removes specified character if given path ends with such a character.
+     * 
+     * @param path The path to prepare
+     * @param c The (trailing) character to remove
+     * @return The path possibly with ending character removed
+     */
+    private static String removeFromPath(final String path, final char c) {
+        final int len = path.length();
+        if (c == path.charAt(len - 1)) {
+            // Ends with "/"
+            return path.substring(0, len - 1);
+        }
+        return path;
     }
 
     /**
