@@ -93,6 +93,8 @@ public final class XAJPv13ForwardRequest extends XAJPv13Request {
 
     private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(XAJPv13ForwardRequest.class);
 
+    private static final boolean DEBUG = LOG.isDebugEnabled();
+
     private static final String methods[] = {
         "OPTIONS", "GET", "HEAD", "POST", "PUT", "DELETE", "TRACE", "PROPFIND", "PROPPATCH", "MKCOL", "COPY", "MOVE", "LOCK", "UNLOCK",
         "ACL", "REPORT", "VERSION-CONTROL", "CHECKIN", "CHECKOUT", "UNCHECKOUT", "SEARCH", "MKWORKSPACE", "UPDATE", "LABEL", "MERGE",
@@ -478,7 +480,7 @@ public final class XAJPv13ForwardRequest extends XAJPv13Request {
                         version = Integer.parseInt(versionStr);
                     } catch (final NumberFormatException e) {
                         version = 0;
-                        if (LOG.isDebugEnabled()) {
+                        if (DEBUG) {
                             LOG.debug("Version set to 0. No number value in $Version cookie: " + versionStr);
                         }
                     }
@@ -635,7 +637,7 @@ public final class XAJPv13ForwardRequest extends XAJPv13Request {
                             /*
                              * Different JVM route detected -> Discard
                              */
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tDifferent JVM route detected. Ignoring JSESSIONID: ").append(id));
                             }
                             break NextCookie;
@@ -648,7 +650,7 @@ public final class XAJPv13ForwardRequest extends XAJPv13Request {
                              * Invalid cookie
                              */
                             jsessionids.remove(id);
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: ").append(current.getValue()));
                             }
                             resp.removeCookie(current);
@@ -664,7 +666,7 @@ public final class XAJPv13ForwardRequest extends XAJPv13Request {
                             /*
                              * But this host defines a JVM route
                              */
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tMissing JVM route in JESSIONID cookie").append(current.getValue()));
                             }
                             break NextCookie;
@@ -677,7 +679,7 @@ public final class XAJPv13ForwardRequest extends XAJPv13Request {
                              * Invalid cookie
                              */
                             jsessionids.remove(id);
-                            if (LOG.isDebugEnabled()) {
+                            if (DEBUG) {
                                 LOG.debug(new StringBuilder("\n\tExpired or invalid cookie -> Removing JSESSIONID cookie: ").append(current.getValue()));
                             }
                             resp.removeCookie(current);
