@@ -85,7 +85,7 @@ import com.openexchange.tools.oxfolder.OXFolderException.FolderCode;
 import com.openexchange.tools.session.ServerSession;
 
 /**
- * RdbFolderSQLInterface
+ * {@link RdbFolderSQLInterface} - The (relational) database implementation of {@link FolderSQLInterface}.
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -101,9 +101,6 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
             this.queryNum = queryNum;
         }
 
-        public int getQueryNum() {
-            return queryNum;
-        }
     }
 
     private static final int getNonTreeVisibleNum(final int module) {
@@ -121,7 +118,12 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         }
     }
 
-    private static final Set<Integer> getNonTreeVisibleModules() {
+    /**
+     * Creates a new {@link Set set} containing the modules of those folders which might not be visible in hierarchical tree view.
+     * 
+     * @return A new {@link Set set} containing the modules.
+     */
+    private static final Set<Integer> newNonTreeVisibleModules() {
         final Set<Integer> retval = new HashSet<Integer>();
         retval.add(Integer.valueOf(FolderObject.CALENDAR));
         retval.add(Integer.valueOf(FolderObject.TASK));
@@ -130,9 +132,10 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         return retval;
     }
 
-    private static final int[] VIRTUAL_IDS = {
-        FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID, FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID,
-        FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID, FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID };
+    private static final int[] VIRTUAL_IDS =
+        {
+            FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID, FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID,
+            FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID, FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID };
 
     private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(RdbFolderSQLInterface.class);
 
@@ -190,9 +193,13 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
     public FolderObject getFolderById(final int id) throws OXException {
         final int pos = Arrays.binarySearch(VIRTUAL_IDS, id);
         if (pos >= 0) {
-            final FolderObject fo = FolderObject.createVirtualFolderObject(id, FolderObject.getFolderString(
-                id,
-                session.getUser().getLocale()), FolderObject.SYSTEM_MODULE, true, FolderObject.SYSTEM_TYPE);
+            final FolderObject fo =
+                FolderObject.createVirtualFolderObject(
+                    id,
+                    FolderObject.getFolderString(id, session.getUser().getLocale()),
+                    FolderObject.SYSTEM_MODULE,
+                    true,
+                    FolderObject.SYSTEM_TYPE);
             if (3 == pos) {
                 fo.setParentFolderID(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID);
             } else {
@@ -236,7 +243,7 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -271,9 +278,10 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
                         (folderobjectArg.containsObjectID() && folderobjectArg.getObjectID() > 0 ? getFolderName(folderobjectArg) : ""),
                         Integer.valueOf(ctx.getContextId()));
                 }
-                final int[] virtualIDs = new int[] {
-                    FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID, FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID,
-                    FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID, FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID };
+                final int[] virtualIDs =
+                    new int[] {
+                        FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID, FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID,
+                        FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID, FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID };
                 if (Arrays.binarySearch(virtualIDs, parentFolderID) > -1) {
                     throw new OXFolderPermissionException(FolderCode.NO_CREATE_SUBFOLDER_PERMISSION, getUserName(session), getFolderName(
                         parentFolderID,
@@ -332,10 +340,8 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
                         OXFolderException.DETAIL_NUMBER_CONCURRENT_MODIFICATION,
                         new Object[0]);
                 }
-                final EffectivePermission effectivePerm = oxfolderAccess.getFolderPermission(
-                    folderobject.getObjectID(),
-                    userId,
-                    userConfiguration);
+                final EffectivePermission effectivePerm =
+                    oxfolderAccess.getFolderPermission(folderobject.getObjectID(), userId, userConfiguration);
                 if (!effectivePerm.hasModuleAccess(folderobject.getModule())) {
                     throw new OXFolderException(
                         FolderCode.NO_MODULE_ACCESS,
@@ -381,7 +387,7 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -394,9 +400,13 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
             final int folderId = folderobject.getObjectID();
             final int pos = Arrays.binarySearch(VIRTUAL_IDS, folderId);
             if (pos >= 0) {
-                final FolderObject fo = FolderObject.createVirtualFolderObject(folderId, FolderObject.getFolderString(
-                    folderId,
-                    session.getUser().getLocale()), FolderObject.SYSTEM_MODULE, true, FolderObject.SYSTEM_TYPE);
+                final FolderObject fo =
+                    FolderObject.createVirtualFolderObject(
+                        folderId,
+                        FolderObject.getFolderString(folderId, session.getUser().getLocale()),
+                        FolderObject.SYSTEM_MODULE,
+                        true,
+                        FolderObject.SYSTEM_TYPE);
                 if (3 == pos) {
                     fo.setParentFolderID(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID);
                 } else {
@@ -470,7 +480,7 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -492,14 +502,11 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
             userId = u.getId();
             groups = u.getGroups();
         }
-        final Queue<FolderObject> q = ((FolderObjectIterator) OXFolderIteratorSQL.getAllVisibleFoldersNotSeenInTreeView(
-            userId,
-            groups,
-            userConfiguration,
-            ctx)).asQueue();
+        final Queue<FolderObject> q =
+            ((FolderObjectIterator) OXFolderIteratorSQL.getAllVisibleFoldersNotSeenInTreeView(userId, groups, userConfiguration, ctx)).asQueue();
         final int size = q.size();
         final Iterator<FolderObject> iter = q.iterator();
-        final Set<Integer> stdModules = getNonTreeVisibleModules();
+        final Set<Integer> stdModules = newNonTreeVisibleModules();
         /*
          * Iterate result queue
          */
@@ -683,7 +690,7 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -773,9 +780,13 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
             final int objectID = folderobject.getObjectID();
             final int pos = Arrays.binarySearch(VIRTUAL_IDS, objectID);
             if (pos >= 0) {
-                final FolderObject fo = FolderObject.createVirtualFolderObject(objectID, FolderObject.getFolderString(
-                    objectID,
-                    session.getUser().getLocale()), FolderObject.SYSTEM_MODULE, true, FolderObject.SYSTEM_TYPE);
+                final FolderObject fo =
+                    FolderObject.createVirtualFolderObject(
+                        objectID,
+                        FolderObject.getFolderString(objectID, session.getUser().getLocale()),
+                        FolderObject.SYSTEM_MODULE,
+                        true,
+                        FolderObject.SYSTEM_TYPE);
                 if (3 == pos) {
                     fo.setParentFolderID(FolderObject.SYSTEM_INFOSTORE_FOLDER_ID);
                 } else {
@@ -828,7 +839,7 @@ public class RdbFolderSQLInterface implements FolderSQLInterface {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
