@@ -49,11 +49,12 @@
 
 package com.openexchange.concurrent;
 
+import static com.openexchange.server.services.ServerServiceRegistry.getInstance;
 import java.util.Iterator;
+import java.util.Set;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
 import com.openexchange.server.ServiceException;
-import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.timer.ScheduledTimerTask;
 import com.openexchange.timer.TimerService;
 
@@ -72,9 +73,11 @@ public final class TimeoutConcurrentMap<K, V> {
 
     private final ScheduledTimerTask timeoutTask;
 
+    private final boolean forceTimeout;
+
     private TimeoutListener<V> defaultTimeoutListener;
 
-    private boolean disposed;
+    private volatile boolean disposed;
 
     /**
      * Initializes a new {@link TimeoutConcurrentMap}.
@@ -83,12 +86,44 @@ public final class TimeoutConcurrentMap<K, V> {
      * @throws ServiceException If initialization fails due to missing {@link TimerService timer service}
      */
     public TimeoutConcurrentMap(final int shrinkerIntervalSeconds) throws ServiceException {
+        this(shrinkerIntervalSeconds, false);
+    }
+
+    /**
+     * Initializes a new {@link TimeoutConcurrentMap}.
+     * 
+     * @param shrinkerIntervalSeconds The shrinker interval in seconds
+     * @param forceTimeout <code>true</code> to force initial time-out of contained elements even if they were "touched"; otherwise
+     *            <code>false</code> to keep them alive as long as not timed-out
+     * @throws ServiceException If initialization fails due to missing {@link TimerService timer service}
+     */
+    public TimeoutConcurrentMap(final int shrinkerIntervalSeconds, final boolean forceTimeout) throws ServiceException {
         super();
+        this.forceTimeout = forceTimeout;
         map = new ConcurrentHashMap<K, ValueWrapper<V>>();
-        final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class, true);
+        final TimerService timer = getInstance().getService(TimerService.class, true);
         timeoutTask = timer.scheduleWithFixedDelay(new TimedRunnable<K, V>(map), 1000, shrinkerIntervalSeconds * 1000);
     }
 
+    /**
+     * Checks if map is empty.
+     * 
+     * @return <code>true</code> if map is empty; otherwise <code>false</code>
+     */
+    public boolean isEmpty() {
+        return map.isEmpty();
+    }
+
+    /**
+     * Returns a set view of the keys contained in this map. The set is backed by the map, so changes to the map are reflected in the set,
+     * and vice-versa.
+     * 
+     * @return A set view of the keys contained in this map.
+     */
+    public Set<K> keySet() {
+        return map.keySet();
+    }
+
     /**
      * Disposes this timed map. This is a shut-down command.
      */
@@ -101,7 +136,7 @@ public final class TimeoutConcurrentMap<K, V> {
                 return;
             }
             timeoutTask.cancel(true);
-            final TimerService timer = ServerServiceRegistry.getInstance().getService(TimerService.class);
+            final TimerService timer = getInstance().getService(TimerService.class);
             if (null != timer) {
                 timer.purge();
             }
@@ -180,7 +215,7 @@ public final class TimeoutConcurrentMap<K, V> {
         if (disposed) {
             throw new IllegalStateException("time-out map was disposed.");
         }
-        final ValueWrapper<V> vw = map.put(key, new ValueWrapper<V>(value, timeToLiveSeconds * 1000, timeoutListener));
+        final ValueWrapper<V> vw = map.put(key, new ValueWrapper<V>(value, timeToLiveSeconds * 1000, forceTimeout, timeoutListener));
         if (null == vw) {
             return null;
         }
@@ -215,7 +250,8 @@ public final class TimeoutConcurrentMap<K, V> {
         if (disposed) {
             throw new IllegalStateException("time-out map was disposed.");
         }
-        final ValueWrapper<V> vw = map.putIfAbsent(key, new ValueWrapper<V>(value, timeToLiveSeconds * 1000, timeoutListener));
+        final ValueWrapper<V> vw =
+            map.putIfAbsent(key, new ValueWrapper<V>(value, timeToLiveSeconds * 1000, forceTimeout, timeoutListener));
         if (null == vw) {
             return null;
         }
@@ -239,14 +275,15 @@ public final class TimeoutConcurrentMap<K, V> {
      * @return The value associated with given key or <code>null</code>
      */
     public V get(final K key) {
-        // Remove from map to avoid time-out event in the meantime
-        final ValueWrapper<V> vw = map.remove(key);
+        /*
+         * It is possible that a get() is performed while a running timer attempts to remove this value. In this case the caller receives
+         * associated value although it is actually timed-out. A little misbehavior that is acceptable.
+         */
+        final ValueWrapper<V> vw = map.get(key);
         if (null == vw) {
             return null;
         }
         vw.touch();
-        // Restore to map
-        map.put(key, vw);
         return vw.value;
     }
 
@@ -294,31 +331,34 @@ public final class TimeoutConcurrentMap<K, V> {
 
         public final TimeoutListener<V> timeoutListener;
 
-        private long lastAccessed;
+        public final boolean forceTimeout;
 
-        public ValueWrapper(final V value, final long ttl, final TimeoutListener<V> timeoutListener) {
+        public volatile long lastAccessed;
+
+        public ValueWrapper(final V value, final long ttl, final boolean forceTimeout, final TimeoutListener<V> timeoutListener) {
             super();
             this.value = value;
             this.ttl = ttl;
             lastAccessed = System.currentTimeMillis();
             this.timeoutListener = timeoutListener;
+            this.forceTimeout = forceTimeout;
         }
 
         public void touch() {
+            if (forceTimeout) {
+                // Force time out; don't touch last-accessed time stamp.
+                return;
+            }
             lastAccessed = System.currentTimeMillis();
         }
 
-        public long getLastAccessed() {
-            return lastAccessed;
-        }
-
     }
 
     private static final class TimedRunnable<K, V> implements Runnable {
 
         private final ConcurrentMap<K, ValueWrapper<V>> tmap;
 
-        public TimedRunnable(final ConcurrentMap<K, ValueWrapper<V>> tmap) {
+        TimedRunnable(final ConcurrentMap<K, ValueWrapper<V>> tmap) {
             super();
             this.tmap = tmap;
         }
@@ -327,7 +367,7 @@ public final class TimeoutConcurrentMap<K, V> {
             final long now = System.currentTimeMillis();
             for (final Iterator<ValueWrapper<V>> it = tmap.values().iterator(); it.hasNext();) {
                 final ValueWrapper<V> vw = it.next();
-                if ((now - vw.getLastAccessed()) > vw.ttl) {
+                if ((now - vw.lastAccessed) > vw.ttl) {
                     it.remove();
                     if (vw.timeoutListener != null) {
                         vw.timeoutListener.onTimeout(vw.value);
