@@ -49,13 +49,15 @@
 
 package com.openexchange.database.osgi;
 
+import java.util.Stack;
 import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
-import org.osgi.framework.Constants;
-import org.osgi.framework.Filter;
+import org.osgi.framework.ServiceRegistration;
 import org.osgi.util.tracker.ServiceTracker;
 import com.openexchange.caching.CacheService;
 import com.openexchange.config.ConfigurationService;
+import com.openexchange.database.CreateTableService;
+import com.openexchange.database.internal.CreateReplicationTable;
 import com.openexchange.database.internal.DBPoolingExceptionFactory;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
 import com.openexchange.groupware.EnumComponent;
@@ -69,33 +71,33 @@ import com.openexchange.timer.TimerService;
  */
 public class Activator implements BundleActivator {
 
-    private ServiceTracker configurationTimerTracker;
-
-    private ServiceTracker managementTracker;
-
-    private ServiceTracker cacheTracker;
+    private Stack<ServiceTracker> trackers = new Stack<ServiceTracker>();
 
     private ComponentRegistration dbpoolingComponent;
 
+    private ServiceRegistration createTableRegistration;
+
     public void start(BundleContext context) throws Exception {
         dbpoolingComponent = new ComponentRegistration(
             context,
             EnumComponent.DB_POOLING,
             "com.openexchange.database",
             DBPoolingExceptionFactory.getInstance());
-        Filter filter = context.createFilter("(|(" + Constants.OBJECTCLASS + '=' + ConfigurationService.class.getName() + ")(" + Constants.OBJECTCLASS + '=' + TimerService.class.getName() + "))");
-        configurationTimerTracker = new ServiceTracker(context, filter, new DatabaseServiceRegisterer(context));
-        configurationTimerTracker.open();
-        managementTracker = new ServiceTracker(context, ManagementService.class.getName(), new ManagementServiceCustomizer(context));
-        managementTracker.open();
-        cacheTracker = new ServiceTracker(context, CacheService.class.getName(), new CacheServiceCustomizer(context));
-        cacheTracker.open();
+        createTableRegistration = context.registerService(CreateTableService.class.getName(), new CreateReplicationTable(), null);
+        trackers.push(new ServiceTracker(context, ConfigurationService.class.getName(), new DatabaseServiceRegisterer(context)));
+        trackers.push(new ServiceTracker(context, ManagementService.class.getName(), new ManagementServiceCustomizer(context)));
+        trackers.push(new ServiceTracker(context, TimerService.class.getName(), new TimerServiceCustomizer(context)));
+        trackers.push(new ServiceTracker(context, CacheService.class.getName(), new CacheServiceCustomizer(context)));
+        for (ServiceTracker tracker : trackers) {
+            tracker.open();
+        }
     }
 
     public void stop(BundleContext context) throws Exception {
-        cacheTracker.close();
-        managementTracker.close();
-        configurationTimerTracker.close();
+        while (!trackers.isEmpty()) {
+            trackers.pop().close();
+        }
+        createTableRegistration.unregister();
         dbpoolingComponent.unregister();
     }
 }
