@@ -49,6 +49,7 @@
 
 package com.openexchange.folderstorage.database;
 
+import static com.openexchange.folderstorage.database.DatabaseFolderStorageUtility.getUnsignedInteger;
 import java.sql.Connection;
 import java.sql.SQLException;
 import java.text.Collator;
@@ -75,6 +76,7 @@ import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StoragePriority;
 import com.openexchange.folderstorage.StorageType;
+import com.openexchange.folderstorage.SystemContentType;
 import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.database.contentType.CalendarContentType;
 import com.openexchange.folderstorage.database.contentType.ContactContentType;
@@ -106,6 +108,7 @@ import com.openexchange.tools.oxfolder.OXFolderAccess;
 import com.openexchange.tools.oxfolder.OXFolderException;
 import com.openexchange.tools.oxfolder.OXFolderIteratorSQL;
 import com.openexchange.tools.oxfolder.OXFolderManager;
+import com.openexchange.tools.oxfolder.OXFolderNotFoundException;
 import com.openexchange.tools.oxfolder.OXFolderSQL;
 import com.openexchange.tools.session.ServerSession;
 import com.openexchange.tools.session.ServerSessionAdapter;
@@ -139,7 +142,7 @@ public final class DatabaseFolderStorage implements FolderStorage {
     public ContentType[] getSupportedContentTypes() {
         return new ContentType[] {
             TaskContentType.getInstance(), CalendarContentType.getInstance(), ContactContentType.getInstance(),
-            InfostoreContentType.getInstance(), UnboundContentType.getInstance() };
+            InfostoreContentType.getInstance(), UnboundContentType.getInstance(), SystemContentType.getInstance() };
     }
 
     public ContentType getDefaultContentType() {
@@ -250,8 +253,10 @@ public final class DatabaseFolderStorage implements FolderStorage {
         }
     }
 
-    private static final int[] PUBLIC_FOLDER_IDS = {
-        FolderObject.SYSTEM_PUBLIC_FOLDER_ID, FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID, FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID };
+    private static final int[] PUBLIC_FOLDER_IDS =
+        {
+            FolderObject.SYSTEM_PUBLIC_FOLDER_ID, FolderObject.SYSTEM_USER_INFOSTORE_FOLDER_ID,
+            FolderObject.SYSTEM_PUBLIC_INFOSTORE_FOLDER_ID };
 
     private static int getFolderType(final int folderIdArg, final StorageParameters storageParameters, final FolderType folderType) throws OXException {
         int type = -1;
@@ -335,10 +340,7 @@ public final class DatabaseFolderStorage implements FolderStorage {
             } else if (InfostoreContentType.getInstance().equals(contentType)) {
                 folderId = OXFolderSQL.getUserDefaultFolder(session.getUserId(), FolderObject.INFOSTORE, con, context);
             } else {
-                throw new FolderException(new OXFolderException(
-                    OXFolderException.FolderCode.UNKNOWN_MODULE,
-                    contentType.toString(),
-                    Integer.valueOf(context.getContextId())));
+                return null;
             }
             return String.valueOf(folderId);
         } catch (final DBPoolingException e) {
@@ -352,9 +354,10 @@ public final class DatabaseFolderStorage implements FolderStorage {
         return getFolder(treeId, folderIdentifier, StorageType.WORKING, storageParameters);
     }
 
-    private static final int[] VIRTUAL_IDS = {
-        FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID, FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID,
-        FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID, FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID };
+    private static final int[] VIRTUAL_IDS =
+        {
+            FolderObject.VIRTUAL_LIST_TASK_FOLDER_ID, FolderObject.VIRTUAL_LIST_CALENDAR_FOLDER_ID,
+            FolderObject.VIRTUAL_LIST_CONTACT_FOLDER_ID, FolderObject.VIRTUAL_LIST_INFOSTORE_FOLDER_ID };
 
     public Folder getFolder(final String treeId, final String folderIdentifier, final StorageType storageType, final StorageParameters storageParameters) throws FolderException {
         try {
@@ -380,7 +383,12 @@ public final class DatabaseFolderStorage implements FolderStorage {
                     /*
                      * A numeric folder identifier
                      */
-                    final int folderId = DatabaseFolderStorageUtility.getUnsignedInteger(folderIdentifier);
+                    final int folderId = getUnsignedInteger(folderIdentifier);
+
+                    if (folderId < 0) {
+                        throw new OXFolderNotFoundException(folderIdentifier, ctx);
+                    }
+
                     if (FolderObject.SYSTEM_ROOT_FOLDER_ID == folderId) {
                         retval = SystemRootFolder.getSystemRootFolder();
                     } else if (Arrays.binarySearch(VIRTUAL_IDS, folderId) >= 0) {
@@ -445,15 +453,14 @@ public final class DatabaseFolderStorage implements FolderStorage {
                 /*
                  * Get from backup tables
                  */
-                final int folderId = DatabaseFolderStorageUtility.getUnsignedInteger(folderIdentifier);
-                final FolderObject fo = FolderObject.loadFolderObjectFromDB(
-                    folderId,
-                    ctx,
-                    con,
-                    true,
-                    false,
-                    "del_oxfolder_tree",
-                    "del_oxfolder_permissions");
+                final int folderId = getUnsignedInteger(folderIdentifier);
+
+                if (folderId < 0) {
+                    throw new OXFolderNotFoundException(folderIdentifier, ctx);
+                }
+
+                final FolderObject fo =
+                    FolderObject.loadFolderObjectFromDB(folderId, ctx, con, true, false, "del_oxfolder_tree", "del_oxfolder_permissions");
                 retval = new DatabaseFolder(fo);
             }
             retval.setTreeID(treeId);
@@ -814,51 +821,61 @@ public final class DatabaseFolderStorage implements FolderStorage {
                     /*
                      * A numeric folder identifier
                      */
-                    final int folderId = DatabaseFolderStorageUtility.getUnsignedInteger(folderIdentifier);
-                    if (FolderObject.SYSTEM_ROOT_FOLDER_ID == folderId) {
-                        retval = true;
-                    } else if (Arrays.binarySearch(VIRTUAL_IDS, folderId) >= 0) {
-                        /*
-                         * A virtual database folder
-                         */
-                        retval = VirtualListFolder.existsVirtualListFolder(folderId, user, userConfiguration, ctx, con);
-                    } else {
-                        /*
-                         * A non-virtual database folder
-                         */
+                    final int folderId = getUnsignedInteger(folderIdentifier);
 
-                        if (FolderObject.SYSTEM_SHARED_FOLDER_ID == folderId) {
-                            /*
-                             * The system shared folder
-                             */
+                    if (folderId < 0) {
+                        retval = false;
+                    } else {
+                        if (FolderObject.SYSTEM_ROOT_FOLDER_ID == folderId) {
                             retval = true;
-                        } else if (FolderObject.SYSTEM_PUBLIC_FOLDER_ID == folderId) {
+                        } else if (Arrays.binarySearch(VIRTUAL_IDS, folderId) >= 0) {
                             /*
-                             * The system public folder
+                             * A virtual database folder
                              */
-                            retval = true;
-                        } else if (FolderObject.SYSTEM_INFOSTORE_FOLDER_ID == folderId) {
-                            /*
-                             * The system infostore folder
-                             */
-                            retval = true;
-                        } else if (FolderObject.SYSTEM_PRIVATE_FOLDER_ID == folderId) {
-                            /*
-                             * The system private folder
-                             */
-                            retval = true;
+                            retval = VirtualListFolder.existsVirtualListFolder(folderId, user, userConfiguration, ctx, con);
                         } else {
                             /*
-                             * Check for shared folder, that is folder is of type private and requesting user is different from folder's
-                             * owner
+                             * A non-virtual database folder
                              */
-                            retval = OXFolderSQL.exists(folderId, con, ctx);
+
+                            if (FolderObject.SYSTEM_SHARED_FOLDER_ID == folderId) {
+                                /*
+                                 * The system shared folder
+                                 */
+                                retval = true;
+                            } else if (FolderObject.SYSTEM_PUBLIC_FOLDER_ID == folderId) {
+                                /*
+                                 * The system public folder
+                                 */
+                                retval = true;
+                            } else if (FolderObject.SYSTEM_INFOSTORE_FOLDER_ID == folderId) {
+                                /*
+                                 * The system infostore folder
+                                 */
+                                retval = true;
+                            } else if (FolderObject.SYSTEM_PRIVATE_FOLDER_ID == folderId) {
+                                /*
+                                 * The system private folder
+                                 */
+                                retval = true;
+                            } else {
+                                /*
+                                 * Check for shared folder, that is folder is of type private and requesting user is different from folder's
+                                 * owner
+                                 */
+                                retval = OXFolderSQL.exists(folderId, con, ctx);
+                            }
                         }
                     }
                 }
             } else {
-                final int folderId = DatabaseFolderStorageUtility.getUnsignedInteger(folderIdentifier);
-                retval = OXFolderSQL.exists(folderId, con, ctx, "del_oxfolder_tree");
+                final int folderId = getUnsignedInteger(folderIdentifier);
+
+                if (folderId < 0) {
+                    retval = false;
+                } else {
+                    retval = OXFolderSQL.exists(folderId, con, ctx, "del_oxfolder_tree");
+                }
             }
             return retval;
         } catch (final DBPoolingException e) {
@@ -875,10 +892,11 @@ public final class DatabaseFolderStorage implements FolderStorage {
             final Connection con = getParameter(Connection.class, DatabaseParameterConstants.PARAM_CONNECTION, storageParameters);
             final Context ctx = storageParameters.getContext();
 
-            final Queue<FolderObject> q = ((FolderObjectIterator) OXFolderIteratorSQL.getAllModifiedFoldersSince(
-                timeStamp == null ? new Date(0) : timeStamp,
-                ctx,
-                con)).asQueue();
+            final Queue<FolderObject> q =
+                ((FolderObjectIterator) OXFolderIteratorSQL.getAllModifiedFoldersSince(
+                    timeStamp == null ? new Date(0) : timeStamp,
+                    ctx,
+                    con)).asQueue();
             final int size = q.size();
             final Iterator<FolderObject> iterator = q.iterator();
             final String[] ret = new String[size];
@@ -909,13 +927,14 @@ public final class DatabaseFolderStorage implements FolderStorage {
                 }
             }
 
-            final Queue<FolderObject> q = ((FolderObjectIterator) OXFolderIteratorSQL.getDeletedFoldersSince(
-                timeStamp,
-                user.getId(),
-                user.getGroups(),
-                userConfiguration.getAccessibleModules(),
-                ctx,
-                con)).asQueue();
+            final Queue<FolderObject> q =
+                ((FolderObjectIterator) OXFolderIteratorSQL.getDeletedFoldersSince(
+                    timeStamp,
+                    user.getId(),
+                    user.getGroups(),
+                    userConfiguration.getAccessibleModules(),
+                    ctx,
+                    con)).asQueue();
             final int size = q.size();
             final Iterator<FolderObject> iterator = q.iterator();
             final String[] ret = new String[size];
