@@ -332,6 +332,14 @@ public final class Update extends AbstractAction {
                     FolderStorage.REAL_TREE_ID,
                     realStorage.getDefaultContentType(),
                     storageParameters);
+                if (null == defaultParentId) {
+                    /*
+                     * No default folder found
+                     */
+                    throw FolderExceptionErrorMessage.NO_DEFAULT_FOLDER.create(
+                        realStorage.getDefaultContentType(),
+                        FolderStorage.REAL_TREE_ID);
+                }
                 // TODO: Check permission for obtained default folder ID?
                 final Folder clone4Real = (Folder) folder.clone();
                 clone4Real.setParentID(defaultParentId);
@@ -386,9 +394,9 @@ public final class Update extends AbstractAction {
     private boolean equallyNamedSibling(final String name, final String treeId, final String parentId, final Collection<FolderStorage> openedStorages) throws FolderException {
         final com.openexchange.folderstorage.internal.actions.List listAction;
         if (null == session) {
-            listAction = new com.openexchange.folderstorage.internal.actions.List(user, context);
+            listAction = new com.openexchange.folderstorage.internal.actions.List(user, context, null);
         } else {
-            listAction = new com.openexchange.folderstorage.internal.actions.List(session);
+            listAction = new com.openexchange.folderstorage.internal.actions.List(session, null);
         }
         listAction.setStorageParameters(storageParameters);
         final UserizedFolder[] subfolders = listAction.doList(treeId, parentId, true, openedStorages);
@@ -403,9 +411,9 @@ public final class Update extends AbstractAction {
     private String nonExistingName(final String name, final String treeId, final String parentId, final Collection<FolderStorage> openedStorages) throws FolderException {
         final com.openexchange.folderstorage.internal.actions.List listAction;
         if (null == session) {
-            listAction = new com.openexchange.folderstorage.internal.actions.List(user, context);
+            listAction = new com.openexchange.folderstorage.internal.actions.List(user, context, null);
         } else {
-            listAction = new com.openexchange.folderstorage.internal.actions.List(session);
+            listAction = new com.openexchange.folderstorage.internal.actions.List(session, null);
         }
         listAction.setStorageParameters(storageParameters);
         final UserizedFolder[] subfolders = listAction.doList(treeId, parentId, true, openedStorages);
