@@ -61,17 +61,20 @@ import com.openexchange.folderstorage.ContentType;
 import com.openexchange.folderstorage.Folder;
 import com.openexchange.folderstorage.FolderException;
 import com.openexchange.folderstorage.FolderExceptionErrorMessage;
+import com.openexchange.folderstorage.FolderServiceDecorator;
 import com.openexchange.folderstorage.FolderStorage;
 import com.openexchange.folderstorage.FolderStorageDiscoverer;
 import com.openexchange.folderstorage.Permission;
 import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StorageType;
+import com.openexchange.folderstorage.Type;
 import com.openexchange.folderstorage.UserizedFolder;
 import com.openexchange.folderstorage.database.contentType.InfostoreContentType;
 import com.openexchange.folderstorage.internal.CalculatePermission;
 import com.openexchange.folderstorage.type.PrivateType;
 import com.openexchange.folderstorage.type.PublicType;
+import com.openexchange.folderstorage.type.SharedType;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.User;
@@ -93,9 +96,10 @@ public final class Updates extends AbstractUserizedFolderAction {
      * Initializes a new {@link Updates}.
      * 
      * @param session The session
+     * @param decorator The optional folder service decorator
      */
-    public Updates(final ServerSession session) {
-        super(session);
+    public Updates(final ServerSession session, final FolderServiceDecorator decorator) {
+        super(session, decorator);
     }
 
     /**
@@ -103,19 +107,21 @@ public final class Updates extends AbstractUserizedFolderAction {
      * 
      * @param user The user
      * @param context The context
+     * @param decorator The optional folder service decorator
      */
-    public Updates(final User user, final Context context) {
-        super(user, context);
+    public Updates(final User user, final Context context, final FolderServiceDecorator decorator) {
+        super(user, context, decorator);
     }
 
     /**
      * Initializes a new {@link Updates}.
      * 
      * @param session The session
+     * @param decorator The optional folder service decorator
      * @param folderStorageDiscoverer The folder storage discoverer
      */
-    public Updates(final ServerSession session, final FolderStorageDiscoverer folderStorageDiscoverer) {
-        super(session, folderStorageDiscoverer);
+    public Updates(final ServerSession session, final FolderServiceDecorator decorator, final FolderStorageDiscoverer folderStorageDiscoverer) {
+        super(session, decorator, folderStorageDiscoverer);
     }
 
     /**
@@ -123,10 +129,11 @@ public final class Updates extends AbstractUserizedFolderAction {
      * 
      * @param user The user
      * @param context The context
+     * @param decorator The optional folder service decorator
      * @param folderStorageDiscoverer The folder storage discoverer
      */
-    public Updates(final User user, final Context context, final FolderStorageDiscoverer folderStorageDiscoverer) {
-        super(user, context, folderStorageDiscoverer);
+    public Updates(final User user, final Context context, final FolderServiceDecorator decorator, final FolderStorageDiscoverer folderStorageDiscoverer) {
+        super(user, context, decorator, folderStorageDiscoverer);
     }
 
     /**
@@ -141,8 +148,8 @@ public final class Updates extends AbstractUserizedFolderAction {
      * @throws FolderException If updates request fails
      */
     public UserizedFolder[][] doUpdates(final String treeId, final Date since, final boolean ignoreDeleted, final ContentType[] includeContentTypes) throws FolderException {
-        final List<FolderStorage> realFolderStorages = new ArrayList<FolderStorage>(
-            Arrays.asList(folderStorageDiscoverer.getTreeFolderStorages(FolderStorage.REAL_TREE_ID)));
+        final List<FolderStorage> realFolderStorages =
+            new ArrayList<FolderStorage>(Arrays.asList(folderStorageDiscoverer.getTreeFolderStorages(FolderStorage.REAL_TREE_ID)));
         for (final FolderStorage folderStorage : realFolderStorages) {
             folderStorage.startTransaction(storageParameters, false);
         }
@@ -156,9 +163,8 @@ public final class Updates extends AbstractUserizedFolderAction {
                 if (s instanceof ServerSession) {
                     userConfiguration = ((ServerSession) s).getUserConfiguration();
                 } else {
-                    userConfiguration = UserConfigurationStorage.getInstance().getUserConfiguration(
-                        user.getId(),
-                        storageParameters.getContext());
+                    userConfiguration =
+                        UserConfigurationStorage.getInstance().getUserConfiguration(user.getId(), storageParameters.getContext());
                 }
             }
             final boolean isReal = FolderStorage.REAL_TREE_ID.equals(treeId);
@@ -177,6 +183,13 @@ public final class Updates extends AbstractUserizedFolderAction {
                 checkOpenedStorage(treeStorage, false, openedStorages);
                 treeChecker = new TreeCheckerImpl(treeStorage, storageParameters);
             }
+
+            /*-
+             * ++++++++++++++++++++++++++++++++++++++++------------++++++++++++++++++++++++++++++++++++++++
+             * ++++++++++++++++++++++++++++++++++++++++ HERE WE GO ++++++++++++++++++++++++++++++++++++++++
+             * ++++++++++++++++++++++++++++++++++++++++------------++++++++++++++++++++++++++++++++++++++++
+             */
+
             final List<Folder> updatedList = new ArrayList<Folder>();
             final List<Folder> deletedList = ignoreDeleted ? null : new ArrayList<Folder>();
             boolean addSystemSharedFolder;
@@ -187,11 +200,8 @@ public final class Updates extends AbstractUserizedFolderAction {
                  */
                 final List<Folder> modifiedFolders = new ArrayList<Folder>();
                 for (final FolderStorage folderStorage : realFolderStorages) {
-                    final String[] modifiedFolderIDs = folderStorage.getModifiedFolderIDs(
-                        treeId,
-                        since,
-                        includeContentTypes,
-                        storageParameters);
+                    final String[] modifiedFolderIDs =
+                        folderStorage.getModifiedFolderIDs(treeId, since, includeContentTypes, storageParameters);
                     for (int i = 0; i < modifiedFolderIDs.length; i++) {
                         try {
                             modifiedFolders.add(folderStorage.getFolder(FolderStorage.REAL_TREE_ID, modifiedFolderIDs[i], storageParameters));
@@ -339,14 +349,8 @@ public final class Updates extends AbstractUserizedFolderAction {
             final UserizedFolder[] modified = new UserizedFolder[updatedList.size()];
             for (int i = 0; i < modified.length; i++) {
                 final Folder folder = updatedList.get(i);
-                modified[i] = getUserizedFolder(
-                    folder,
-                    getEffectivePermission(folder),
-                    treeId,
-                    true,
-                    true,
-                    storageParameters,
-                    realFolderStorages);
+                modified[i] =
+                    getUserizedFolder(folder, getEffectivePermission(folder), treeId, true, true, storageParameters, realFolderStorages);
             }
             /*
              * Generate array of deleted folders (if non-null)
@@ -358,14 +362,8 @@ public final class Updates extends AbstractUserizedFolderAction {
                 deleted = new UserizedFolder[deletedList.size()];
                 for (int i = 0; i < deleted.length; i++) {
                     final Folder folder = deletedList.get(i);
-                    deleted[i] = getUserizedFolder(
-                        folder,
-                        getEffectivePermission(folder),
-                        treeId,
-                        true,
-                        true,
-                        storageParameters,
-                        realFolderStorages);
+                    deleted[i] =
+                        getUserizedFolder(folder, getEffectivePermission(folder), treeId, true, true, storageParameters, realFolderStorages);
                 }
             }
             /*
@@ -460,7 +458,8 @@ public final class Updates extends AbstractUserizedFolderAction {
     }
 
     private static boolean isShared(final Folder f, final int userId) {
-        return PrivateType.getInstance().equals(f.getType()) && f.getCreatedBy() != userId;
+        final Type type = f.getType();
+        return SharedType.getInstance().equals(type) || PrivateType.getInstance().equals(type) && f.getCreatedBy() != userId;
     }
 
     private static boolean isPublic(final Folder f) {
