@@ -79,7 +79,11 @@ import com.openexchange.folderstorage.SortableId;
 import com.openexchange.folderstorage.StorageParameters;
 import com.openexchange.folderstorage.StoragePriority;
 import com.openexchange.folderstorage.StorageType;
+import com.openexchange.folderstorage.mail.contentType.DraftsContentType;
 import com.openexchange.folderstorage.mail.contentType.MailContentType;
+import com.openexchange.folderstorage.mail.contentType.SentContentType;
+import com.openexchange.folderstorage.mail.contentType.SpamContentType;
+import com.openexchange.folderstorage.mail.contentType.TrashContentType;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.ldap.User;
@@ -87,6 +91,7 @@ import com.openexchange.mail.FullnameArgument;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.MailField;
 import com.openexchange.mail.MailProviderRegistry;
+import com.openexchange.mail.MailSessionCache;
 import com.openexchange.mail.MailSessionParameterNames;
 import com.openexchange.mail.MailSortField;
 import com.openexchange.mail.OrderDirection;
@@ -138,7 +143,10 @@ public final class MailFolderStorage implements FolderStorage {
             } catch (final MailException e) {
                 throw new FolderException(e);
             }
-            accesses.putIfAbsent(key, ma);
+            final MailAccess<?, ?> prev = accesses.putIfAbsent(key, ma);
+            if (null != prev) {
+                ma = prev;
+            }
         }
         return ma;
     }
@@ -164,7 +172,9 @@ public final class MailFolderStorage implements FolderStorage {
     }
 
     public ContentType[] getSupportedContentTypes() {
-        return new ContentType[] { MailContentType.getInstance() };
+        return new ContentType[] {
+            MailContentType.getInstance(), DraftsContentType.getInstance(), SentContentType.getInstance(), SpamContentType.getInstance(),
+            TrashContentType.getInstance() };
     }
 
     public ContentType getDefaultContentType() {
@@ -172,9 +182,10 @@ public final class MailFolderStorage implements FolderStorage {
     }
 
     public void commitTransaction(final StorageParameters params) throws FolderException {
-        final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) params.getParameter(
-            MailFolderType.getInstance(),
-            MailParameterConstants.PARAM_MAIL_ACCESS);
+        final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+            (ConcurrentMap<Integer, MailAccess<?, ?>>) params.getParameter(
+                MailFolderType.getInstance(),
+                MailParameterConstants.PARAM_MAIL_ACCESS);
         if (null != accesses) {
             try {
                 final Collection<MailAccess<?, ?>> values = accesses.values();
@@ -189,9 +200,10 @@ public final class MailFolderStorage implements FolderStorage {
 
     public void createFolder(final Folder folder, final StorageParameters storageParameters) throws FolderException {
         try {
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -242,9 +254,10 @@ public final class MailFolderStorage implements FolderStorage {
 
     public void clearFolder(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
         try {
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -277,9 +290,10 @@ public final class MailFolderStorage implements FolderStorage {
 
     public void deleteFolder(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
         try {
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -311,11 +325,43 @@ public final class MailFolderStorage implements FolderStorage {
     }
 
     public String getDefaultFolderID(final User user, final String treeId, final ContentType contentType, final StorageParameters storageParameters) throws FolderException {
-        if (!MailContentType.getInstance().equals(contentType)) {
-            // TODO: Throw appropriate folder exception
+        if (!(contentType instanceof MailContentType)) {
+            throw FolderExceptionErrorMessage.UNKNOWN_CONTENT_TYPE.create(contentType.toString());
+        }
+
+        if (MailContentType.getInstance().equals(contentType)) {
+            return prepareFullname(MailAccount.DEFAULT_ID, "INBOX");
+        }
+        try {
+            @SuppressWarnings("unchecked") final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
+            if (null == accesses) {
+                throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
+            }
+            /*
+             * Open mail access
+             */
+            final MailAccess<?, ?> mailAccess = getMailAccessForAccount(0, storageParameters.getSession(), accesses);
+            openMailAccess(mailAccess);
+            // Return primary account's default folder
+            if (DraftsContentType.getInstance().equals(contentType)) {
+                return prepareFullname(MailAccount.DEFAULT_ID, mailAccess.getFolderStorage().getDraftsFolder());
+            }
+            if (SentContentType.getInstance().equals(contentType)) {
+                return prepareFullname(MailAccount.DEFAULT_ID, mailAccess.getFolderStorage().getSentFolder());
+            }
+            if (SpamContentType.getInstance().equals(contentType)) {
+                return prepareFullname(MailAccount.DEFAULT_ID, mailAccess.getFolderStorage().getSpamFolder());
+            }
+            if (TrashContentType.getInstance().equals(contentType)) {
+                return prepareFullname(MailAccount.DEFAULT_ID, mailAccess.getFolderStorage().getTrashFolder());
+            }
+            throw FolderExceptionErrorMessage.UNKNOWN_CONTENT_TYPE.create(contentType.toString());
+        } catch (final MailException e) {
+            throw new FolderException(e);
         }
-        // Return primary account's INBOX folder
-        return prepareFullname(MailAccount.DEFAULT_ID, "INBOX");
     }
 
     public Folder getFolder(final String treeId, final String folderId, final StorageParameters storageParameters) throws FolderException {
@@ -327,9 +373,10 @@ public final class MailFolderStorage implements FolderStorage {
             throw FolderExceptionErrorMessage.UNSUPPORTED_STORAGE_TYPE.create(storageType);
         }
         try {
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            @SuppressWarnings("unchecked") final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -343,11 +390,12 @@ public final class MailFolderStorage implements FolderStorage {
             final boolean hasSubfolders;
             if (MailFolder.DEFAULT_FOLDER_ID.equals(fullname)) {
                 final MailFolder rootFolder = mailAccess.getRootFolder();
-                retval = new MailFolderImpl(
-                    rootFolder,
-                    mailAccess.getAccountId(),
-                    mailAccess.getMailConfig().getCapabilities().getCapabilities(),
-                    null);
+                retval =
+                    new MailFolderImpl(
+                        rootFolder,
+                        mailAccess.getAccountId(),
+                        mailAccess.getMailConfig().getCapabilities().getCapabilities(),
+                        null);
                 /*
                  * Set proper name for non-primary account
                  */
@@ -356,13 +404,13 @@ public final class MailFolderStorage implements FolderStorage {
                      * Set proper name
                      */
                     try {
-                        final MailAccountStorageService storageService = MailServiceRegistry.getServiceRegistry().getService(
-                            MailAccountStorageService.class,
-                            true);
-                        final MailAccount mailAccount = storageService.getMailAccount(
-                            accountId,
-                            storageParameters.getUser().getId(),
-                            storageParameters.getContext().getContextId());
+                        final MailAccountStorageService storageService =
+                            MailServiceRegistry.getServiceRegistry().getService(MailAccountStorageService.class, true);
+                        final MailAccount mailAccount =
+                            storageService.getMailAccount(
+                                accountId,
+                                storageParameters.getUser().getId(),
+                                storageParameters.getContext().getContextId());
                         if (!UnifiedINBOXManagement.PROTOCOL_UNIFIED_INBOX.equals(mailAccount.getMailProtocol())) {
                             retval.setName(mailAccount.getName());
                         }
@@ -376,14 +424,14 @@ public final class MailFolderStorage implements FolderStorage {
             } else {
                 openMailAccess(mailAccess);
                 final MailFolder mailFolder = mailAccess.getFolderStorage().getFolder(fullname);
-                retval = new MailFolderImpl(
-                    mailFolder,
-                    mailAccess.getAccountId(),
-                    mailAccess.getMailConfig().getCapabilities().getCapabilities(),
-                    mailAccess.getFolderStorage().getTrashFolder());
+                retval =
+                    new MailFolderImpl(
+                        mailFolder,
+                        mailAccess.getAccountId(),
+                        mailAccess.getMailConfig().getCapabilities().getCapabilities(),
+                        new MailAccessFullnameProvider(mailAccess));
                 hasSubfolders = mailFolder.hasSubfolders();
             }
-
             retval.setTreeID(treeId);
             /*
              * Check if denoted parent can hold default folders like Trash, Sent, etc.
@@ -461,12 +509,14 @@ public final class MailFolderStorage implements FolderStorage {
     }
 
     private boolean isDefaultFoldersChecked(final int accountId, final Session session) {
-        final Boolean b = (Boolean) session.getParameter(MailSessionParameterNames.getParamDefaultFolderChecked(accountId));
+        final Boolean b =
+            MailSessionCache.getInstance(session).getParameter(accountId, MailSessionParameterNames.getParamDefaultFolderChecked());
         return (b != null) && b.booleanValue();
     }
 
     private String[] getSortedDefaultMailFolders(final int accountId, final Session session) {
-        final String[] arr = (String[]) session.getParameter(MailSessionParameterNames.getParamDefaultFolderArray(accountId));
+        final String[] arr =
+            MailSessionCache.getInstance(session).getParameter(accountId, MailSessionParameterNames.getParamDefaultFolderArray());
         if (arr == null) {
             return new String[0];
         }
@@ -530,9 +580,10 @@ public final class MailFolderStorage implements FolderStorage {
             }
 
             // A mail folder denoted by fullname
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            @SuppressWarnings("unchecked") final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -610,9 +661,10 @@ public final class MailFolderStorage implements FolderStorage {
     }
 
     public void rollback(final StorageParameters params) {
-        final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) params.getParameter(
-            MailFolderType.getInstance(),
-            MailParameterConstants.PARAM_MAIL_ACCESS);
+        final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+            (ConcurrentMap<Integer, MailAccess<?, ?>>) params.getParameter(
+                MailFolderType.getInstance(),
+                MailParameterConstants.PARAM_MAIL_ACCESS);
         if (null != accesses) {
             try {
                 final Collection<MailAccess<?, ?>> values = accesses.values();
@@ -655,9 +707,10 @@ public final class MailFolderStorage implements FolderStorage {
             return false;
         }
         try {
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -695,9 +748,10 @@ public final class MailFolderStorage implements FolderStorage {
 
     public void updateFolder(final Folder folder, final StorageParameters storageParameters) throws FolderException {
         try {
-            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses = (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
-                MailFolderType.getInstance(),
-                MailParameterConstants.PARAM_MAIL_ACCESS);
+            final ConcurrentMap<Integer, MailAccess<?, ?>> accesses =
+                (ConcurrentMap<Integer, MailAccess<?, ?>>) storageParameters.getParameter(
+                    MailFolderType.getInstance(),
+                    MailParameterConstants.PARAM_MAIL_ACCESS);
             if (null == accesses) {
                 throw new FolderException(new MailException(MailException.Code.MISSING_PARAM, MailParameterConstants.PARAM_MAIL_ACCESS));
             }
@@ -812,14 +866,15 @@ public final class MailFolderStorage implements FolderStorage {
                             }
                         }
                         // Copy
-                        final String destFullname = fullCopy(
-                            mailAccess,
-                            fullname,
-                            otherAccess,
-                            newParent,
-                            p.getSeparator(),
-                            storageParameters.getUser().getId(),
-                            otherAccess.getMailConfig().getCapabilities().hasPermissions());
+                        final String destFullname =
+                            fullCopy(
+                                mailAccess,
+                                fullname,
+                                otherAccess,
+                                newParent,
+                                p.getSeparator(),
+                                storageParameters.getUser().getId(),
+                                otherAccess.getMailConfig().getCapabilities().hasPermissions());
                         // Delete source
                         mailAccess.getFolderStorage().deleteFolder(fullname, true);
                         // Perform other updates
@@ -868,12 +923,13 @@ public final class MailFolderStorage implements FolderStorage {
         }
         final String destFullname = destAccess.getFolderStorage().createFolder(mfd);
         // Copy messages
-        final MailMessage[] msgs = srcAccess.getMessageStorage().getAllMessages(
-            srcFullname,
-            null,
-            MailSortField.RECEIVED_DATE,
-            OrderDirection.ASC,
-            new MailField[] { MailField.FULL });
+        final MailMessage[] msgs =
+            srcAccess.getMessageStorage().getAllMessages(
+                srcFullname,
+                null,
+                MailSortField.RECEIVED_DATE,
+                OrderDirection.ASC,
+                new MailField[] { MailField.FULL });
         final IMailMessageStorage destMessageStorage = destAccess.getMessageStorage();
         // Append messages to destination account
         /* final String[] mailIds = */destMessageStorage.appendMessages(destFullname, msgs);
