@@ -60,7 +60,6 @@ import java.util.Set;
 import java.util.TimeZone;
 import com.openexchange.api2.OXException;
 import com.openexchange.database.DBPoolingException;
-import com.openexchange.groupware.calendar.MBoolean;
 import com.openexchange.groupware.container.Appointment;
 import com.openexchange.groupware.container.CalendarObject;
 import com.openexchange.groupware.container.Participant;
@@ -141,8 +140,9 @@ public interface CalendarCollectionService {
 
     /**
      * If user or shared folder owner is missing in participants it is added.
+     * @throws OXException 
      */
-    public void checkAndFillIfUserIsUser(final CalendarDataObject cdao, final Participant p);
+    public void checkAndFillIfUserIsUser(final CalendarDataObject cdao, final Participant p) throws OXException;
 
     public void removeParticipant(final CalendarDataObject cdao, final int uid) throws OXException;
 
