@@ -53,7 +53,6 @@ import static com.openexchange.java.Autoboxing.I;
 import static com.openexchange.java.Autoboxing.I2i;
 import static com.openexchange.tools.sql.DBUtils.closeSQLStuff;
 import static com.openexchange.tools.sql.DBUtils.getIN;
-
 import java.sql.Connection;
 import java.sql.PreparedStatement;
 import java.sql.ResultSet;
@@ -67,12 +66,13 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Set;
-
+import java.util.Map.Entry;
 import com.openexchange.database.DBPoolingException;
 import com.openexchange.groupware.EnumComponent;
 import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.ldap.LdapException.Code;
 import com.openexchange.server.impl.DBPool;
+import com.openexchange.tools.StringCollection;
 import com.openexchange.tools.Collections.SmartIntArray;
 
 /**
@@ -119,7 +119,7 @@ public class RdbUserStorage extends UserStorage {
         int userId = -1;
         try {
             stmt = con.prepareStatement(SELECT_ID);
-            stmt.setLong(1, context.getContextId());
+            stmt.setInt(1, context.getContextId());
             stmt.setString(2, uid);
             result = stmt.executeQuery();
             if (result.next()) {
@@ -142,20 +142,17 @@ public class RdbUserStorage extends UserStorage {
         return userId;
     }
 
-    /**
-     * {@inheritDoc}
-     */
     @Override
     public User getUser(final int userId, final Context context) throws LdapException {
-        Connection con = null;
+        final Connection con;
         try {
             con = DBPool.pickup(context);
-        } catch (final DBPoolingException e) {
+        } catch (DBPoolingException e) {
             throw new LdapException(EnumComponent.USER, Code.NO_CONNECTION, e);
         }
         try {
             return getUser(context, con, new int[] { userId })[0];
-        } catch (final UserException e) {
+        } catch (UserException e) {
             throw new LdapException(e);
         } finally {
             DBPool.closeReaderSilent(context, con);
@@ -172,7 +169,7 @@ public class RdbUserStorage extends UserStorage {
         try {
             stmt = con.prepareStatement(getIN(SELECT_USER, userIds.length));
             int pos = 1;
-            stmt.setLong(pos++, ctx.getContextId());
+            stmt.setInt(pos++, ctx.getContextId());
             for (int userId : userIds) {
                 stmt.setInt(pos++, userId);
             }
@@ -198,7 +195,7 @@ public class RdbUserStorage extends UserStorage {
                 user.setContactId(result.getInt(pos++));
                 users.put(I(user.getId()), user);
             }
-        } catch (final SQLException e) {
+        } catch (SQLException e) {
             throw new UserException(UserException.Code.SQL_ERROR, e, e.getMessage());
         } finally {
             closeSQLStuff(result, stmt);
@@ -263,21 +260,13 @@ public class RdbUserStorage extends UserStorage {
             while (result.next()) {
                 users.get(I(result.getInt(1))).setLoginInfo(result.getString(2));
             }
-        } catch (final SQLException e) {
-            throw new UserException(UserException.Code.SQL_ERROR, e,
-                e.getMessage());
+        } catch (SQLException e) {
+            throw new UserException(UserException.Code.SQL_ERROR, e, e.getMessage());
         } finally {
             closeSQLStuff(result, stmt);
         }
     }
 
-    /**
-     * Reads the contact information for a user.
-     * @param context context.
-     * @param con readable database connection.
-     * @param user User object.
-     * @throws UserException if reading contact fails.
-     */
     private void loadContact(Context ctx, Connection con, Map<Integer, UserImpl> users) throws UserException {
         PreparedStatement stmt = null;
         ResultSet result = null;
@@ -298,21 +287,13 @@ public class RdbUserStorage extends UserStorage {
                 user.setSurname(result.getString(pos++));
                 user.setDisplayName(result.getString(pos++));
             }
-        } catch (final SQLException e) {
-            throw new UserException(UserException.Code.SQL_ERROR, e,
-                e.getMessage());
+        } catch (SQLException e) {
+            throw new UserException(UserException.Code.SQL_ERROR, e, e.getMessage());
         } finally {
             closeSQLStuff(result, stmt);
         }
     }
 
-    /**
-     * Reads the group identifier the user is member of.
-     * @param context context.
-     * @param con readable database connection.
-     * @param user User object.
-     * @throws UserException if loading groups failed.
-     */
     private void loadGroups(Context context, Connection con, Map<Integer, UserImpl> users) throws UserException {
         Map<Integer, List<Integer>> tmp = new HashMap<Integer, List<Integer>>(users.size(), 1);
         for (User user : users.values()) {
@@ -334,9 +315,8 @@ public class RdbUserStorage extends UserStorage {
             while (result.next()) {
                 tmp.get(I(result.getInt(1))).add(I(result.getInt(2)));
             }
-        } catch (final SQLException e) {
-            throw new UserException(UserException.Code.SQL_ERROR, e,
-                e.getMessage());
+        } catch (SQLException e) {
+            throw new UserException(UserException.Code.SQL_ERROR, e, e.getMessage());
         } finally {
             closeSQLStuff(result, stmt);
         }
@@ -347,13 +327,6 @@ public class RdbUserStorage extends UserStorage {
     
     private static final String STR_ALIAS = "alias";
     
-    /**
-     * Reads the attributes/aliases of a user.
-     * @param context The context
-     * @param con readable database connection.
-     * @param user User object.
-     * @throws UserException if loading the aliases fails.
-     */
     private void loadAttributes(Context context, Connection con, Map<Integer, UserImpl> users) throws UserException {
         Map<Integer, Map<String, Set<String>>> usersAttrs = new HashMap<Integer, Map<String, Set<String>>>();
         PreparedStatement stmt = null;
@@ -391,7 +364,7 @@ public class RdbUserStorage extends UserStorage {
              * Check for aliases
              */
             {
-            	final Set<String> aliases = attrs.get(STR_ALIAS);
+                Set<String> aliases = attrs.get(STR_ALIAS);
                 if (aliases == null) {
                     user.setAliases(new String[0]);
                 } else {
@@ -410,28 +383,82 @@ public class RdbUserStorage extends UserStorage {
 
     @Override
     public void updateUser(final User user, final Context context) throws LdapException {
-        Connection con = null;
+        final Connection con;
         try {
             con = DBPool.pickupWriteable(context);
         } catch (final Exception e) {
             throw new LdapException(EnumComponent.USER, Code.NO_CONNECTION, e);
         }
-        PreparedStatement stmt = null;
         try {
-            final String sql = "UPDATE user SET " + TIMEZONE + "=?," + LANGUAGE
-                + "=? WHERE cid=? AND id=?";
-            stmt = con.prepareStatement(sql);
-            int pos = 1;
-            stmt.setString(pos++, user.getTimeZone());
-            stmt.setString(pos++, user.getPreferredLanguage());
-            stmt.setInt(pos++, context.getContextId());
-            stmt.setInt(pos++, user.getId());
-            stmt.execute();
-        } catch (final SQLException e) {
-            throw new LdapException(EnumComponent.USER, Code.SQL_ERROR, e,
-                e.getMessage());
+            final int contextId = context.getContextId();
+            final int id = user.getId();
+            /*
+             * Update time zone and language
+             */
+            PreparedStatement stmt = null;
+            try {
+                final String sql = "UPDATE user SET " + TIMEZONE + "=?," + LANGUAGE
+                    + "=? WHERE cid=? AND id=?";
+                stmt = con.prepareStatement(sql);
+                int pos = 1;
+                stmt.setString(pos++, user.getTimeZone());
+                stmt.setString(pos++, user.getPreferredLanguage());
+                stmt.setInt(pos++, contextId);
+                stmt.setInt(pos++, id);
+                stmt.execute();
+            } catch (final SQLException e) {
+                throw new LdapException(EnumComponent.USER, Code.SQL_ERROR, e,
+                    e.getMessage());
+            } finally {
+                closeSQLStuff(null, stmt);
+            }
+            /*
+             * Check if attributes are set
+             */
+            final Map<String, Set<String>> attributes = user.getAttributes();
+            if (null != attributes) {
+                /*
+                 * Update attributes
+                 */
+                try {
+                    /*
+                     * Clear all attributes
+                     */
+                    stmt = con.prepareStatement("DELETE FROM user_attribute WHERE cid=? AND " + IDENTIFIER + "=?");
+                    int pos = 1;
+                    stmt.setInt(pos++, contextId);
+                    stmt.setInt(pos++, id);
+                    stmt.executeUpdate();
+                    closeSQLStuff(null, stmt);
+                    /*
+                     * Insert new ones
+                     */
+                    if (!attributes.isEmpty()) {
+                        /*
+                         * Batch update them
+                         */
+                        stmt = con.prepareStatement("INSERT INTO user_attribute (cid, " + IDENTIFIER + ", name, value) VALUES (?, ?, ?, ?)");
+                        for (final Entry<String, Set<String>> entry : attributes.entrySet()) {
+                            final String name = entry.getKey();
+                            for (final String value : entry.getValue()) {
+                                pos = 1;
+                                stmt.setInt(pos++, contextId);
+                                stmt.setInt(pos++, id);
+                                stmt.setString(pos++, name);
+                                stmt.setString(pos++, value);
+                                stmt.addBatch();
+                            }
+                        }
+                        stmt.executeBatch();
+                    }
+                } catch (final SQLException e) {
+                    throw new LdapException(EnumComponent.USER, Code.SQL_ERROR, e,
+                        e.getMessage());
+                } finally {
+                    closeSQLStuff(null, stmt);
+                }
+            }
         } finally {
-            closeSQLStuff(null, stmt);
             DBPool.closeWriterSilent(context, con);
         }
     }
@@ -441,47 +468,46 @@ public class RdbUserStorage extends UserStorage {
      */
     @Override
     public User searchUser(String email, Context context) throws LdapException {
-        String sql = "SELECT id FROM user WHERE cid=? AND mail=?";
+        String sql = "SELECT id FROM user WHERE cid=? AND mail LIKE ?";
         Connection con;
         try {
             con = DBPool.pickup(context);
-        } catch (final DBPoolingException e) {
+        } catch (DBPoolingException e) {
             throw new LdapException(EnumComponent.USER, Code.NO_CONNECTION, e);
         }
         try {
+            String pattern = StringCollection.prepareForSearch(email, false, true);
             PreparedStatement stmt = null;
             ResultSet result = null;
             int userId = -1;
             try {
                 stmt = con.prepareStatement(sql);
                 stmt.setInt(1, context.getContextId());
-                stmt.setString(2, email);
+                stmt.setString(2, pattern);
                 result = stmt.executeQuery();
                 if (result.next()) {
                     userId = result.getInt(1);
                 }
-            } catch (final SQLException e) {
-                throw new LdapException(EnumComponent.USER, Code.SQL_ERROR, e,
-                    e.getMessage());
+            } catch (SQLException e) {
+                throw new LdapException(EnumComponent.USER, Code.SQL_ERROR, e, e.getMessage());
             } finally {
                 closeSQLStuff(result, stmt);
             }
             try {
                 if (userId == -1) {
-                    sql = "SELECT id FROM user_attribute WHERE cid=? AND name=? AND value=?";
+                    sql = "SELECT id FROM user_attribute WHERE cid=? AND name=? AND value LIKE ?";
                     stmt = con.prepareStatement(sql);
                     int pos = 1;
                     stmt.setInt(pos++, context.getContextId());
                     stmt.setString(pos++, ALIAS);
-                    stmt.setString(pos++, email);
+                    stmt.setString(pos++, pattern);
                     result = stmt.executeQuery();
                     if (result.next()) {
                         userId = result.getInt(1);
                     }
                 }
                 if (userId == -1) {
-                    throw new LdapException(EnumComponent.USER,
-                        Code.NO_USER_BY_MAIL, email);
+                    throw new LdapException(EnumComponent.USER, Code.NO_USER_BY_MAIL, email);
                 }
                 return getUser(context, con, new int[] { userId })[0];
             } catch (SQLException e) {
@@ -561,7 +587,7 @@ public class RdbUserStorage extends UserStorage {
         PreparedStatement stmt = null;
         ResultSet result = null;
         try {
-            stmt = con.prepareStatement("SELECT id FROM user WHERE cid=?");
+            stmt = con.prepareStatement("SELECT id FROM user WHERE user.cid=?");
             stmt.setInt(1, ctx.getContextId());
             result = stmt.executeQuery();
             List<Integer> tmp = new ArrayList<Integer>();
