@@ -203,6 +203,7 @@ public final class ConfigTree {
     private static Class< ? extends PreferencesItemService>[] getClasses() {
         return new Class[] {
             com.openexchange.groupware.settings.tree.AvailableModules.class,
+            com.openexchange.groupware.settings.tree.BetaFeatures.class,
             com.openexchange.groupware.settings.tree.CalendarNotification.class,
             com.openexchange.groupware.settings.tree.ContactID.class,
             com.openexchange.groupware.settings.tree.ContextID.class,
@@ -300,6 +301,8 @@ public final class ConfigTree {
             com.openexchange.groupware.settings.tree.participants.ShowDialog.class,
             com.openexchange.groupware.settings.tree.participants.ShowWithoutEmail.class,
             com.openexchange.groupware.settings.tree.ReloadTimes.class,
+            // TODO: Enable per-user spell check switch if needed
+            // com.openexchange.groupware.settings.tree.SpellCheck.class,
             com.openexchange.groupware.settings.tree.ServerVersion.class,
             com.openexchange.groupware.settings.tree.TaskNotification.class,
             com.openexchange.groupware.settings.tree.TimeZone.class
