@@ -73,8 +73,9 @@ import com.openexchange.groupware.contexts.impl.ContextImpl;
 import com.openexchange.groupware.ldap.LdapException;
 import com.openexchange.groupware.ldap.RdbUserStorage;
 import com.openexchange.groupware.ldap.User;
-import com.openexchange.groupware.update.Schema;
-import com.openexchange.groupware.update.UpdateTask;
+import com.openexchange.groupware.update.PerformParameters;
+import com.openexchange.groupware.update.ProgressState;
+import com.openexchange.groupware.update.UpdateTaskAdapter;
 import com.openexchange.groupware.update.exception.Classes;
 import com.openexchange.groupware.update.exception.UpdateException;
 import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
@@ -83,10 +84,6 @@ import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.mailaccount.MailAccount;
 import com.openexchange.mailaccount.MailAccountDescription;
-import com.openexchange.mailaccount.MailAccountException;
-import com.openexchange.mailaccount.MailAccountStorageService;
-import com.openexchange.server.ServiceException;
-import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.spamhandler.SpamHandler;
 
 /**
@@ -95,11 +92,7 @@ import com.openexchange.spamhandler.SpamHandler;
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 @OXExceptionSource(classId = Classes.UPDATE_TASK, component = EnumComponent.UPDATE)
-public final class MailAccountMigrationTask implements UpdateTask {
-
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class);
-
-    private static final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(MailAccountMigrationTask.class);
+public final class MailAccountMigrationTask extends UpdateTaskAdapter {
 
     public MailAccountMigrationTask() {
         super();
@@ -113,9 +106,10 @@ public final class MailAccountMigrationTask implements UpdateTask {
         return UpdateTaskPriority.HIGH.priority;
     }
 
-    public void perform(final Schema schema, final int contextId) throws AbstractOXException {
+    public void perform(final PerformParameters params) throws AbstractOXException {
+        final int contextId = params.getContextId();
         final Map<Integer, List<Integer>> m = getAllUsers(contextId);
-
+        final ProgressState state = params.getProgressState();
         for (final Iterator<Map.Entry<Integer, List<Integer>>> it = m.entrySet().iterator(); it.hasNext();) {
             final Map.Entry<Integer, List<Integer>> me = it.next();
             final int currentContextId = me.getKey().intValue();
@@ -127,15 +121,17 @@ public final class MailAccountMigrationTask implements UpdateTask {
                 sb.append(currentContextId);
                 sb.append(":\n");
                 sb.append(e.getMessage());
+                final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class);
                 LOG.error(sb.toString(), e);
             }
+            state.incrementState();
         }
     }
 
     private static Map<Integer, List<Integer>> getAllUsers(final int contextId) throws UpdateException {
         final Connection writeCon;
         try {
-            writeCon = Database.get(contextId, false);
+            writeCon = Database.get(contextId, true);
         } catch (final DBPoolingException e) {
             throw new UpdateException(e);
         }
@@ -165,55 +161,72 @@ public final class MailAccountMigrationTask implements UpdateTask {
             throw createSQLError(e);
         } finally {
             closeSQLStuff(rs, stmt);
-            Database.back(contextId, false, writeCon);
+            Database.back(contextId, true, writeCon);
+        }
+    }
+
+    private static boolean existsPrimaryMailAccount(final int userId, final int contextId) throws UpdateException {
+        final Connection writeCon;
+        try {
+            writeCon = Database.get(contextId, true);
+        } catch (final DBPoolingException e) {
+            throw new UpdateException(e);
+        }
+        PreparedStatement stmt = null;
+        try {
+            stmt = writeCon.prepareStatement("SELECT id FROM user_mail_account WHERE cid = ? AND id = ? AND user = ?");
+            stmt.setInt(1, contextId);
+            stmt.setInt(2, MailAccount.DEFAULT_ID);
+            stmt.setInt(3, userId);
+            return stmt.executeQuery().next();
+        } catch (final SQLException e) {
+            throw createSQLError(e);
+        } finally {
+            closeSQLStuff(stmt);
+            Database.back(contextId, true, writeCon);
         }
     }
 
     private static void iterateUsersPerContext(final List<Integer> users, final int contextId) throws UpdateException {
         final Context ctx = new ContextImpl(contextId);
+        final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailAccountMigrationTask.class);
         // First check (and possibly insert) a sequence for specified context
         checkAndInsertMailAccountSequence(ctx);
         // Proceed with user data migration to new mail account tables
         try {
+            final RdbUserStorage rdbUserStorage = new RdbUserStorage();
             final StringBuilder sb = new StringBuilder(256);
             for (final Integer userId : users) {
-                final MailAccountStorageService storageService = ServerServiceRegistry.getInstance().getService(
-                    MailAccountStorageService.class,
-                    true);
                 // Check for default account
-                try {
-                    storageService.getDefaultMailAccount(userId.intValue(), ctx.getContextId());
+                if (existsPrimaryMailAccount(userId.intValue(), contextId)) {
                     if (LOG.isInfoEnabled()) {
                         sb.setLength(0);
                         LOG.info(sb.append("Default mail account already exists for user ").append(userId).append(" in context ").append(
                             ctx.getContextId()));
                     }
                     continue;
-                } catch (final MailAccountException e) {
-                    // Expected exception since default account should not exist
-                    if (LOG.isTraceEnabled()) {
-                        sb.setLength(0);
-                        LOG.trace(sb.append("Creating default mail account for user ").append(userId).append(" in context ").append(
-                            ctx.getContextId()));
-                    }
+                }
+                // Default account does not exist
+                if (LOG.isTraceEnabled()) {
+                    sb.setLength(0);
+                    LOG.trace(sb.append("Creating default mail account for user ").append(userId).append(" in context ").append(
+                        ctx.getContextId()));
                 }
                 // Create default account
-                final User user = new RdbUserStorage().getUser(userId.intValue(), ctx);
+                final User user = rdbUserStorage.getUser(userId.intValue(), ctx);
                 final UserSettingMail usm = UserSettingMailStorage.getInstance().getUserSettingMail(userId.intValue(), ctx);
                 try {
-                    handleUser(user, getNameProvderFromUSM(usm), ctx, sb);
+                    handleUser(user, getNameProvderFromUSM(usm), ctx, sb, LOG);
                 } catch (final UpdateException e) {
                     LOG.error("Default mail account for user " + user.getId() + " in context " + contextId + " could not be created", e);
                 }
             }
         } catch (final LdapException e) {
             throw new UpdateException(e);
-        } catch (final ServiceException e) {
-            throw new UpdateException(e);
         }
     }
 
-    private static void handleUser(final User user, final FolderNameProvider folderNameProvdider, final Context ctx, final StringBuilder sb) throws UpdateException {
+    private static void handleUser(final User user, final FolderNameProvider folderNameProvdider, final Context ctx, final StringBuilder sb, final org.apache.commons.logging.Log LOG) throws UpdateException {
         /*
          * Insert
          */
@@ -250,8 +263,9 @@ public final class MailAccountMigrationTask implements UpdateTask {
         return null == string ? "" : string;
     }
 
-    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "A SQL error occurred while performing task MailAccountCreateTablesTask: %1$s." })
+    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 1 }, msg = { "A SQL error occurred while performing task MailAccountMigrationTask: %1$s." })
     private static UpdateException createSQLError(final SQLException e) {
+        final UpdateExceptionFactory EXCEPTION = new UpdateExceptionFactory(MailAccountMigrationTask.class);
         return EXCEPTION.create(1, e, e.getMessage());
     }
 
@@ -340,7 +354,8 @@ public final class MailAccountMigrationTask implements UpdateTask {
         }
         PreparedStatement stmt = null;
         try {
-            stmt = con.prepareStatement("INSERT INTO user_mail_account (cid, id, user, name, url, login, password, primary_addr, default_flag, trash, sent, drafts, spam, confirmed_spam, confirmed_ham, spam_handler, trash_fullname, sent_fullname, drafts_fullname, spam_fullname, confirmed_spam_fullname, confirmed_ham_fullname) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
+            stmt =
+                con.prepareStatement("INSERT INTO user_mail_account (cid, id, user, name, url, login, password, primary_addr, default_flag, trash, sent, drafts, spam, confirmed_spam, confirmed_ham, spam_handler, trash_fullname, sent_fullname, drafts_fullname, spam_fullname, confirmed_spam_fullname, confirmed_ham_fullname) VALUES (?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?, ?)");
             int pos = 1;
             // cid, id, user, name, url, login, password, primary_addr, default_flag, trash, sent, drafts, spam, confirmed_spam,
             // confirmed_ham, spam_handler
@@ -374,7 +389,8 @@ public final class MailAccountMigrationTask implements UpdateTask {
             stmt.executeUpdate();
             stmt.close();
             // cid, id, user, name, url, login, password, send_addr, default_flag
-            stmt = con.prepareStatement("INSERT INTO user_transport_account (cid, id, user, name, url, login, password, send_addr, default_flag) VALUES (?,?,?,?,?,?,?,?,?)");
+            stmt =
+                con.prepareStatement("INSERT INTO user_transport_account (cid, id, user, name, url, login, password, send_addr, default_flag) VALUES (?,?,?,?,?,?,?,?,?)");
             pos = 1;
             stmt.setLong(pos++, cid);
             stmt.setLong(pos++, id);
@@ -389,7 +405,7 @@ public final class MailAccountMigrationTask implements UpdateTask {
         } catch (final SQLException e) {
             throw createSQLError(e);
         } finally {
-            closeSQLStuff(null, stmt);
+            closeSQLStuff(stmt);
             Database.back(cid, true, con);
         }
     }
