@@ -71,14 +71,19 @@ import com.openexchange.groupware.contexts.Context;
 import com.openexchange.groupware.contexts.impl.ContextException;
 import com.openexchange.groupware.contexts.impl.ContextImpl;
 import com.openexchange.groupware.contexts.impl.ContextStorage;
+import com.openexchange.groupware.update.PerformParameters;
+import com.openexchange.groupware.update.ProgressState;
 import com.openexchange.groupware.update.Schema;
 import com.openexchange.groupware.update.SchemaStore;
 import com.openexchange.groupware.update.SchemaStoreImpl;
 import com.openexchange.groupware.update.UpdateTask;
+import com.openexchange.groupware.update.UpdateTaskV2;
 import com.openexchange.groupware.update.exception.Classes;
 import com.openexchange.groupware.update.exception.SchemaException;
 import com.openexchange.groupware.update.exception.UpdateException;
 import com.openexchange.groupware.update.exception.UpdateExceptionFactory;
+import com.openexchange.groupware.update.internal.PerformParametersImpl;
+import com.openexchange.groupware.update.internal.ProgressStatusImpl;
 import com.openexchange.tools.sql.DBUtils;
 
 /**
@@ -102,7 +107,8 @@ public final class UpdateTaskToolkit {
         super();
     }
 
-    private static final String SELECT_CONTEXT = "SELECT name,enabled,filestore_id,filestore_name,filestore_login,filestore_passwd,quota_max FROM context WHERE cid=?";
+    private static final String SELECT_CONTEXT =
+        "SELECT name,enabled,filestore_id,filestore_name,filestore_login,filestore_passwd,quota_max FROM context WHERE cid=?";
 
     /**
      * Loads the context by given context identifier.
@@ -214,6 +220,17 @@ public final class UpdateTaskToolkit {
         return loginInfo.toArray(new String[loginInfo.size()]);
     }
 
+    /**
+     * Force (re-)run of update task denoted by given class name
+     * 
+     * @param className The update task's class name
+     * @param schemaName A valid schema name
+     * @throws UpdateException If update task cannot be performed
+     */
+    public static void forceUpdateTask(final String className, final String schemaName) throws UpdateException {
+        forceUpdateTask(className, getContextIdBySchema(schemaName));
+    }
+
     /**
      * Force (re-)run of update task denoted by given class name
      * 
@@ -223,33 +240,74 @@ public final class UpdateTaskToolkit {
      */
     public static void forceUpdateTask(final String className, final int contextId) throws UpdateException {
         synchronized (LOCK) {
+            forceUpdateTask0(getUpdateTask(className), contextId);
+        }
+    }
+
+    /**
+     * Force (re-)run of update task denoted by given class name. This method should only be called when holding <code>LOCK</code>.
+     * 
+     * @param task The update task
+     * @param contextId The context identifier
+     * @throws UpdateException If update task cannot be performed
+     */
+    private static void forceUpdateTask0(final UpdateTask task, final int contextId) throws UpdateException {
+        /*
+         * Get schema for given context ID
+         */
+        final Schema schema = getSchema(contextId);
+        /*
+         * Lock schema
+         */
+        lockSchema(schema, contextId);
+        try {
             /*
-             * Get schema for given context ID
+             * Apply new version number
              */
-            final Schema schema = getSchema(contextId);
+            runUpdateTask(task, schema, contextId);
+        } finally {
             /*
-             * Lock schema
+             * Unlock schema
+             */
+            unlockSchema(schema, contextId);
+            /*
+             * Invalidate schema's contexts
              */
-            lockSchema(schema, contextId);
             try {
-                /*
-                 * Apply new version number
-                 */
-                runUpdateTask(className, schema, contextId);
-            } finally {
-                /*
-                 * Unlock schema
-                 */
-                unlockSchema(schema, contextId);
-                /*
-                 * Invalidate schema's contexts
-                 */
-                try {
-                    removeContexts(contextId);
-                } catch (final DBPoolingException e) {
-                    LOG.error(e.getMessage(), e);
-                } catch (final ContextException e) {
-                    LOG.error(e.getMessage(), e);
+                removeContexts(contextId);
+            } catch (final DBPoolingException e) {
+                LOG.error(e.getMessage(), e);
+            } catch (final ContextException e) {
+                LOG.error(e.getMessage(), e);
+            }
+        }
+    }
+
+    /**
+     * Force (re-)run of update task denoted by given class name on all schemas.
+     * 
+     * @param className The update task's class name
+     * @throws UpdateException If update task cannot be performed
+     */
+    public static void forceUpdateTaskOnAllSchemas(final String className) throws UpdateException {
+        synchronized (LOCK) {
+            /*
+             * Get update task by class name
+             */
+            final UpdateTask updateTask = getUpdateTask(className);
+            /*
+             * Get all available schemas
+             */
+            final Map<String, Set<Integer>> map = getSchemasAndContexts();
+            final int size = map.size();
+            /*
+             * ... and iterate them
+             */
+            final Iterator<Set<Integer>> iter = map.values().iterator();
+            for (int i = 0; i < size; i++) {
+                final Set<Integer> set = iter.next();
+                if (!set.isEmpty()) {
+                    forceUpdateTask0(updateTask, set.iterator().next().intValue());
                 }
             }
         }
@@ -261,7 +319,7 @@ public final class UpdateTaskToolkit {
      * @return All schemas with their versions
      * @throws UpdateException If retrieving schemas and versions fails
      */
-    public static Map<String, Integer> getSchemasAndVersions() throws UpdateException {
+    public static Map<String, Schema> getSchemasAndVersions() throws UpdateException {
         /*
          * Get schemas with their context IDs
          */
@@ -270,18 +328,24 @@ public final class UpdateTaskToolkit {
          * Get version for each schema
          */
         final int size = schemasAndContexts.size();
-        final Map<String, Integer> schemasAndVersions = new HashMap<String, Integer>(size);
+        final Map<String, Schema> schemas = new HashMap<String, Schema>(size);
         final Iterator<Map.Entry<String, Set<Integer>>> it = schemasAndContexts.entrySet().iterator();
         for (int i = 0; i < size; i++) {
             final Map.Entry<String, Set<Integer>> entry = it.next();
             final Schema schema = getSchema(entry.getValue().iterator().next().intValue());
-            schemasAndVersions.put(entry.getKey(), Integer.valueOf(schema.getDBVersion()));
+            schemas.put(entry.getKey(), schema);
         }
-        return schemasAndVersions;
+        return schemas;
     }
 
     private static final String SQL_SELECT_SCHEMAS = "SELECT db_schema, cid FROM context_server2db_pool";
 
+    /**
+     * Gets schemas and their contexts as a map.
+     * 
+     * @return A map containing schemas and their contexts.
+     * @throws UpdateException If an error occurs
+     */
     @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 14 }, msg = { "A SQL error occurred while reading schema version information: %1$s." })
     private static Map<String, Set<Integer>> getSchemasAndContexts() throws UpdateException {
         try {
@@ -323,6 +387,27 @@ public final class UpdateTaskToolkit {
 
     }
 
+    @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 16 }, msg = { "Unknown schema name: %1$s." })
+    public static int getContextIdBySchema(final String schemaName) throws UpdateException {
+        final Map<String, Set<Integer>> map = getSchemasAndContexts();
+        final Set<Integer> set = map.get(schemaName);
+        if (null == set) {
+            throw EXCEPTION.create(16, schemaName);
+        }
+        return set.iterator().next().intValue();
+    }
+
+    /**
+     * Sets the schema's version number to given version number
+     * 
+     * @param versionNumber The version number to set
+     * @param schemaName A valid schema name
+     * @throws UpdateException If changing version number fails
+     */
+    public static void resetVersion(final int versionNumber, final String schemaName) throws UpdateException {
+        resetVersion(versionNumber, getContextIdBySchema(schemaName));
+    }
+
     /**
      * Sets the schema's version number to given version number
      * 
@@ -372,34 +457,47 @@ public final class UpdateTaskToolkit {
     }
 
     @OXThrowsMultiple(category = { Category.CODE_ERROR }, desc = { "" }, exceptionId = { 15 }, msg = { "Error loading update task \"%1$s\"." })
-    private static void runUpdateTask(final String className, final Schema schema, final int contextId) throws UpdateException {
+    private static UpdateTask getUpdateTask(final String className) throws UpdateException {
+        /*
+         * Load update task by class name
+         */
+        try {
+            return Class.forName(className).asSubclass(UpdateTask.class).newInstance();
+        } catch (final InstantiationException e) {
+            throw EXCEPTION.create(15, e, className);
+        } catch (final IllegalAccessException e) {
+            throw EXCEPTION.create(15, e, className);
+        } catch (final ClassNotFoundException e) {
+            throw EXCEPTION.create(15, e, className);
+        }
+    }
+
+    private static void runUpdateTask(final UpdateTask task, final Schema schema, final int contextId) throws UpdateException {
         try {
             /*
              * Remove affected contexts and kick active sessions
              */
             removeContexts(contextId);
             /*
-             * Load update task by class name
+             * Get class name
              */
-            UpdateTask task;
+            final String className = task.getClass().getName();
+            final String schemaName = schema.getSchema();
             try {
-                task = Class.forName(className).asSubclass(UpdateTask.class).newInstance();
-            } catch (final InstantiationException e) {
-                throw EXCEPTION.create(15, e, className);
-            } catch (final IllegalAccessException e) {
-                throw EXCEPTION.create(15, e, className);
-            } catch (final ClassNotFoundException e) {
-                throw EXCEPTION.create(15, e, className);
-            }
-            try {
-                LOG.info("Starting update task " + className + " on schema " + schema.getSchema() + ".");
-                task.perform(schema, contextId);
+                LOG.info(new StringBuilder(64).append("Starting update task ").append(className).append(" on schema ").append(schemaName).append(
+                    '.').toString());
+                if (task instanceof UpdateTaskV2) {
+                    final ProgressState logger = new ProgressStatusImpl(className, schemaName);
+                    final PerformParameters params = new PerformParametersImpl(schema, contextId, logger);
+                    ((UpdateTaskV2) task).perform(params);
+                } else {
+                    task.perform(schema, contextId);
+                }
             } catch (final AbstractOXException e) {
                 LOG.error(e.getMessage(), e);
                 throw new UpdateException(e);
             }
-            LOG.info("Update task " + className + " on schema " + schema.getSchema() + " done.");
-
+            LOG.info(new StringBuilder(64).append("Update task ").append(className).append(schemaName).append(" done.").toString());
         } catch (final DBPoolingException e) {
             LOG.error(e.getMessage(), e);
             throw new UpdateException(e);
