@@ -51,10 +51,17 @@ package com.openexchange.groupware.userconfiguration;
 
 import java.io.Serializable;
 import java.util.Arrays;
+import java.util.Map;
+import java.util.Set;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
+import com.openexchange.config.ConfigurationService;
 import com.openexchange.groupware.container.FolderObject;
 import com.openexchange.groupware.contexts.Context;
+import com.openexchange.groupware.ldap.LdapException;
+import com.openexchange.groupware.ldap.User;
+import com.openexchange.groupware.ldap.UserStorage;
+import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.tools.Collections.SmartIntArray;
 
 /**
@@ -117,24 +124,43 @@ public final class UserConfiguration implements Serializable, Cloneable {
     private static final int SUBSCRIPTION = 1 << 23;
 
     private static final int PUBLICATION = 1 << 24;
-    
+
     private static final int ACTIVE_SYNC = 1 << 25;
-    
+
     private static final int USM = 1 << 26;
 
     /*-
      * Field members
      */
+
+    /**
+     * The user permission bits.
+     */
     private int permissionBits;
 
+    /**
+     * The user identifier.
+     */
     private final int userId;
 
+    /**
+     * The identifiers of user's groups
+     */
     private int[] groups;
 
+    /**
+     * The context.
+     */
     private final transient Context ctx;
 
+    /**
+     * The accessible modules.
+     */
     private int[] accessibleModules;
 
+    /**
+     * Whether accessible modules have already been computed.
+     */
     private volatile boolean accessibleModulesComputed;
 
     /**
@@ -724,10 +750,20 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     /**
      * Checks if this user configuration indicates to enable multiple mail accounts.
+     * <p>
+     * Since this is currently a beta feature, it is globally configurable via user's attribute <code>"beta"</code>.
      * 
      * @return <code>true</code> if this user configuration indicates to enable multiple mail accounts; otherwise <code>false</code>
      */
     public boolean isMultipleMailAccounts() {
+        try {
+            return hasBetaEnabled() && hasPermission(MULTIPLE_MAIL_ACCOUNTS);
+        } catch (final LdapException e) {
+            LOG.error(e.getMessage(), e);
+        }
+        /*
+         * Return flag
+         */
         return hasPermission(MULTIPLE_MAIL_ACCOUNTS);
     }
 
@@ -747,6 +783,14 @@ public final class UserConfiguration implements Serializable, Cloneable {
      * @return <code>true</code> if this user configuration indicates to enable subscription; otherwise <code>false</code>
      */
     public boolean isSubscription() {
+        try {
+            return hasBetaEnabled() && hasPermission(SUBSCRIPTION);
+        } catch (final LdapException e) {
+            LOG.error(e.getMessage(), e);
+        }
+        /*
+         * Return flag
+         */
         return hasPermission(SUBSCRIPTION);
     }
 
@@ -766,6 +810,14 @@ public final class UserConfiguration implements Serializable, Cloneable {
      * @return <code>true</code> if this user configuration indicates to enable publication; otherwise <code>false</code>
      */
     public boolean isPublication() {
+        try {
+            return hasBetaEnabled() && hasPermission(PUBLICATION);
+        } catch (final LdapException e) {
+            LOG.error(e.getMessage(), e);
+        }
+        /*
+         * Return flag
+         */
         return hasPermission(PUBLICATION);
     }
 
@@ -776,24 +828,22 @@ public final class UserConfiguration implements Serializable, Cloneable {
      */
     public void setPublication(final boolean publication) {
         setPermission(publication, PUBLICATION);
-
     }
-    
+
     /**
-     *  Checks if this user configuration indicates that the user may use Exchange Active Sync
+     * Checks if this user configuration indicates that the user may use Exchange Active Sync
      */
     public boolean hasActiveSync() {
         return hasPermission(ACTIVE_SYNC);
     }
-    
+
     /**
      * Sets if this user is able to use Exchange Active Sync
      */
-    public void setActiveSync(boolean eas) {
+    public void setActiveSync(final boolean eas) {
         setPermission(eas, ACTIVE_SYNC);
     }
-    
-    
+
     /**
      * Cheks if this user configuration indicates that the user may use USM.
      */
@@ -804,7 +854,7 @@ public final class UserConfiguration implements Serializable, Cloneable {
     /**
      * Sets if this user is able to user USM.
      */
-    public void setUSM(boolean usm) {
+    public void setUSM(final boolean usm) {
         setPermission(usm, USM);
     }
 
@@ -911,7 +961,56 @@ public final class UserConfiguration implements Serializable, Cloneable {
 
     @Override
     public String toString() {
-        return new StringBuilder().append("UserConfiguration_").append(userId).append('@').append(Integer.toBinaryString(permissionBits)).toString();
+        return new StringBuilder(32).append("UserConfiguration_").append(userId).append('@').append(Integer.toBinaryString(permissionBits)).toString();
+    }
+
+    private static final String BETA = "beta";
+
+    private static final String PROP_BETA = "com.openexchange.user.beta";
+
+    /**
+     * Checks whether configuration's user has beta features enabled.
+     * 
+     * @return <code>true</code> if configuration's user has beta features enabled; otherwise <code>false</code>
+     * @throws LdapException If user cannot be fetched from storage
+     */
+    private boolean hasBetaEnabled() throws LdapException {
+        return getBooleanAttribute(BETA, UserStorage.getInstance().getUser(userId, ctx), getBooleanProperty(PROP_BETA, true));
+    }
+
+    /**
+     * Gets the specified <code>boolean</code> property from configuration service.
+     * 
+     * @param name The property's name
+     * @param defaultValue The default <code>boolean</code> value to return if property is missing
+     * @return The <code>boolean</code> value
+     */
+    private static boolean getBooleanProperty(final String name, final boolean defaultValue) {
+        final ConfigurationService service = ServerServiceRegistry.getInstance().getService(ConfigurationService.class);
+        if (null == service) {
+            return defaultValue;
+        }
+        return service.getBoolProperty(name, defaultValue);
+    }
+
+    /**
+     * Gets the specified <code>boolean</code> attribute from given user.
+     * 
+     * @param name The name of the <code>boolean</code> attribute
+     * @param user The user
+     * @param defaultValue The default value to return if user has no attribute of specified name
+     * @return The value of the <code>boolean</code> attribute
+     */
+    private static boolean getBooleanAttribute(final String name, final User user, final boolean defaultValue) {
+        final Map<String, Set<String>> attributes = user.getAttributes();
+        if (null == attributes) {
+            return defaultValue;
+        }
+        final Set<String> bset = attributes.get(name);
+        if (null == bset || bset.isEmpty()) {
+            return defaultValue;
+        }
+        return Boolean.parseBoolean(bset.iterator().next());
     }
 
 }
