@@ -360,7 +360,35 @@ public class MailException extends AbstractOXException {
         /**
          * In order to accomplish the search, %1$d or more characters are required.
          */
-        PATTERN_TOO_SHORT("In order to accomplish the search, %1$d or more characters are required.", Category.USER_INPUT, 68);
+        PATTERN_TOO_SHORT("In order to accomplish the search, %1$d or more characters are required.", Category.USER_INPUT, 68),
+        /**
+         * Mail folder must not be deleted: %1$s.
+         */
+        FOLDER_DELETION_DENIED("Mail folder must not be deleted: %1$s.", Category.CODE_ERROR, 69),
+        /**
+         * No delete access on mail folder: %1$s.
+         */
+        NO_DELETE_ACCESS("No delete access on mail folder: %1$s.", Category.PERMISSION, 70),
+        /**
+         * Mail folder must not be moved: %1$s.
+         */
+        FOLDER_MOVE_DENIED("Mail folder must not be moved: %1$s.", Category.CODE_ERROR, 71),
+        /**
+         * Mail folder must not be updated: %1$s.
+         */
+        FOLDER_UPDATE_DENIED("Mail folder must not be updated: %1$s.", Category.CODE_ERROR, 72),
+        /**
+         * No write access on mail folder: %1$s.
+         */
+        NO_WRITE_ACCESS("No write access on mail folder: %1$s.", Category.PERMISSION, 73),
+        /**
+         * No connection available to access mailbox
+         */
+        NOT_CONNECTED("No connection available to access mailbox", Category.CODE_ERROR, 74),
+        /**
+         * Mail could not be found in folder %1$s for Message-Id: %2$s
+         */
+        MAIL_NOT_FOUN_BY_MESSAGE_ID("Mail could not be found in folder %1$s for Message-Id: %2$s", Category.CODE_ERROR, 32);
 
         private final String message;
 
