@@ -161,6 +161,22 @@ public final class MailFields {
         return arr[mailField.ordinal()];
     }
 
+    /**
+     * Checks if any of specified mail field constants is contained.
+     * 
+     * @param mailFields The mail fields to check
+     * @return <code>true</code> if any of specified mail field constants is contained; otherwise <code>false</code>.
+     */
+    public boolean containsAny(final MailFields mailFields) {
+        final boolean[] otherArr = mailFields.arr;
+        for (int i = 0; i < otherArr.length; i++) {
+            if (otherArr[i] && arr[i]) {
+                return true;
+            }
+        }
+        return false;
+    }
+
     /**
      * Returns a newly created array of {@link MailField} constants
      * 
