@@ -50,6 +50,7 @@
 package com.openexchange.mail;
 
 import com.openexchange.api2.MailInterfaceMonitor;
+import com.openexchange.filemanagement.ManagedFile;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.dataobjects.MailFolder;
 import com.openexchange.mail.dataobjects.MailFolderDescription;
@@ -58,6 +59,7 @@ import com.openexchange.mail.dataobjects.MailPart;
 import com.openexchange.mail.dataobjects.compose.ComposeType;
 import com.openexchange.mail.dataobjects.compose.ComposedMailMessage;
 import com.openexchange.mail.usersetting.UserSettingMail;
+import com.openexchange.search.SearchTerm;
 import com.openexchange.session.Session;
 import com.openexchange.tools.iterator.SearchIterator;
 
@@ -105,6 +107,16 @@ public abstract class MailServletInterface {
 
     public static final MailInterfaceMonitor mailInterfaceMonitor = new MailInterfaceMonitor();
 
+    /**
+     * Gets a mail's ID by specified "Message-Id" header.
+     * 
+     * @param folder The folder to search in
+     * @param messageID The "Message-Id" header
+     * @return The ID of the mail corresponding to specified "Message-Id" header
+     * @throws MailException If no mauil could be found
+     */
+    public abstract String getMailIDByMessageID(final String folder, final String messageID) throws MailException;
+
     /**
      * Returns all message counts in specified folder in an <code>int</code> array as follows: <code>0</code>: Message Count, <code>1</code>
      * : New Message Count, <code>2</code>: Unread MessageCount, <code>3</code>: Deleted Message Count
@@ -167,6 +179,13 @@ public abstract class MailServletInterface {
      */
     public abstract SearchIterator<MailMessage> getMessages(String folder, int[] fromToIndices, int sortCol, int order, int[] searchCols, String[] searchPatterns, boolean linkSearchTermsWithOR, int[] fields) throws MailException;
 
+    /**
+     * Returns an instance of <code>SearchIterator</code> containing a selection of messages located in given folder.
+     * <code>fromToIndices</code> can define a range of messages that should be returned. Moreover <code>searchCols</code> and
+     * <code>searchPatterns</code> defines a search pattern to further confine returned messages.
+     */
+    public abstract SearchIterator<MailMessage> getMessages(String folder, int[] fromToIndices, int sortCol, int order, SearchTerm<?> searchTerm, boolean linkSearchTermsWithOR, int[] fields) throws MailException;
+
     /**
      * Returns a thread-view-sorted instance of <code>SearchIterator</code> containing all messages located in given folder.
      */
@@ -203,6 +222,17 @@ public abstract class MailServletInterface {
      */
     public abstract MailPart getMessageAttachment(String folder, String msgUID, String attachmentPosition, boolean displayVersion) throws MailException;
 
+    /**
+     * Returns message's attachments as a ZIP file backed by returned managed file instance.
+     * 
+     * @param folder The folder
+     * @param msgUID The message ID
+     * @param attachmentPositions The attachment positions
+     * @return A ZIP file backed by returned managed file instance
+     * @throws MailException If an error occurs
+     */
+    public abstract ManagedFile getMessageAttachments(String folder, String msgUID, String[] attachmentPositions) throws MailException;
+
     /**
      * Returns a message's inline image located identified with given <code>cid</code> wrapped by an instance of
      * <code>JSONMessageAttachmentObject</code> for a convenient access to its attributes and content.
