@@ -385,10 +385,40 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
      * @throws MailException If returning the root folder fails
      */
     public MailFolder getRootFolder() throws MailException {
-        connect0(false);
+        if (!isConnected()) {
+            connect0(false);
+        }
         return getFolderStorage().getRootFolder();
     }
 
+    /**
+     * Convenience method to obtain folder's number of unread messages in a fast way; meaning no default folder check is performed.
+     * <p>
+     * The same result is yielded through calling <code>getFolderStorage().getFolder().getUnreadMessageCount()</code> on a connected
+     * {@link MailAccess}.
+     * <p>
+     * Since this mail access instance is connected if not already done before, the {@link #close(boolean)} operation should be invoked
+     * afterwards:
+     * 
+     * <pre>
+     * final MailAccess mailAccess = MailAccess.getInstance(session);
+     * final int unreadCount = mailAccess.getNumberOfUnreadMessages();
+     * try {
+     *  // Do something with unread count
+     * } finally {
+     *  mailAccess.close(putToCache)
+     * }
+     * </pre>
+     * 
+     * @throws MailException If returning the unread count fails
+     */
+    public int getUnreadMessagesCount(final String fullname) throws MailException {
+        if (!isConnected()) {
+            connect0(false);
+        }
+        return getFolderStorage().getFolder(fullname).getUnreadMessageCount();
+    }
+
     private final void connect0(final boolean checkDefaultFolder) throws MailException {
         applyNewThread();
         if (isConnected()) {
@@ -412,14 +442,15 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
             throw e;
         } catch (final Exception e) {
             final MailConfig mailConfig = getMailConfig();
-            final MailException mailExc = new MailException(
-                MailException.Code.DEFAULT_FOLDER_CHECK_FAILED,
-                e,
-                mailConfig.getServer(),
-                Integer.valueOf(session.getUserId()),
-                mailConfig.getLogin(),
-                Integer.valueOf(session.getContextId()),
-                e.getMessage());
+            final MailException mailExc =
+                new MailException(
+                    MailException.Code.DEFAULT_FOLDER_CHECK_FAILED,
+                    e,
+                    mailConfig.getServer(),
+                    Integer.valueOf(session.getUserId()),
+                    mailConfig.getLogin(),
+                    Integer.valueOf(session.getContextId()),
+                    e.getMessage());
             LOG.error(mailExc.getMessage(), mailExc);
             closeInternal();
             throw mailExc;
@@ -593,8 +624,9 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
              * Admin mail login is not permitted per configuration
              */
             Context ctx;
+            final String key = MailSessionParameterNames.getParamSessionContext();
             try {
-                ctx = (Context) session.getParameter(MailSessionParameterNames.getParamSessionContext(accountId));
+                ctx = (Context) session.getParameter(key);
             } catch (final ClassCastException e1) {
                 ctx = null;
             }
@@ -604,6 +636,7 @@ public abstract class MailAccess<F extends IMailFolderStorage, M extends IMailMe
                 } catch (final ContextException e) {
                     throw new MailException(e);
                 }
+                session.setParameter(key, ctx);
             }
             if (session.getUserId() == ctx.getMailadmin()) {
                 throw new MailException(MailException.Code.ACCOUNT_DOES_NOT_EXIST, Integer.valueOf(ctx.getContextId()));
