@@ -49,14 +49,8 @@
 
 package com.openexchange.mail.cache;
 
-import java.io.Serializable;
-import java.lang.reflect.Array;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
-import java.util.concurrent.atomic.AtomicBoolean;
 import java.util.concurrent.locks.Lock;
 import java.util.concurrent.locks.ReadWriteLock;
 import java.util.concurrent.locks.ReentrantReadWriteLock;
@@ -87,229 +81,6 @@ public final class MailMessageCache {
      */
     private static final String ANNOT_UNCHECKED = "unchecked";
 
-    private static final class DoubleKeyMap<K1, K2, V> implements Serializable {
-
-        private static final long serialVersionUID = 4691428774420782654L;
-
-        private final transient Map<K1, Map<K2, V>> map;
-
-        private final transient Class<V> clazz;
-
-        /**
-         * Constructor.
-         * 
-         * @param clazz The class of the values
-         */
-        public DoubleKeyMap(final Class<V> clazz) {
-            map = new ConcurrentHashMap<K1, Map<K2, V>>();
-            this.clazz = clazz;
-        }
-
-        /**
-         * Detects if first key is contained in this map.
-         * 
-         * @param k1 The first key
-         * @return <code>true</code> if first key is contained in this map; otherwise <code>false</code>
-         */
-        public boolean containsKey(final K1 k1) {
-            return map.containsKey(k1);
-        }
-
-        /**
-         * Detects if key pair is contained in this map.
-         * 
-         * @param k1 The first key
-         * @param k2 The second key
-         * @return <code>true</code> if key pair is contained in this map; otherwise <code>false</code>
-         */
-        public boolean containsKeypair(final K1 k1, final K2 k2) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (null == innerMap) {
-                return false;
-            }
-            return innerMap.containsKey(k2);
-        }
-
-        /**
-         * Gets all values associated with given first key.
-         * 
-         * @param k1 The first key
-         * @return All values associated with given first key or <code>null</code> if none found
-         */
-        @SuppressWarnings(ANNOT_UNCHECKED)
-        public V[] getValues(final K1 k1) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (innerMap == null) {
-                return null;
-            }
-            return innerMap.values().toArray((V[]) Array.newInstance(clazz, innerMap.size()));
-        }
-
-        /**
-         * Gets the values associated with given first key and given second keys.
-         * 
-         * @param k1 The first key
-         * @param keys The second keys
-         * @return The values associated with given first key and given second keys
-         */
-        @SuppressWarnings(ANNOT_UNCHECKED)
-        public V[] getValues(final K1 k1, final K2[] keys) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (innerMap == null) {
-                return null;
-            }
-            final List<V> tmp = new ArrayList<V>(keys.length);
-            for (int i = 0; i < keys.length; i++) {
-                tmp.add(innerMap.get(keys[i]));
-            }
-            return tmp.toArray((V[]) Array.newInstance(clazz, tmp.size()));
-        }
-
-        /**
-         * Gets the single value associated with given key pair.
-         * 
-         * @param k1 The first key
-         * @param k2 The second key
-         * @return The single value associated with given key pair or <code>null</code> if not present
-         */
-        public V getValue(final K1 k1, final K2 k2) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (null == innerMap) {
-                return null;
-            }
-            return innerMap.get(k2);
-        }
-
-        /**
-         * Puts given values into map.
-         * 
-         * @param k1 The first key
-         * @param keys The second keys
-         * @param values The values to insert
-         */
-        public void putValues(final K1 k1, final K2[] keys, final V[] values) {
-            if ((k1 == null) || (keys == null) || (values == null)) {
-                throw new IllegalArgumentException("Argument must not be null");
-            }
-            Map<K2, V> innerMap = this.map.get(k1);
-            if (innerMap == null) {
-                innerMap = new ConcurrentHashMap<K2, V>(values.length);
-                this.map.put(k1, innerMap);
-            }
-            for (int i = 0; i < values.length; i++) {
-                if (values[i] != null) {
-                    innerMap.put(keys[i], values[i]);
-                }
-            }
-        }
-
-        /**
-         * Puts a single value into map.
-         * 
-         * @param k1 The first key
-         * @param k2 The second key
-         * @param value The value to insert
-         * @return The value formerly bound to given key pair or <code>null</code> if none was bound before
-         */
-        public V putValue(final K1 k1, final K2 k2, final V value) {
-            if ((k1 == null) || (k2 == null) || (value == null)) {
-                throw new IllegalArgumentException("Argument must not be null");
-            }
-            Map<K2, V> innerMap = this.map.get(k1);
-            if (innerMap == null) {
-                innerMap = new ConcurrentHashMap<K2, V>();
-                this.map.put(k1, innerMap);
-            }
-            return innerMap.put(k2, value);
-        }
-
-        /**
-         * Removes all values associated with given first key.
-         * 
-         * @param k1 The first key
-         */
-        public void removeValues(final K1 k1) {
-            map.remove(k1);
-        }
-
-        /**
-         * Removes the values associated with given first key and is in list of second keys.
-         * 
-         * @param k1 The first key
-         * @param keys The second keys
-         */
-        public void removeValues(final K1 k1, final K2[] keys) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (null == innerMap) {
-                return;
-            }
-            for (int i = 0; i < keys.length; i++) {
-                innerMap.remove(keys[i]);
-            }
-            if (innerMap.isEmpty()) {
-                /*
-                 * Remove empty inner map
-                 */
-                map.remove(k1);
-            }
-        }
-
-        /**
-         * Removes the single value associated with given key pair.
-         * 
-         * @param k1 The first key
-         * @param k2 The second key
-         * @return The removed value or <code>null</code> if not present
-         */
-        public V removeValue(final K1 k1, final K2 k2) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (null == innerMap) {
-                return null;
-            }
-            final V retval = innerMap.remove(k2);
-            if ((retval != null) && innerMap.isEmpty()) {
-                /*
-                 * Remove empty inner map
-                 */
-                map.remove(k1);
-            }
-            return retval;
-        }
-
-        /**
-         * Checks if no values are bound to given first key.
-         * 
-         * @param k1 The first key
-         * @return <code>true</code> if no values are bound to given first key; otherwise <code>false</code>
-         */
-        public boolean isEmpty(final K1 k1) {
-            final Map<K2, V> innerMap = map.get(k1);
-            if (null == innerMap) {
-                return true;
-            } else if (innerMap.isEmpty()) {
-                map.remove(k1);
-                return true;
-            }
-            return false;
-        }
-
-        /**
-         * Checks if whole map is empty.
-         * 
-         * @return <code>true</code> if whole map is empty; otherwise <code>false</code>
-         */
-        public boolean isEmpty() {
-            return map.isEmpty();
-        }
-
-        /**
-         * Clears whole map.
-         */
-        public void clear() {
-            map.clear();
-        }
-    }
-
     private static interface MailFieldUpdater {
 
         public void updateField(MailMessage mail, Object newValue);
@@ -383,15 +154,14 @@ public final class MailMessageCache {
 
     static final String REGION_NAME = "MailMessageCache";
 
-    private static final AtomicBoolean initialized = new AtomicBoolean();
-
     private static final ConcurrentMap<CacheKey, ReadWriteLock> contextLocks = new ConcurrentHashMap<CacheKey, ReadWriteLock>();
 
-    private static MailMessageCache singleton;
+    private static volatile MailMessageCache singleton;
 
     /*-
-     * Field members
+     * ############################################## Field members ##############################################
      */
+
     private Cache cache;
 
     /**
@@ -474,32 +244,42 @@ public final class MailMessageCache {
      * @throws OXCachingException If instance initialization failed
      */
     public static MailMessageCache getInstance() throws OXCachingException {
-        if (!initialized.get()) {
-            synchronized (initialized) {
-                if (null == singleton) {
-                    singleton = new MailMessageCache();
-                    initialized.set(true);
+        MailMessageCache tmp = singleton;
+        if (null == tmp) {
+            synchronized (MailMessageCache.class) {
+                tmp = singleton;
+                if (null == tmp) {
+                    tmp = singleton = new MailMessageCache();
                 }
             }
         }
-        return singleton;
+        return tmp;
     }
 
     /**
      * Releases the singleton instance.
      */
     public static void releaseInstance() {
-        if (initialized.get()) {
-            synchronized (initialized) {
+        if (null != singleton) {
+            synchronized (MailMessageCache.class) {
                 if (null != singleton) {
                     singleton = null;
-                    initialized.set(false);
                 }
             }
         }
     }
 
-    @SuppressWarnings(ANNOT_UNCHECKED)
+    /**
+     * Updates cached message
+     * 
+     * @param uids The messages' identifiers
+     * @param accountId The account ID
+     * @param fullname The fullname
+     * @param userId The user identifier
+     * @param cid The context identifier
+     * @param changedFields The changed fields
+     * @param newValues The new values
+     */
     public void updateCachedMessages(final String[] uids, final int accountId, final String fullname, final int userId, final int cid, final MailListField[] changedFields, final Object[] newValues) {
         if (null == cache) {
             return;
@@ -508,7 +288,8 @@ public final class MailMessageCache {
         final Lock writeLock = getLock(mapKey).writeLock();
         writeLock.lock();
         try {
-            final DoubleKeyMap<CacheKey, String, MailMessage> map = (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+            final @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+                (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
             if (map == null) {
                 return;
             }
@@ -551,13 +332,13 @@ public final class MailMessageCache {
      * @param cid The context ID
      * @return <code>true</code> if cache holds messages belonging to a certain folder; otherwise <code>false</code>
      */
-    @SuppressWarnings(ANNOT_UNCHECKED)
     public boolean containsFolderMessages(final int accountId, final String fullname, final int userId, final int cid) {
         if (null == cache) {
             return false;
         }
         final CacheKey mapKey = getMapKey(userId, cid);
-        final DoubleKeyMap<CacheKey, String, MailMessage> map = (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+        final @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+            (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
         if (map == null) {
             return false;
         }
@@ -597,7 +378,6 @@ public final class MailMessageCache {
      * @param userId The user ID
      * @param cid The context ID
      */
-    @SuppressWarnings(ANNOT_UNCHECKED)
     public void removeFolderMessages(final int accountId, final String fullname, final int userId, final int cid) {
         if (null == cache) {
             return;
@@ -606,7 +386,8 @@ public final class MailMessageCache {
         final Lock writeLock = getLock(mapKey).writeLock();
         writeLock.lock();
         try {
-            final DoubleKeyMap<CacheKey, String, MailMessage> map = (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+            final @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+                (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
             if (map == null) {
                 return;
             }
@@ -625,7 +406,6 @@ public final class MailMessageCache {
      * @param userId The user ID
      * @param cid The context ID
      */
-    @SuppressWarnings(ANNOT_UNCHECKED)
     public void removeMessages(final String[] uids, final int accountId, final String fullname, final int userId, final int cid) {
         if (null == cache) {
             return;
@@ -634,7 +414,8 @@ public final class MailMessageCache {
         final Lock writeLock = getLock(mapKey).writeLock();
         writeLock.lock();
         try {
-            final DoubleKeyMap<CacheKey, String, MailMessage> map = (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+            final @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+                (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
             if (map == null) {
                 return;
             }
@@ -655,7 +436,6 @@ public final class MailMessageCache {
      * @param cid The context ID
      * @return An array of {@link MailMessage} containing the fetched messages or <code>null</code>
      */
-    @SuppressWarnings(ANNOT_UNCHECKED)
     public MailMessage[] getMessages(final String[] uids, final int accountId, final String fullname, final int userId, final int cid) {
         if (null == cache) {
             return null;
@@ -664,7 +444,8 @@ public final class MailMessageCache {
         final Lock readLock = getLock(mapKey).readLock();
         readLock.lock();
         try {
-            final DoubleKeyMap<CacheKey, String, MailMessage> map = (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+            final @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+                (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
             if (null == map) {
                 return null;
             }
@@ -700,7 +481,6 @@ public final class MailMessageCache {
      * @param cid The context ID
      * @throws OXCachingException If cache put fails
      */
-    @SuppressWarnings(ANNOT_UNCHECKED)
     public void putMessages(final int accountId, final MailMessage[] mails, final int userId, final int cid) throws OXCachingException {
         if (null == cache) {
             return;
@@ -712,7 +492,8 @@ public final class MailMessageCache {
             final Lock writeLock = getLock(mapKey).writeLock();
             writeLock.lock();
             try {
-                DoubleKeyMap<CacheKey, String, MailMessage> map = (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
+                @SuppressWarnings(ANNOT_UNCHECKED) DoubleKeyMap<CacheKey, String, MailMessage> map =
+                    (DoubleKeyMap<CacheKey, String, MailMessage>) cache.get(mapKey);
                 if (null == map) {
                     map = new DoubleKeyMap<CacheKey, String, MailMessage>(MailMessage.class);
                     cache.put(mapKey, map);
