@@ -70,6 +70,17 @@ public class MailFolder implements Serializable {
      */
     private static final long serialVersionUID = -8203697938992090309L;
 
+    /**
+     * The default folder type.
+     */
+    public static enum DefaultFolderType {
+        NONE, INBOX, DRAFTS, SENT, SPAM, TRASH, CONFIRMED_SPAM, CONFIRMED_HAM;
+    }
+
+    private DefaultFolderType defaulFolderType;
+
+    private boolean b_defaulFolderType;
+
     private String name;
 
     private boolean b_name;
@@ -177,6 +188,7 @@ public class MailFolder implements Serializable {
      */
     public MailFolder() {
         super();
+        defaulFolderType = DefaultFolderType.NONE;
     }
 
     /**
@@ -289,6 +301,105 @@ public class MailFolder implements Serializable {
         b_hasSubscribedSubfolders = true;
     }
 
+    /**
+     * Gets the default folder type.
+     * 
+     * @return The default folder type
+     */
+    public DefaultFolderType getDefaultFolderType() {
+        return defaulFolderType;
+    }
+
+    /**
+     * Checks if this mail folder denotes the INBOX folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the INBOX folder; otherwise <code>false</code>
+     */
+    public boolean isInbox() {
+        return DefaultFolderType.INBOX.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if this mail folder denotes the DRAFTS folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the DRAFTS folder; otherwise <code>false</code>
+     */
+    public boolean isDrafts() {
+        return DefaultFolderType.DRAFTS.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if this mail folder denotes the SENT folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the SENT folder; otherwise <code>false</code>
+     */
+    public boolean isSent() {
+        return DefaultFolderType.SENT.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if this mail folder denotes the SPAM folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the SPAM folder; otherwise <code>false</code>
+     */
+    public boolean isSpam() {
+        return DefaultFolderType.SPAM.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if this mail folder denotes the TRASH folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the TRASH folder; otherwise <code>false</code>
+     */
+    public boolean isTrash() {
+        return DefaultFolderType.TRASH.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if this mail folder denotes the CONFIRMED_SPAM folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the CONFIRMED_SPAM folder; otherwise <code>false</code>
+     */
+    public boolean isConfirmedSpam() {
+        return DefaultFolderType.CONFIRMED_SPAM.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if this mail folder denotes the CONFIRMED_HAM folder.
+     * 
+     * @return <code>true</code> if this mail folder denotes the CONFIRMED_HAM folder; otherwise <code>false</code>
+     */
+    public boolean isConfirmedHam() {
+        return DefaultFolderType.CONFIRMED_HAM.equals(defaulFolderType);
+    }
+
+    /**
+     * Checks if default folder type was set through {@link #setDefaultFolderType(DefaultFolderType)}.
+     * 
+     * @return <code>true</code> if default folder type is set; otherwise <code>false</code>
+     */
+    public boolean containsDefaultFolderType() {
+        return b_defaulFolderType;
+    }
+
+    /**
+     * Removes the default folder type.
+     */
+    public void removeDefaultFolderType() {
+        defaulFolderType = DefaultFolderType.NONE;
+        b_defaulFolderType = false;
+    }
+
+    /**
+     * Sets default folder type.
+     * 
+     * @param name the name to set
+     */
+    public void setDefaultFolderType(final DefaultFolderType defaulFolderType) {
+        this.defaulFolderType = defaulFolderType;
+        b_defaulFolderType = true;
+    }
+
     /**
      * Gets the name.
      * 
