@@ -72,10 +72,14 @@ import com.openexchange.mail.dataobjects.MailMessage;
 import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.parser.MailMessageParser;
 import com.openexchange.mail.parser.handlers.JSONMessageHandler;
+import com.openexchange.mail.parser.handlers.RawJSONMessageHandler;
+import com.openexchange.mail.structure.StructureMailMessageParser;
+import com.openexchange.mail.structure.parser.MIMEStructureHandler;
 import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.usersetting.UserSettingMailStorage;
 import com.openexchange.mail.utils.DisplayMode;
 import com.openexchange.session.Session;
+import com.openexchange.tools.TimeZoneUtils;
 
 /**
  * {@link MessageWriter} - Writes {@link MailMessage} instances as JSON strings
@@ -84,7 +88,7 @@ import com.openexchange.session.Session;
  */
 public final class MessageWriter {
 
-    private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MessageWriter.class);
+    // private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MessageWriter.class);
 
     /**
      * No instantiation
@@ -93,6 +97,21 @@ public final class MessageWriter {
         super();
     }
 
+    /**
+     * Writes specified mail's structure as a JSON object.
+     * 
+     * @param accountId The mail's account ID
+     * @param mail The mail to write
+     * @param maxSize The allowed max. size
+     * @return The structure as a JSON object
+     * @throws MailException If writing structure fails
+     */
+    public static JSONObject writeStructure(final int accountId, final MailMessage mail, final long maxSize) throws MailException {
+        final MIMEStructureHandler handler = new MIMEStructureHandler(maxSize);
+        new StructureMailMessageParser().parseMailMessage(mail, handler);
+        return handler.getJSONMailObject();
+    }
+
     /**
      * Writes whole mail as a JSON object.
      * 
@@ -116,7 +135,8 @@ public final class MessageWriter {
         }
         final UserSettingMail usm;
         try {
-            usm = null == settings ? UserSettingMailStorage.getInstance().getUserSettingMail(session.getUserId(), session.getContextId()) : settings;
+            usm =
+                null == settings ? UserSettingMailStorage.getInstance().getUserSettingMail(session.getUserId(), session.getContextId()) : settings;
         } catch (final UserConfigurationException e) {
             throw new MailException(e);
         }
@@ -125,6 +145,28 @@ public final class MessageWriter {
         return handler.getJSONObject();
     }
 
+    /**
+     * Writes raw mail as a JSON object.
+     * 
+     * @param accountId The account ID
+     * @param mail The mail to write
+     * @return The written JSON object or <code>null</code> if message's text body parts exceed max. size
+     * @throws MailException If writing message fails
+     */
+    public static JSONObject writeRawMailMessage(final int accountId, final MailMessage mail) throws MailException {
+        final MailPath mailPath;
+        if (mail.getFolder() != null && mail.getMailId() != null) {
+            mailPath = new MailPath(accountId, mail.getFolder(), mail.getMailId());
+        } else if (mail.getMsgref() != null) {
+            mailPath = mail.getMsgref();
+        } else {
+            mailPath = MailPath.NULL;
+        }
+        final RawJSONMessageHandler handler = new RawJSONMessageHandler(accountId, mailPath, mail);
+        new MailMessageParser().parseMailMessage(mail, handler);
+        return handler.getJSONObject();
+    }
+
     public static interface MailFieldWriter {
 
         public void writeField(JSONValue jsonContainer, MailMessage mail, int level, boolean withKey, int accountId, int user, int cid) throws MailException;
@@ -272,7 +314,7 @@ public final class MessageWriter {
                         if (mail.containsSentDate() && mail.getSentDate() != null) {
                             ((JSONObject) jsonContainer).put(
                                 MailJSONField.SENT_DATE.getKey(),
-                                addUserTimezone(mail.getSentDate().getTime(), TimeZone.getTimeZone(UserStorage.getStorageUser(
+                                addUserTimezone(mail.getSentDate().getTime(), TimeZoneUtils.getTimeZone(UserStorage.getStorageUser(
                                     user,
                                     ContextStorage.getStorageContext(cid)).getTimeZone())));
                         }
@@ -280,7 +322,7 @@ public final class MessageWriter {
                         if (mail.containsSentDate() && mail.getSentDate() != null) {
                             ((JSONArray) jsonContainer).put(addUserTimezone(
                                 mail.getSentDate().getTime(),
-                                TimeZone.getTimeZone(UserStorage.getStorageUser(user, ContextStorage.getStorageContext(cid)).getTimeZone())));
+                                TimeZoneUtils.getTimeZone(UserStorage.getStorageUser(user, ContextStorage.getStorageContext(cid)).getTimeZone())));
                         } else {
                             ((JSONArray) jsonContainer).put(JSONObject.NULL);
                         }
@@ -300,7 +342,7 @@ public final class MessageWriter {
                         if (mail.containsReceivedDate() && mail.getReceivedDate() != null) {
                             ((JSONObject) jsonContainer).put(
                                 MailJSONField.RECEIVED_DATE.getKey(),
-                                addUserTimezone(mail.getReceivedDate().getTime(), TimeZone.getTimeZone(UserStorage.getStorageUser(
+                                addUserTimezone(mail.getReceivedDate().getTime(), TimeZoneUtils.getTimeZone(UserStorage.getStorageUser(
                                     user,
                                     ContextStorage.getStorageContext(cid)).getTimeZone())));
                         }
@@ -308,7 +350,7 @@ public final class MessageWriter {
                         if (mail.containsReceivedDate() && mail.getReceivedDate() != null) {
                             ((JSONArray) jsonContainer).put(addUserTimezone(
                                 mail.getReceivedDate().getTime(),
-                                TimeZone.getTimeZone(UserStorage.getStorageUser(user, ContextStorage.getStorageContext(cid)).getTimeZone())));
+                                TimeZoneUtils.getTimeZone(UserStorage.getStorageUser(user, ContextStorage.getStorageContext(cid)).getTimeZone())));
                         } else {
                             ((JSONArray) jsonContainer).put(JSONObject.NULL);
                         }
@@ -356,7 +398,8 @@ public final class MessageWriter {
                     if ((mail.containsPrevSeen() ? mail.isPrevSeen() : mail.isSeen())) {
                         value = JSONObject.NULL;
                     } else {
-                        value = mail.getDispositionNotification() == null ? JSONObject.NULL : mail.getDispositionNotification().toUnicodeString();
+                        value =
+                            mail.getDispositionNotification() == null ? JSONObject.NULL : mail.getDispositionNotification().toUnicodeString();
                     }
                     if (withKey) {
                         if (!JSONObject.NULL.equals(value)) {
