@@ -49,12 +49,10 @@
 
 package com.openexchange.mail.mime;
 
-import java.io.BufferedReader;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.Serializable;
-import java.io.StringReader;
 import java.util.ArrayList;
 import java.util.HashMap;
 import java.util.HashSet;
@@ -64,6 +62,7 @@ import java.util.Map;
 import java.util.NoSuchElementException;
 import java.util.Set;
 import java.util.Map.Entry;
+import java.util.regex.Pattern;
 import com.openexchange.mail.MailException;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
@@ -79,7 +78,8 @@ public class HeaderCollection implements Serializable {
 
     private static final long serialVersionUID = 6939560514144351286L;
 
-    private static final transient org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(HeaderCollection.class);
+    private static final transient org.apache.commons.logging.Log LOG =
+        org.apache.commons.logging.LogFactory.getLog(HeaderCollection.class);
 
     /**
      * Read-only constant for an empty header collection
@@ -178,14 +178,15 @@ public class HeaderCollection implements Serializable {
             int i = -1;
             NextRead: while ((i = inputStream.read()) != -1) {
                 int count = 0;
-                while ((i == '\r') || (i == '\n')) {
-                    if (i != -1) {
-                        buffer.write(i);
-                    }
-                    if ((i == '\n') && (++count >= 2)) {
+                while (('\r' == i) || ('\n' == i)) {
+                    buffer.write(i);
+                    if (('\n' == i) && (++count >= 2)) {
                         break NextRead;
                     }
                     i = inputStream.read();
+                    if (-1 == i) { // EOF
+                        break NextRead;
+                    }
                 }
                 buffer.write(i);
             }
@@ -195,6 +196,8 @@ public class HeaderCollection implements Serializable {
         }
     }
 
+    private static final Pattern SPLIT = Pattern.compile("\r?\n");
+
     /**
      * Read and parse the given headers' <small><b><a href="http://www.ietf.org/rfc/rfc822.txt">RFC822</a></b></small> source till the blank
      * line separating the header from the body.
@@ -206,49 +209,64 @@ public class HeaderCollection implements Serializable {
      * @throws MailException If reading from headers' source fails
      */
     public void load(final String headerSrc) throws MailException {
-        if (null == headerSrc || headerSrc.length() == 0) {
+        if ((null == headerSrc) || (0 == headerSrc.length())) {
             // Nothing to load
             return;
         }
         /*
          * Read header lines until a blank line.
          */
-        final BufferedReader reader = new BufferedReader(new StringReader(headerSrc));
-        final StringBuilder lineBuffer = new StringBuilder(128);
-        String line;
+        final String[] lines = SPLIT.split(headerSrc, 0);
+
+        final StringBuilder lineBuffer = new StringBuilder(76);
+        boolean emptyBuffer = true;
+
         String prevline = null;
-        try {
-            do {
-                line = reader.readLine();
-                if (line != null && line.length() > 0 && (line.charAt(0) == ' ' || line.charAt(0) == '\t')) {
-                    /*
-                     * Header continuation
-                     */
-                    if (prevline != null) {
-                        lineBuffer.append(prevline);
-                        prevline = null;
-                    }
-                    lineBuffer.append(CRLF);
-                    lineBuffer.append(line);
-                } else {
-                    /*
-                     * A new header
-                     */
-                    if (prevline != null) {
-                        addHeaderLine(prevline);
-                    } else if (lineBuffer.length() > 0) {
-                        /*
-                         * Store previous header first
-                         */
-                        addHeaderLine(lineBuffer.toString());
-                        lineBuffer.setLength(0);
-                    }
-                    prevline = line;
+
+        String line;
+        int length;
+
+        for (int i = 0; i < lines.length && (length = (line = lines[i]).length()) > 0; i++) {
+            if ((length > 0) && isSpaceOrTab(line.charAt(0))) {
+                /*
+                 * Header continuation
+                 */
+                if (prevline != null) {
+                    lineBuffer.append(prevline);
+                    prevline = null;
                 }
-            } while (line != null && line.length() > 0);
-        } catch (final IOException ioex) {
-            throw new MailException(MailException.Code.IO_ERROR, ioex, ioex.getMessage());
+                lineBuffer.append(CRLF);
+                lineBuffer.append(line);
+                emptyBuffer = false;
+            } else {
+                /*
+                 * A new header
+                 */
+                if (prevline != null) {
+                    addHeaderLine(prevline);
+                } else if (!emptyBuffer) {
+                    /*
+                     * Store previous header first
+                     */
+                    addHeaderLine(lineBuffer.toString());
+                    lineBuffer.setLength(0);
+                    emptyBuffer = true;
+                }
+                prevline = line;
+            }
         }
+        /*
+         * Check for pending header line
+         */
+        if (prevline != null) {
+            addHeaderLine(prevline);
+        } else if (!emptyBuffer) {
+            addHeaderLine(lineBuffer.toString());
+        }
+    }
+
+    private static boolean isSpaceOrTab(final char c) {
+        return (c == ' ' || c == '\t');
     }
 
     private final void addHeaderLine(final String headerLine) {
@@ -682,7 +700,8 @@ public class HeaderCollection implements Serializable {
         public void remove() {
             if (entry == null) {
                 throw new IllegalStateException(
-                    "next() method has not yet been called, or the remove()" + " method has already been called after the last call to the next() method.");
+                    new StringBuilder(64).append("next() method has not yet been called, or the remove()").append(
+                        " method has already been called after the last call to the next() method.").toString());
             }
             entry.getValue().remove(--index);
             if (entry.getValue().isEmpty()) {
