@@ -63,13 +63,13 @@ import javax.mail.internet.MimeUtility;
  * Quotes are added to encoded personal names to maintain them when converting to mail-safe version. Parental {@link InternetAddress} class
  * ignores quotes when when converting to mail-safe version:
  * <p>
- * <code>``"Müller,&nbsp;Jan"&nbsp;&lt;mj@foo.de&gt;''</code><br>
+ * <code>``"M&uuml;ller,&nbsp;Jan"&nbsp;&lt;mj@foo.de&gt;''</code><br>
  * is converted to<br>
  * <code>``=?UTF-8?Q?M=C3=BCller=2C_Jan?=&nbsp;&lt;mj@foo.de&gt;''</code>
  * <p>
  * This class maintains the quotes in mail-safe version:
  * <p>
- * <code>``"Müller,&nbsp;Jan"&nbsp;&lt;mj@foo.de&gt;''</code><br>
+ * <code>``"M&uuml;ller,&nbsp;Jan"&nbsp;&lt;mj@foo.de&gt;''</code><br>
  * is converted to<br>
  * <code>``=?UTF-8?Q?=22M=C3=BCller=2C_Jan=22?=&nbsp;&lt;mj@foo.de&gt;''</code>
  * 
@@ -767,28 +767,14 @@ public final class QuotedInternetAddress extends InternetAddress {
      */
     public QuotedInternetAddress(final String address) throws AddressException {
         super();
-        // use our address parsing utility routine to parse the string
-        final InternetAddress a[] = parse(address, true);
-        // if we got back anything other than a single address, it's an error
-        if (a.length != 1) {
-            throw new AddressException("Illegal address", address);
-        }
-
-        /*
-         * Now copy the contents of the single address we parsed into the current object, which will be returned from the constructor. XXX -
-         * this sure is a round-about way of getting this done.
-         */
-        final QuotedInternetAddress internetAddress = (QuotedInternetAddress) a[0];
-        this.address = internetAddress.address;
-        this.personal = internetAddress.personal;
-        this.encodedPersonal = internetAddress.encodedPersonal;
+        parseAddress0(address);
     }
 
     /**
      * Initializes a new {@link QuotedInternetAddress}.
      * <p>
      * Parse the given string and create an InternetAddress. If strict is <code>false</code>, the detailed syntax of the address isn't
-     * checked.
+     * checked. toACE
      * 
      * @param address The address in RFC822 format
      * @param strict <code>true</code> enforce RFC822 syntax; otherwise <code>false</code>
@@ -834,6 +820,40 @@ public final class QuotedInternetAddress extends InternetAddress {
         setPersonal(personal, charset);
     }
 
+    /**
+     * Parses the given string into this {@link QuotedInternetAddress}.
+     * 
+     * @param address The address in RFC822 format
+     * @throws AddressException If parsing the address fails
+     */
+    public void parseAddress(final String address) throws AddressException {
+        parseAddress0(address);
+    }
+
+    /**
+     * Internal parse routine.
+     * 
+     * @param address The address in RFC822 format
+     * @throws AddressException If parsing the address fails
+     */
+    private void parseAddress0(final String address) throws AddressException {
+        // use our address parsing utility routine to parse the string
+        final InternetAddress a[] = parse(address, true);
+        // if we got back anything other than a single address, it's an error
+        if (a.length != 1) {
+            throw new AddressException("Illegal address", address);
+        }
+
+        /*
+         * Now copy the contents of the single address we parsed into the current object, which will be returned from the constructor. XXX -
+         * this sure is a round-about way of getting this done.
+         */
+        final QuotedInternetAddress internetAddress = (QuotedInternetAddress) a[0];
+        this.address = internetAddress.address;
+        this.personal = internetAddress.personal;
+        this.encodedPersonal = internetAddress.encodedPersonal;
+    }
+
     /**
      * Sets the email address.
      * 
@@ -925,7 +945,7 @@ public final class QuotedInternetAddress extends InternetAddress {
     /**
      * Returns a properly formatted address (RFC 822 syntax) of Unicode characters.
      * 
-     * @return Unicode address string
+     * @return The Unicode address string
      */
     @Override
     public String toUnicodeString() {
@@ -936,7 +956,7 @@ public final class QuotedInternetAddress extends InternetAddress {
             }
             return new StringBuilder(32).append(quotePhrase(p)).append(" <").append(toIDN(address)).append('>').toString();
         } else if (isGroup() || isSimple()) {
-            return address;
+            return toIDN(address);
         } else {
             return new StringBuilder().append('<').append(toIDN(address)).append('>').toString();
         }
