@@ -110,20 +110,22 @@ public final class MIMEMessageConverter {
 
     private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MIMEMessageConverter.class);
 
-    private static final EnumSet<MailField> ENUM_SET_FULL = EnumSet.complementOf(EnumSet.of(
-        MailField.BODY,
-        MailField.FULL,
-        MailField.ACCOUNT_NAME));
+    private static final boolean DEBUG = LOG.isDebugEnabled();
+
+    private static final EnumSet<MailField> ENUM_SET_FULL =
+        EnumSet.complementOf(EnumSet.of(MailField.BODY, MailField.FULL, MailField.ACCOUNT_NAME));
 
     private static interface MailMessageFieldFiller {
 
-        public static final String[] NON_MATCHING_HEADERS = {
-            MessageHeaders.HDR_FROM, MessageHeaders.HDR_TO, MessageHeaders.HDR_CC, MessageHeaders.HDR_BCC, MessageHeaders.HDR_DISP_NOT_TO,
-            MessageHeaders.HDR_REPLY_TO, MessageHeaders.HDR_SUBJECT, MessageHeaders.HDR_DATE, MessageHeaders.HDR_X_PRIORITY,
-            MessageHeaders.HDR_MESSAGE_ID, MessageHeaders.HDR_IN_REPLY_TO, MessageHeaders.HDR_REFERENCES, MessageHeaders.HDR_X_OX_VCARD,
-            MessageHeaders.HDR_X_OX_NOTIFICATION };
+        public static final String[] NON_MATCHING_HEADERS =
+            {
+                MessageHeaders.HDR_FROM, MessageHeaders.HDR_TO, MessageHeaders.HDR_CC, MessageHeaders.HDR_BCC,
+                MessageHeaders.HDR_DISP_NOT_TO, MessageHeaders.HDR_REPLY_TO, MessageHeaders.HDR_SUBJECT, MessageHeaders.HDR_DATE,
+                MessageHeaders.HDR_X_PRIORITY, MessageHeaders.HDR_MESSAGE_ID, MessageHeaders.HDR_IN_REPLY_TO,
+                MessageHeaders.HDR_REFERENCES, MessageHeaders.HDR_X_OX_VCARD, MessageHeaders.HDR_X_OX_NOTIFICATION };
 
-        public static final org.apache.commons.logging.Log LOG1 = org.apache.commons.logging.LogFactory.getLog(MailMessageFieldFiller.class);
+        public static final org.apache.commons.logging.Log LOG1 =
+            org.apache.commons.logging.LogFactory.getLog(MailMessageFieldFiller.class);
 
         /**
          * Fills a fields from source instance of {@link Message} in given destination instance of {@link MailMessage}.
@@ -245,8 +247,8 @@ public final class MIMEMessageConverter {
             } else {
                 final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(size <= 0 ? DEFAULT_MESSAGE_SIZE : size);
                 mail.writeTo(out);
-                mimeMessage = new MimeMessage(MIMEDefaultSession.getDefaultSession(), new UnsynchronizedByteArrayInputStream(
-                    out.toByteArray()));
+                mimeMessage =
+                    new MimeMessage(MIMEDefaultSession.getDefaultSession(), new UnsynchronizedByteArrayInputStream(out.toByteArray()));
             }
             if (mail.containsFlags()) {
                 parseMimeFlags(mail.getFlags(), mimeMessage);
@@ -472,8 +474,8 @@ public final class MIMEMessageConverter {
         }
     }
 
-    private static final EnumMap<MailField, MailMessageFieldFiller> FILLER_MAP_EXT = new EnumMap<MailField, MailMessageFieldFiller>(
-        MailField.class);
+    private static final EnumMap<MailField, MailMessageFieldFiller> FILLER_MAP_EXT =
+        new EnumMap<MailField, MailMessageFieldFiller>(MailField.class);
 
     static {
         FILLER_MAP_EXT.put(MailField.HEADERS, new MailMessageFieldFiller() {
@@ -734,7 +736,7 @@ public final class MIMEMessageConverter {
             final MailMessageFieldFiller filler = FILLER_MAP_EXT.get(field);
             if (filler == null) {
                 if (MailField.BODY.equals(field) || MailField.FULL.equals(field) || MailField.ACCOUNT_NAME.equals(field)) {
-                    if (LOG.isDebugEnabled()) {
+                    if (DEBUG) {
                         LOG.debug("Ignoring mail field " + field);
                     }
                     fillers[i] = null;
@@ -748,8 +750,8 @@ public final class MIMEMessageConverter {
         return fillers;
     }
 
-    private static final EnumMap<MailField, MailMessageFieldFiller> FILLER_MAP = new EnumMap<MailField, MailMessageFieldFiller>(
-        MailField.class);
+    private static final EnumMap<MailField, MailMessageFieldFiller> FILLER_MAP =
+        new EnumMap<MailField, MailMessageFieldFiller>(MailField.class);
 
     static {
         FILLER_MAP.put(MailField.HEADERS, new MailMessageFieldFiller() {
@@ -874,6 +876,10 @@ public final class MIMEMessageConverter {
         });
         FILLER_MAP.put(MailField.CONTENT_TYPE, new MailMessageFieldFiller() {
 
+            private final String multipart = "multipart";
+
+            private final String mixed = "mixed";
+
             public void fillField(final MailMessage mailMessage, final Message msg) throws MessagingException, MailException {
                 ContentType ct = null;
                 try {
@@ -903,9 +909,23 @@ public final class MIMEMessageConverter {
                     mailMessage.setHasAttachment(((ExtendedMimeMessage) msg).hasAttachment());
                 } else {
                     try {
-                        mailMessage.setHasAttachment(ct.isMimeType(MIMETypes.MIME_MULTIPART_ALL) && (ct.isMimeType(MIMETypes.MIME_MULTIPART_MIXED) || hasAttachments(
+                        mailMessage.setHasAttachment(ct.startsWith(multipart) && (mixed.equalsIgnoreCase(ct.getSubType()) || hasAttachments(
                             (Multipart) msg.getContent(),
                             ct.getSubType())));
+                    } catch (final ClassCastException e) {
+                        // Cast to javax.mail.Multipart failed
+                        LOG1.warn(new StringBuilder(256).append(
+                            "Message's Content-Type indicates to be multipart/* but its content is not an instance of javax.mail.Multipart but ").append(
+                            e.getMessage()).append(
+                            ".\nIn case if IMAP it is due to a wrong BODYSTRUCTURE returned by IMAP server.\nGoing to mark message to have (file) attachments if Content-Type matches multipart/mixed.").toString());
+                        mailMessage.setHasAttachment(ct.startsWith(MIMETypes.MIME_MULTIPART_MIXED));
+                    } catch (final MessagingException e) {
+                        // A messaging error occurred
+                        LOG1.warn(new StringBuilder(256).append(
+                            "Parsing message's multipart/* content to check for file attachments caused a messaging error: ").append(
+                            e.getMessage()).append(
+                            ".\nGoing to mark message to have (file) attachments if Content-Type matches multipart/mixed.").toString());
+                        mailMessage.setHasAttachment(ct.startsWith(MIMETypes.MIME_MULTIPART_MIXED));
                     } catch (final IOException e) {
                         throw new MailException(MailException.Code.IO_ERROR, e, e.getMessage());
                     }
@@ -1052,7 +1072,7 @@ public final class MIMEMessageConverter {
                         }
                     };
                 } else if (MailField.BODY.equals(field) || MailField.FULL.equals(field) || MailField.ACCOUNT_NAME.equals(field)) {
-                    if (LOG.isDebugEnabled()) {
+                    if (DEBUG) {
                         LOG.debug("Ignoring mail field " + field);
                     }
                     fillers[i] = null;
@@ -1093,6 +1113,8 @@ public final class MIMEMessageConverter {
         }
     }
 
+    private static final String MULTI_PRIMTYPE = "multipart/";
+
     private static final String MULTI_SUBTYPE_MIXED = "MIXED";
 
     /**
@@ -1156,9 +1178,25 @@ public final class MIMEMessageConverter {
             }
             {
                 final ContentType ct = mail.getContentType();
-                mail.setHasAttachment(ct.isMimeType(MIMETypes.MIME_MULTIPART_ALL) && (MULTI_SUBTYPE_MIXED.equalsIgnoreCase(ct.getSubType()) || hasAttachments(
-                    (Multipart) msg.getContent(),
-                    ct.getSubType())));
+                try {
+                    mail.setHasAttachment(ct.startsWith(MULTI_PRIMTYPE) && (MULTI_SUBTYPE_MIXED.equalsIgnoreCase(ct.getSubType()) || hasAttachments(
+                        (Multipart) msg.getContent(),
+                        ct.getSubType())));
+                } catch (final ClassCastException e) {
+                    // Cast to javax.mail.Multipart failed
+                    LOG.warn(new StringBuilder(256).append(
+                        "Message's Content-Type indicates to be multipart/* but its content is not an instance of javax.mail.Multipart but ").append(
+                        e.getMessage()).append(
+                        ".\nIn case if IMAP it is due to a wrong BODYSTRUCTURE returned by IMAP server.\nGoing to mark message to have (file) attachments if Content-Type matches multipart/mixed.").toString());
+                    mail.setHasAttachment(ct.startsWith(MIMETypes.MIME_MULTIPART_MIXED));
+                } catch (final MessagingException e) {
+                    // A messaging error occurred
+                    LOG.warn(new StringBuilder(256).append(
+                        "Parsing message's multipart/* content to check for file attachments caused a messaging error: ").append(
+                        e.getMessage()).append(
+                        ".\nGoing to mark message to have (file) attachments if Content-Type matches multipart/mixed.").toString());
+                    mail.setHasAttachment(ct.startsWith(MIMETypes.MIME_MULTIPART_MIXED));
+                }
             }
             {
                 final String[] tmp = msg.getHeader(MessageHeaders.HDR_CONTENT_ID);
@@ -1541,7 +1579,7 @@ public final class MIMEMessageConverter {
                 }
             }
         } catch (final MessagingException e) {
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG) {
                 LOG.debug("JavaMail API failed to load part's headers. Using own routine.", e);
             }
             final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(DEFAULT_MESSAGE_SIZE);
@@ -1559,7 +1597,7 @@ public final class MIMEMessageConverter {
                 headers = new HeaderCollection(0);
             }
         } catch (final IllegalArgumentException e) {
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG) {
                 LOG.debug("JavaMail API failed to load part's headers. Using own routine.", e);
             }
             final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(DEFAULT_MESSAGE_SIZE);
@@ -1712,7 +1750,7 @@ public final class MIMEMessageConverter {
      * Gets the headers denoted by specified header name and decodes its value to a unicode string if necessary.
      * 
      * <pre>
-     * &quot;=?UTF-8?Q?=C3=BCber?=&quot;    is decoded to    &quot;&amp;uumlber&quot;
+     * &quot;=?UTF-8?Q?=C3=BCber?=&quot;    is decoded to    &quot;&#252;ber&quot;
      * </pre>
      * 
      * @param name The header name
@@ -1769,7 +1807,7 @@ public final class MIMEMessageConverter {
         try {
             return QuotedInternetAddress.parseHeader(addresses, true);
         } catch (final AddressException e) {
-            if (LOG.isDebugEnabled()) {
+            if (DEBUG) {
                 LOG.debug(
                     new StringBuilder(128).append("Internet addresses could not be properly parsed: \"").append(e.getMessage()).append(
                         "\". Using plain addresses' string representation instead.").toString(),
@@ -1809,7 +1847,7 @@ public final class MIMEMessageConverter {
             try {
                 priority = Integer.parseInt(tmp[0]);
             } catch (final NumberFormatException nfe) {
-                if (LOG.isDebugEnabled()) {
+                if (DEBUG) {
                     LOG.debug("Assuming priority NORMAL due to strange X-Priority header: " + priorityStr);
                 }
                 priority = MailMessage.PRIORITY_NORMAL;
