@@ -271,7 +271,7 @@ public class MIMEMessageFiller {
                 final ContactInterface contactInterface = ServerServiceRegistry.getInstance().getService(
                     ContactInterfaceDiscoveryService.class).newContactInterface(FolderObject.SYSTEM_LDAP_FOLDER_ID, session);
 
-                final Contact c = contactInterface.getUserById(ctx.getMailadmin());
+                final Contact c = contactInterface.getUserById(ctx.getMailadmin(), false);
                 if (null != c && c.getCompany() != null && c.getCompany().length() > 0) {
                     final String encoded = MimeUtility.fold(14, MimeUtility.encodeText(
                         c.getCompany(),
@@ -312,9 +312,10 @@ public class MIMEMessageFiller {
          */
         if (mail.containsFrom()) {
             InternetAddress sender = null;
-            if (usm.getSendAddr() != null && usm.getSendAddr().length() > 0) {
+            final String sendAddr = usm.getSendAddr();
+            if (sendAddr != null && sendAddr.length() > 0) {
                 try {
-                    sender = new QuotedInternetAddress(usm.getSendAddr(), true);
+                    sender = new QuotedInternetAddress(sendAddr, true);
                 } catch (final AddressException e) {
                     LOG.error("Default send address cannot be parsed", e);
                 }
@@ -604,14 +605,14 @@ public class MIMEMessageFiller {
         final boolean sendMultipartAlternative;
         if (mail.isDraft()) {
             sendMultipartAlternative = false;
-            if (mail.getContentType().isMimeType(MIMETypes.MIME_MULTIPART_ALTERNATIVE)) {
+            if (mail.getContentType().startsWith(MIMETypes.MIME_MULTIPART_ALTERNATIVE)) {
                 /*
                  * Allow only HTML if a draft message should be "sent"
                  */
                 mail.setContentType(MIMETypes.MIME_TEXT_HTML);
             }
         } else {
-            sendMultipartAlternative = mail.getContentType().isMimeType(MIMETypes.MIME_MULTIPART_ALTERNATIVE);
+            sendMultipartAlternative = mail.getContentType().startsWith(MIMETypes.MIME_MULTIPART_ALTERNATIVE);
         }
         /*
          * HTML content with embedded images
@@ -727,12 +728,12 @@ public class MIMEMessageFiller {
                     if (fileName != null && !ct.containsNameParameter()) {
                         ct.setNameParameter(fileName);
                     }
-                    vcardPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, ct.toString()));
+                    vcardPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(ct.toString()));
                     vcardPart.setHeader(MessageHeaders.HDR_MIME_VERSION, VERSION_1_0);
                     if (fileName != null) {
                         final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
                         cd.setFilenameParameter(fileName);
-                        vcardPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, cd.toString()));
+                        vcardPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(cd.toString()));
                     }
                     /*
                      * Append body part
@@ -803,12 +804,12 @@ public class MIMEMessageFiller {
                 }
                 mimeMessage.setContent(mailText, mail.getContentType().toString());
                 mimeMessage.setHeader(MessageHeaders.HDR_MIME_VERSION, VERSION_1_0);
-                mimeMessage.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, mail.getContentType().toString()));
+                mimeMessage.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(mail.getContentType().toString()));
             } else {
                 final MimeBodyPart msgBodyPart = new MimeBodyPart();
                 msgBodyPart.setContent(mail.getContent(), mail.getContentType().toString());
                 msgBodyPart.setHeader(MessageHeaders.HDR_MIME_VERSION, VERSION_1_0);
-                msgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, mail.getContentType().toString()));
+                msgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(mail.getContentType().toString()));
                 primaryMultipart.addBodyPart(msgBodyPart);
             }
         } else {
@@ -826,7 +827,7 @@ public class MIMEMessageFiller {
             } else {
                 final ContentDisposition contentDisposition = new ContentDisposition(disposition);
                 contentDisposition.setDisposition(Part.INLINE);
-                msgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, contentDisposition.toString()));
+                msgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(contentDisposition.toString()));
             }
             mp.addBodyPart(msgBodyPart);
             addMessageBodyPart(mp, mail, true);
@@ -1004,7 +1005,7 @@ public class MIMEMessageFiller {
     }
 
     protected final void addMessageBodyPart(final Multipart mp, final MailPart part, final boolean inline) throws MessagingException, MailException, IOException {
-        if (part.getContentType().isMimeType(MIMETypes.MIME_MESSAGE_RFC822)) {
+        if (part.getContentType().startsWith(MIMETypes.MIME_MESSAGE_RFC822)) {
             // TODO: Works correctly?
             final StringBuilder sb = new StringBuilder(32);
             final ByteArrayOutputStream out = new UnsynchronizedByteArrayOutputStream(BUF_SIZE);
@@ -1017,7 +1018,7 @@ public class MIMEMessageFiller {
          */
         final String fileName = part.getFileName();
         final ContentType ct = part.getContentType();
-        if (ct.isMimeType(MIMETypes.MIME_APPL_OCTET) && fileName != null) {
+        if (ct.startsWith(MIMETypes.MIME_APPL_OCTET) && fileName != null) {
             /*
              * Try to determine MIME type
              */
@@ -1031,7 +1032,7 @@ public class MIMEMessageFiller {
         if (fileName != null && !ct.containsNameParameter()) {
             ct.setNameParameter(fileName);
         }
-        messageBodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, ct.toString()));
+        messageBodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(ct.toString()));
         if (!inline) {
             /*
              * Force base64 encoding to keep data as it is
@@ -1052,7 +1053,7 @@ public class MIMEMessageFiller {
         if (fileName != null && !cd.containsFilenameParameter()) {
             cd.setFilenameParameter(fileName);
         }
-        messageBodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, cd.toString()));
+        messageBodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(cd.toString()));
         /*
          * Content-ID
          */
@@ -1120,7 +1121,7 @@ public class MIMEMessageFiller {
         if (null != filename) {
             ct.setNameParameter(filename);
         }
-        origMsgPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, ct.toString()));
+        origMsgPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(ct.toString()));
         /*
          * Set content disposition
          */
@@ -1135,7 +1136,7 @@ public class MIMEMessageFiller {
         if (null != filename && !cd.containsFilenameParameter()) {
             cd.setFilenameParameter(filename);
         }
-        origMsgPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, cd.toString()));
+        origMsgPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(cd.toString()));
         mp.addBodyPart(origMsgPart);
     }
 
@@ -1358,12 +1359,12 @@ public class MIMEMessageFiller {
             if (fileName != null) {
                 contentDisposition.setFilenameParameter(fileName);
             }
-            imgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, contentDisposition.toString()));
+            imgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(contentDisposition.toString()));
             final ContentType ct = new ContentType(imageProvider.getContentType());
             if (fileName != null && !ct.containsNameParameter()) {
                 ct.setNameParameter(fileName);
             }
-            imgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, ct.toString()));
+            imgBodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(ct.toString()));
             mp.addBodyPart(imgBodyPart);
         }
         return cid;
