@@ -49,7 +49,6 @@
 
 package com.openexchange.mail.mime.processing;
 
-import static com.openexchange.mail.mime.utils.MIMEMessageUtility.fold;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.InputStream;
@@ -204,9 +203,8 @@ public final class MimeForward {
              * New MIME message with a dummy session
              */
             final Context ctx = ContextStorage.getStorageContext(session.getContextId());
-            final UserSettingMail usm = userSettingMail == null ? UserSettingMailStorage.getInstance().getUserSettingMail(
-                session.getUserId(),
-                ctx) : userSettingMail;
+            final UserSettingMail usm =
+                userSettingMail == null ? UserSettingMailStorage.getInstance().getUserSettingMail(session.getUserId(), ctx) : userSettingMail;
             final MimeMessage forwardMsg = new MimeMessage(MIMEDefaultSession.getDefaultSession());
             {
                 /*
@@ -218,13 +216,14 @@ public final class MimeForward {
                     forwardMsg.setSubject(subjectPrefix, MailProperties.getInstance().getDefaultMimeCharset());
                 } else {
                     origSubject = MIMEMessageUtility.unfold(origSubject);
-                    final String subject = MIMEMessageUtility.decodeMultiEncodedHeader(origSubject.regionMatches(
-                        true,
-                        0,
-                        subjectPrefix,
-                        0,
-                        subjectPrefix.length()) ? origSubject : new StringBuilder(subjectPrefix.length() + origSubject.length()).append(
-                        subjectPrefix).append(origSubject).toString());
+                    final String subject =
+                        MIMEMessageUtility.decodeMultiEncodedHeader(origSubject.regionMatches(
+                            true,
+                            0,
+                            subjectPrefix,
+                            0,
+                            subjectPrefix.length()) ? origSubject : new StringBuilder(subjectPrefix.length() + origSubject.length()).append(
+                            subjectPrefix).append(origSubject).toString());
                     forwardMsg.setSubject(subject, MailProperties.getInstance().getDefaultMimeCharset());
                 }
             }
@@ -253,6 +252,12 @@ public final class MimeForward {
         }
     }
 
+    private static final String MULTIPART = "multipart/";
+
+    private static final String TEXT = "text/";
+
+    private static final String TEXT_HTM = "text/htm";
+
     private static MailMessage asInlineForward(final MailMessage originalMsg, final Session session, final Context ctx, final UserSettingMail usm, final MimeMessage forwardMsg) throws MailException, MessagingException, IOException {
         /*
          * Check for message reference
@@ -260,7 +265,7 @@ public final class MimeForward {
         final MailPath msgref = originalMsg.getMailPath();
         final ContentType originalContentType = originalMsg.getContentType();
         final MailMessage forwardMail;
-        if (originalContentType.isMimeType(MIMETypes.MIME_MULTIPART_ALL)) {
+        if (originalContentType.startsWith(MULTIPART)) {
             final Multipart multipart = new MimeMultipart();
             {
                 /*
@@ -283,11 +288,11 @@ public final class MimeForward {
                         firstSeenText == null ? "" : firstSeenText,
                         UserStorage.getStorageUser(session.getUserId(), ctx).getLocale(),
                         originalMsg,
-                        contentType.isMimeType(MIMETypes.MIME_TEXT_HTM_ALL)),
+                        contentType.startsWith(TEXT_HTM)),
                     contentType.getCharsetParameter(),
                     contentType.getSubType());
                 textPart.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
-                textPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, contentType.toString()));
+                textPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(contentType.toString()));
                 multipart.addBodyPart(textPart);
                 forwardMsg.setContent(multipart);
                 forwardMsg.saveChanges();
@@ -304,7 +309,7 @@ public final class MimeForward {
                 compositeMail.addAdditionalParts(mailPart);
             }
             forwardMail = compositeMail;
-        } else if (originalContentType.isMimeType(MIMETypes.MIME_TEXT_ALL)) {
+        } else if (originalContentType.startsWith(TEXT)) {
             /*
              * Original message is a simple text mail: Add message body prefixed with forward text
              */
@@ -315,16 +320,13 @@ public final class MimeForward {
                 }
             }
             final String content = MimeProcessingUtility.readContent(originalMsg, originalContentType.getCharsetParameter());
-            forwardMsg.setText(
-                generateForwardText(
-                    content == null ? "" : content,
-                    UserStorage.getStorageUser(session.getUserId(), ctx).getLocale(),
-                    originalMsg,
-                    originalContentType.isMimeType(MIMETypes.MIME_TEXT_HTM_ALL)),
-                originalContentType.getCharsetParameter(),
-                originalContentType.getSubType());
+            forwardMsg.setText(generateForwardText(
+                content == null ? "" : content,
+                UserStorage.getStorageUser(session.getUserId(), ctx).getLocale(),
+                originalMsg,
+                originalContentType.startsWith(TEXT_HTM)), originalContentType.getCharsetParameter(), originalContentType.getSubType());
             forwardMsg.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
-            forwardMsg.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.fold(14, originalContentType.toString()));
+            forwardMsg.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(originalContentType.toString()));
             forwardMsg.saveChanges();
             forwardMail = MIMEMessageConverter.convertMessage(forwardMsg);
         } else {
@@ -345,7 +347,7 @@ public final class MimeForward {
                     originalMsg,
                     false), MailProperties.getInstance().getDefaultMimeCharset(), "plain");
                 textPart.setHeader(MessageHeaders.HDR_MIME_VERSION, "1.0");
-                textPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, fold(14, contentType.toString()));
+                textPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, MIMEMessageUtility.foldContentType(contentType.toString()));
                 multipart.addBodyPart(textPart);
                 forwardMsg.setContent(multipart);
                 forwardMsg.saveChanges();
@@ -423,9 +425,10 @@ public final class MimeForward {
             } else {
                 final ByteArrayOutputStream tmp = new UnsynchronizedByteArrayOutputStream((int) originalMsg.getSize());
                 originalMsg.writeTo(tmp);
-                nested = MIMEMessageConverter.convertMessage(new MimeMessage(
-                    MIMEDefaultSession.getDefaultSession(),
-                    new UnsynchronizedByteArrayInputStream(tmp.toByteArray())));
+                nested =
+                    MIMEMessageConverter.convertMessage(new MimeMessage(
+                        MIMEDefaultSession.getDefaultSession(),
+                        new UnsynchronizedByteArrayInputStream(tmp.toByteArray())));
             }
             nested.setMsgref(originalMsg.getMailPath());
             compositeMail.addAdditionalParts(new NestedMessageMailPart(nested));
@@ -447,19 +450,19 @@ public final class MimeForward {
         final ContentType contentType = multipartPart.getContentType();
         final int count = multipartPart.getEnclosedCount();
         final ContentType partContentType = new ContentType();
-        if ((contentType.isMimeType(MIMETypes.MIME_MULTIPART_ALTERNATIVE) || contentType.isMimeType(MIMETypes.MIME_MULTIPART_RELATED)) && usm.isDisplayHtmlInlineContent() && count >= 2) {
+        if ((contentType.startsWith(MIMETypes.MIME_MULTIPART_ALTERNATIVE) || contentType.startsWith(MIMETypes.MIME_MULTIPART_RELATED)) && usm.isDisplayHtmlInlineContent() && count >= 2) {
             /*
              * Get html content
              */
             for (int i = 0; i < count; i++) {
                 final MailPart part = multipartPart.getEnclosedMailPart(i);
                 partContentType.setContentType(part.getContentType());
-                if (partContentType.isMimeType(MIMETypes.MIME_TEXT_HTM_ALL) && MimeProcessingUtility.isInline(part, partContentType)) {
+                if (partContentType.startsWith(TEXT_HTM) && MimeProcessingUtility.isInline(part, partContentType)) {
                     final String charset = MessageUtility.checkCharset(part, partContentType);
                     retvalContentType.setContentType(partContentType);
                     retvalContentType.setCharsetParameter(charset);
                     return MimeProcessingUtility.readContent(part, charset);
-                } else if (partContentType.isMimeType(MIMETypes.MIME_MULTIPART_ALL)) {
+                } else if (partContentType.startsWith(MULTIPART)) {
                     final String text = getFirstSeenText(part, retvalContentType, usm);
                     if (text != null) {
                         return text;
@@ -473,12 +476,12 @@ public final class MimeForward {
         for (int i = 0; i < count; i++) {
             final MailPart part = multipartPart.getEnclosedMailPart(i);
             partContentType.setContentType(part.getContentType());
-            if (partContentType.isMimeType(MIMETypes.MIME_TEXT_ALL) && MimeProcessingUtility.isInline(part, partContentType)) {
+            if (partContentType.startsWith(TEXT) && MimeProcessingUtility.isInline(part, partContentType)) {
                 final String charset = MessageUtility.checkCharset(part, partContentType);
                 retvalContentType.setContentType(partContentType);
                 retvalContentType.setCharsetParameter(charset);
                 return MimeProcessingUtility.handleInlineTextPart(part, retvalContentType, usm.isDisplayHtmlInlineContent());
-            } else if (partContentType.isMimeType(MIMETypes.MIME_MULTIPART_ALL)) {
+            } else if (partContentType.startsWith(MULTIPART)) {
                 final String text = getFirstSeenText(part, retvalContentType, usm);
                 if (text != null) {
                     return text;
@@ -520,24 +523,27 @@ public final class MimeForward {
         String forwardPrefix = strHelper.getString(MailStrings.FORWARD_PREFIX);
         {
             final InternetAddress[] from = msg.getFrom();
-            forwardPrefix = PATTERN_FROM.matcher(forwardPrefix).replaceFirst(
-                from == null || from.length == 0 ? "" : from[0].toUnicodeString());
+            forwardPrefix =
+                PATTERN_FROM.matcher(forwardPrefix).replaceFirst(from == null || from.length == 0 ? "" : from[0].toUnicodeString());
         }
         {
             final InternetAddress[] to = msg.getTo();
-            forwardPrefix = PATTERN_TO.matcher(forwardPrefix).replaceFirst(
-                to == null || to.length == 0 ? "" : MimeProcessingUtility.addrs2String(to));
+            forwardPrefix =
+                PATTERN_TO.matcher(forwardPrefix).replaceFirst(to == null || to.length == 0 ? "" : MimeProcessingUtility.addrs2String(to));
         }
         {
             final InternetAddress[] cc = msg.getCc();
-            forwardPrefix = PATTERN_CCLINE.matcher(forwardPrefix).replaceFirst(
-                cc == null || cc.length == 0 ? "" : new StringBuilder(64).append("\nCc: ").append(MimeProcessingUtility.addrs2String(cc)).toString());
+            forwardPrefix =
+                PATTERN_CCLINE.matcher(forwardPrefix).replaceFirst(
+                    cc == null || cc.length == 0 ? "" : new StringBuilder(64).append("\nCc: ").append(
+                        MimeProcessingUtility.addrs2String(cc)).toString());
         }
         {
             final Date date = msg.getSentDate();
             try {
-                forwardPrefix = PATTERN_DATE.matcher(forwardPrefix).replaceFirst(
-                    date == null ? "" : DateFormat.getDateInstance(DateFormat.LONG, locale).format(date));
+                forwardPrefix =
+                    PATTERN_DATE.matcher(forwardPrefix).replaceFirst(
+                        date == null ? "" : DateFormat.getDateInstance(DateFormat.LONG, locale).format(date));
             } catch (final Exception t) {
                 if (LOG.isWarnEnabled()) {
                     LOG.warn(t.getMessage(), t);
@@ -545,8 +551,9 @@ public final class MimeForward {
                 forwardPrefix = PATTERN_DATE.matcher(forwardPrefix).replaceFirst("");
             }
             try {
-                forwardPrefix = PATTERN_TIME.matcher(forwardPrefix).replaceFirst(
-                    date == null ? "" : DateFormat.getTimeInstance(DateFormat.SHORT, locale).format(date));
+                forwardPrefix =
+                    PATTERN_TIME.matcher(forwardPrefix).replaceFirst(
+                        date == null ? "" : DateFormat.getTimeInstance(DateFormat.SHORT, locale).format(date));
             } catch (final Exception t) {
                 if (LOG.isWarnEnabled()) {
                     LOG.warn(t.getMessage(), t);
@@ -557,8 +564,8 @@ public final class MimeForward {
         }
         {
             final String decodedSubject = MIMEMessageUtility.decodeMultiEncodedHeader(msg.getSubject());
-            forwardPrefix = PATTERN_SUBJECT.matcher(forwardPrefix).replaceFirst(
-                decodedSubject == null ? "" : Matcher.quoteReplacement(decodedSubject));
+            forwardPrefix =
+                PATTERN_SUBJECT.matcher(forwardPrefix).replaceFirst(decodedSubject == null ? "" : Matcher.quoteReplacement(decodedSubject));
         }
         if (html) {
             forwardPrefix = HTMLProcessing.htmlFormat(forwardPrefix);
