@@ -59,7 +59,6 @@ import java.util.HashSet;
 import java.util.List;
 import java.util.Locale;
 import java.util.Set;
-import java.util.TimeZone;
 import java.util.concurrent.Callable;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.concurrent.ConcurrentMap;
@@ -76,6 +75,9 @@ import javax.mail.internet.InternetAddress;
 import javax.mail.internet.MailDateFormat;
 import javax.mail.internet.MimeUtility;
 import javax.mail.internet.ParseException;
+import org.apache.commons.codec.DecoderException;
+import org.apache.commons.codec.binary.Base64;
+import org.apache.commons.codec.net.QuotedPrintableCodec;
 import com.openexchange.filemanagement.ManagedFileManagement;
 import com.openexchange.groupware.ldap.User;
 import com.openexchange.groupware.ldap.UserStorage;
@@ -91,9 +93,12 @@ import com.openexchange.mail.mime.MIMETypes;
 import com.openexchange.mail.mime.MessageHeaders;
 import com.openexchange.mail.mime.PlainTextAddress;
 import com.openexchange.mail.mime.QuotedInternetAddress;
+import com.openexchange.mail.utils.CharsetDetector;
 import com.openexchange.server.services.ServerServiceRegistry;
 import com.openexchange.session.Session;
+import com.openexchange.tools.TimeZoneUtils;
 import com.openexchange.tools.session.ServerSession;
+import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 import com.sun.mail.imap.protocol.BODYSTRUCTURE;
 
@@ -181,7 +186,7 @@ public final class MIMEMessageUtility {
 
                 public MailDateFormat call() throws Exception {
                     final MailDateFormat mdf = new MailDateFormat();
-                    mdf.setTimeZone(TimeZone.getTimeZone(timeZoneId));
+                    mdf.setTimeZone(TimeZoneUtils.getTimeZone(timeZoneId));
                     return mdf;
                 }
             });
@@ -232,13 +237,13 @@ public final class MIMEMessageUtility {
         return isWhitespace;
     }
 
-    private static final Pattern PATTERN_EMBD_IMG = Pattern.compile(
-        "(<img[^>]+src=\"?cid:)([^\"]+)(\"?[^>]*/?>)",
-        Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
+    private static final Pattern PATTERN_EMBD_IMG =
+        Pattern.compile("(<img[^>]+src=\"?cid:)([^\"]+)(\"?[^>]*/?>)", Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
 
-    private static final Pattern PATTERN_EMBD_IMG_ALT = Pattern.compile(
-        "(<img[^>]+src=\"?)([0-9a-z&&[^.\\s>\"]]+\\.[0-9a-z&&[^.\\s>\"]]+)(\"?[^>]*/?>)",
-        Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
+    private static final Pattern PATTERN_EMBD_IMG_ALT =
+        Pattern.compile(
+            "(<img[^>]+src=\"?)([0-9a-z&&[^.\\s>\"]]+\\.[0-9a-z&&[^.\\s>\"]]+)(\"?[^>]*/?>)",
+            Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
 
     /**
      * Detects if given HTML content contains inlined images
@@ -252,7 +257,7 @@ public final class MIMEMessageUtility {
      * @param htmlContent The HTML content
      * @return <code>true</code> if given HTML content contains inlined images; otherwise <code>false</code>
      */
-    public static boolean hasEmbeddedImages(final String htmlContent) {
+    public static boolean hasEmbeddedImages(final CharSequence htmlContent) {
         return PATTERN_EMBD_IMG.matcher(htmlContent).find() || PATTERN_EMBD_IMG_ALT.matcher(htmlContent).find();
     }
 
@@ -262,7 +267,7 @@ public final class MIMEMessageUtility {
      * @param htmlContent The HTML content
      * @return an instance of <code>{@link List}</code> containing all occurring content IDs
      */
-    public static List<String> getContentIDs(final String htmlContent) {
+    public static List<String> getContentIDs(final CharSequence htmlContent) {
         final List<String> retval = new ArrayList<String>();
         Matcher m = PATTERN_EMBD_IMG.matcher(htmlContent);
         while (m.find()) {
@@ -285,16 +290,19 @@ public final class MIMEMessageUtility {
      */
     public static boolean equalsCID(final String contentId1, final String contentId2) {
         if (null != contentId1 && null != contentId2) {
-            final String cid1 = contentId1.length() > 0 && contentId1.charAt(0) == '<' ? contentId1.substring(1, contentId1.length() - 1) : contentId1;
-            final String cid2 = contentId2.length() > 0 && contentId2.charAt(0) == '<' ? contentId2.substring(1, contentId2.length() - 1) : contentId2;
+            final String cid1 =
+                contentId1.length() > 0 && contentId1.charAt(0) == '<' ? contentId1.substring(1, contentId1.length() - 1) : contentId1;
+            final String cid2 =
+                contentId2.length() > 0 && contentId2.charAt(0) == '<' ? contentId2.substring(1, contentId2.length() - 1) : contentId2;
             return cid1.equalsIgnoreCase(cid2);
         }
         return false;
     }
 
-    public static final Pattern PATTERN_REF_IMG = Pattern.compile(
-        "(<img[^>]*?)(src=\")([^\"]+?)((?:uid=|id=))([^\"&]+)(?:(&[^\"]+\")|(\"))([^>]*/?>)",
-        Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
+    public static final Pattern PATTERN_REF_IMG =
+        Pattern.compile(
+            "(<img[^>]*?)(src=\")([^\"]+?)((?:uid=|id=))([^\"&]+)(?:(&[^\"]+\")|(\"))([^>]*/?>)",
+            Pattern.CASE_INSENSITIVE | Pattern.DOTALL);
 
     /**
      * Detects if given HTML content contains references to local image files
@@ -313,7 +321,7 @@ public final class MIMEMessageUtility {
      * @param session The user session
      * @return <code>true</code> if given HTML content contains references to local image files; otherwise <code>false</code>
      */
-    public static boolean hasReferencedLocalImages(final String htmlContent, final Session session) {
+    public static boolean hasReferencedLocalImages(final CharSequence htmlContent, final Session session) {
         final Matcher m = PATTERN_REF_IMG.matcher(htmlContent);
         if (m.find()) {
             final ManagedFileManagement mfm = ServerServiceRegistry.getInstance().getService(ManagedFileManagement.class);
@@ -477,6 +485,34 @@ public final class MIMEMessageUtility {
         return found;
     }
 
+    /**
+     * The max. length of a RFC 2047 style encoded word.
+     */
+    private static final int ENCODED_WORD_LEN = 75;
+
+    /**
+     * Decodes a string header obtained from ENVELOPE fetch item.
+     * 
+     * @param headerValue The header value
+     * @return The decoded header value
+     */
+    public static String decodeEnvelopeHeader(final String headerValue) {
+        final int length = headerValue.length();
+        /*
+         * Passes possibly encoded-word is greater than 75 characters and contains no CR?LF
+         */
+        if ((length > ENCODED_WORD_LEN) && (headerValue.indexOf('\r') < 0) && (headerValue.indexOf('\n') < 0)) {
+            final StringBuilder sb = new StringBuilder(length).append(headerValue);
+            final String pattern = "?= =?";
+            int i;
+            while ((i = sb.indexOf(pattern)) >= 0) {
+                sb.deleteCharAt(i + 2);
+            }
+            return decodeMultiEncodedHeader0(sb.toString(), false);
+        }
+        return decodeMultiEncodedHeader0(headerValue, true);
+    }
+
     private static final Pattern ENC_PATTERN = Pattern.compile("=\\?(\\S+?)\\?(\\S+?)\\?(.+?)\\?=");
 
     /**
@@ -490,10 +526,14 @@ public final class MIMEMessageUtility {
      * @return The possibly decoded header value
      */
     public static String decodeMultiEncodedHeader(final String headerValue) {
+        return decodeMultiEncodedHeader0(headerValue, true);
+    }
+
+    private static String decodeMultiEncodedHeader0(final String headerValue, final boolean unfold) {
         if (headerValue == null) {
             return null;
         }
-        final String hdrVal = MIMEMessageUtility.unfold(headerValue);
+        final String hdrVal = unfold ? MIMEMessageUtility.unfold(headerValue) : headerValue;
         /*
          * Whether the sequence "=?" exists at all
          */
@@ -510,8 +550,10 @@ public final class MIMEMessageUtility {
                     sb.append(MimeUtility.decodeWord(m.group()));
                     lastMatch = m.end();
                 } catch (final UnsupportedEncodingException e) {
-                    LOG.error("Unsupported character-encoding in encoded-word: " + m.group(), e);
-                    sb.append(m.group());
+                    if (LOG.isDebugEnabled()) {
+                        LOG.debug("Unsupported character-encoding in encoded-word: " + m.group(), e);
+                    }
+                    sb.append(handleUnsupportedEncoding(m));
                     lastMatch = m.end();
                 } catch (final ParseException e) {
                     return decodeMultiEncodedHeaderSafe(headerValue);
@@ -523,6 +565,50 @@ public final class MIMEMessageUtility {
         return hdrVal;
     }
 
+    private static String handleUnsupportedEncoding(final Matcher m) {
+        final String asciiText = m.group(3);
+        final String detectedCharset;
+        final byte[] rawBytes;
+        try {
+            final String transferEncoding = m.group(2);
+            if ("Q".equalsIgnoreCase(transferEncoding)) {
+                try {
+                    rawBytes = QuotedPrintableCodec.decodeQuotedPrintable(asciiText.getBytes("US-ASCII"));
+                } catch (final DecoderException e) {
+                    /*
+                     * Invalid quoted-printable
+                     */
+                    LOG.warn("Cannot decode quoted-printable: " + e.getMessage(), e);
+                    return asciiText;
+                }
+            } else if ("B".equalsIgnoreCase(transferEncoding)) {
+                rawBytes = Base64.decodeBase64(asciiText.getBytes("US-ASCII"));
+            } else {
+                /*
+                 * Unknown transfer-encoding; just return current match
+                 */
+                LOG.warn("Unknown transfer-encoding: " + transferEncoding);
+                return asciiText;
+            }
+            detectedCharset = CharsetDetector.detectCharset(new UnsynchronizedByteArrayInputStream(rawBytes));
+        } catch (final UnsupportedEncodingException ignore) {
+            // Cannot occur
+            if (LOG.isTraceEnabled()) {
+                LOG.trace(ignore.getMessage(), ignore);
+            }
+            return asciiText;
+        }
+        try {
+            return new String(rawBytes, detectedCharset);
+        } catch (final UnsupportedEncodingException e) {
+            /*
+             * Even detected charset is unknown... giving up
+             */
+            LOG.warn("Unknown character-encoding: " + detectedCharset);
+            return asciiText;
+        }
+    }
+
     /**
      * Decodes a multi-mime-encoded header value using the algorithm specified in RFC 2047, Section 6.1 in a safe manner.
      * 
@@ -689,10 +775,13 @@ public final class MIMEMessageUtility {
      * 
      * @param addresslist - comma separated address strings
      * @param strict - <code>true</code> to enforce RFC822 syntax; otherwise <code>false</code>
-     * @return array of <code>InternetAddress</code> objects
+     * @return An array of <code>InternetAddress</code> objects
      * @throws AddressException - if parsing fails
      */
     public static InternetAddress[] parseAddressList(final String addresslist, final boolean strict) throws AddressException {
+        if (null == addresslist) {
+            return new InternetAddress[0];
+        }
         final String al = replaceWithComma(unfold(addresslist));
         InternetAddress[] addrs = null;
         try {
@@ -789,7 +878,8 @@ public final class MIMEMessageUtility {
         boolean needQuoting = false;
         for (int i = 0; !needQuoting && i < len; i++) {
             final char c = chars[i];
-            needQuoting = (c == '"' || c == '\\' || (c < 040 && c != '\r' && c != '\n' && c != '\t') || c >= 0177 || RFC822.indexOf(c) >= 0);
+            needQuoting =
+                (c == '"' || c == '\\' || (c < 040 && c != '\r' && c != '\n' && c != '\t') || c >= 0177 || RFC822.indexOf(c) >= 0);
         }
         try {
             if (!needQuoting) {
@@ -804,6 +894,30 @@ public final class MIMEMessageUtility {
         }
     }
 
+    private static final int USED_CT = 14;
+
+    /**
+     * Folds specified <code>Content-Type</code> value.
+     * 
+     * @param contentDisposition The <code>Content-Type</code> value
+     * @return The folded <code>Content-Type</code> value
+     */
+    public static String foldContentType(final String contentType) {
+        return fold(USED_CT, contentType);
+    }
+
+    private static final int USED_CD = 21;
+
+    /**
+     * Folds specified <code>Content-Disposition</code> value.
+     * 
+     * @param contentDisposition The <code>Content-Disposition</code> value
+     * @return The folded <code>Content-Disposition</code> value
+     */
+    public static String foldContentDisposition(final String contentDisposition) {
+        return fold(USED_CD, contentDisposition);
+    }
+
     /**
      * Folds a string at linear whitespace so that each line is no longer than 76 characters, if possible. If there are more than 76
      * non-whitespace characters consecutively, the string is folded at the first whitespace after that sequence. The parameter
@@ -889,76 +1003,79 @@ public final class MIMEMessageUtility {
         }
         StringBuilder sb = null;
         int i;
-        /*-
-         * Check folded encoded-words as per RFC 2047:
-         * 
-         * An 'encoded-word' may not be more than 75 characters long, including
-         * 'charset', 'encoding', 'encoded-text', and delimiters.  If it is
-         * desirable to encode more text than will fit in an 'encoded-word' of
-         * 75 characters, multiple 'encoded-word's (separated by CRLF SPACE) may
-         * be used.
-         * 
-         * In this case the SPACE character is not part of the header and should
-         * be discarded.
-         */
-        String s;
-        if (headerLine.indexOf("=?") == -1) {
-            s = headerLine;
-        } else {
-            s = unfoldEncodedWords(headerLine);
-        }
-        while ((i = s.indexOf('\r')) >= 0 || (i = s.indexOf('\n')) >= 0) {
-            final int start = i;
-            final int len = s.length();
-            i++; // skip CR or NL
-            if ((i < len) && (s.charAt(i - 1) == '\r') && (s.charAt(i) == '\n')) {
-                i++; // skip LF
+        if ((i = headerLine.indexOf('\r')) >= 0 || (i = headerLine.indexOf('\n')) >= 0) {
+            /*-
+             * Check folded encoded-words as per RFC 2047:
+             * 
+             * An 'encoded-word' may not be more than 75 characters long, including
+             * 'charset', 'encoding', 'encoded-text', and delimiters.  If it is
+             * desirable to encode more text than will fit in an 'encoded-word' of
+             * 75 characters, multiple 'encoded-word's (separated by CRLF SPACE) may
+             * be used.
+             * 
+             * In this case the SPACE character is not part of the header and should
+             * be discarded.
+             */
+            String s;
+            if (headerLine.indexOf("=?") == -1) {
+                s = headerLine;
+            } else {
+                s = unfoldEncodedWords(headerLine);
+                if ((i = s.indexOf('\r')) < 0 && (i = s.indexOf('\n')) < 0) {
+                    return s;
+                }
             }
-            if (start == 0 || s.charAt(start - 1) != '\\') {
-                char c;
-                /*
-                 * If next line starts with whitespace, skip all of it
-                 */
-                if ((i < len) && (((c = s.charAt(i)) == ' ') || (c == '\t'))) {
-                    i++; // skip whitespace
-                    while ((i < len) && (((c = s.charAt(i)) == ' ') || (c == '\t'))) {
-                        i++;
+            do {
+                final int start = i;
+                final int len = s.length();
+                i++; // skip CR or NL
+                if ((i < len) && (s.charAt(i - 1) == '\r') && (s.charAt(i) == '\n')) {
+                    i++; // skip LF
+                }
+                if (start == 0 || s.charAt(start - 1) != '\\') {
+                    char c;
+                    /*
+                     * If next line starts with whitespace, skip all of it
+                     */
+                    if ((i < len) && (((c = s.charAt(i)) == ' ') || (c == '\t'))) {
+                        i++; // skip whitespace
+                        while ((i < len) && (((c = s.charAt(i)) == ' ') || (c == '\t'))) {
+                            i++;
+                        }
+                        if (sb == null) {
+                            sb = new StringBuilder(s.length());
+                        }
+                        if (start != 0) {
+                            sb.append(s.substring(0, start));
+                            sb.append(' ');
+                        }
+                        s = s.substring(i);
+                    } else {
+                        /*
+                         * It's not a continuation line, just leave it in
+                         */
+                        if (sb == null) {
+                            sb = new StringBuilder(s.length());
+                        }
+                        sb.append(s.substring(0, i));
+                        s = s.substring(i);
                     }
-                    if (sb == null) {
-                        sb = new StringBuilder(s.length());
-                    }
-                    if (start != 0) {
-                        sb.append(s.substring(0, start));
-                        sb.append(' ');
-                    }
-                    s = s.substring(i);
                 } else {
                     /*
-                     * It's not a continuation line, just leave it in
+                     * There's a backslash at "start - 1", strip it out, but leave in the line break
                      */
                     if (sb == null) {
                         sb = new StringBuilder(s.length());
                     }
-                    sb.append(s.substring(0, i));
+                    sb.append(s.substring(0, start - 1));
+                    sb.append(s.substring(start, i));
                     s = s.substring(i);
                 }
-            } else {
-                /*
-                 * There's a backslash at "start - 1", strip it out, but leave in the line break
-                 */
-                if (sb == null) {
-                    sb = new StringBuilder(s.length());
-                }
-                sb.append(s.substring(0, start - 1));
-                sb.append(s.substring(start, i));
-                s = s.substring(i);
-            }
-        }
-        if (sb != null) {
+            } while ((i = s.indexOf('\r')) >= 0 || (i = s.indexOf('\n')) >= 0);
             sb.append(s);
             return sb.toString();
         }
-        return s;
+        return headerLine;
     }
 
     private static final Pattern PAT_ENC_WORDS = Pattern.compile("(\r?\n(?:\t| ))(=\\?\\S+?\\?\\S+?\\?.+?\\?=)");
