@@ -52,10 +52,11 @@ package com.openexchange.mail.parser;
 import static com.openexchange.mail.MailServletInterface.mailInterfaceMonitor;
 import java.io.ByteArrayOutputStream;
 import java.io.IOException;
-import java.io.UnsupportedEncodingException;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
+import java.util.NoSuchElementException;
+import java.util.Map.Entry;
 import javax.activation.DataHandler;
 import javax.activation.DataSource;
 import javax.mail.MessagingException;
@@ -73,6 +74,7 @@ import net.freeutils.tnef.mime.ContactHandler;
 import net.freeutils.tnef.mime.RawDataSource;
 import net.freeutils.tnef.mime.ReadReceiptHandler;
 import net.freeutils.tnef.mime.TNEFMime;
+import com.openexchange.i18n.LocaleTools;
 import com.openexchange.mail.MailException;
 import com.openexchange.mail.api.MailConfig;
 import com.openexchange.mail.config.MailProperties;
@@ -91,7 +93,6 @@ import com.openexchange.mail.mime.utils.MIMEMessageUtility;
 import com.openexchange.mail.utils.CharsetDetector;
 import com.openexchange.mail.utils.MessageUtility;
 import com.openexchange.mail.uuencode.UUEncodedMultiPart;
-import com.openexchange.tools.stream.UnsynchronizedByteArrayInputStream;
 import com.openexchange.tools.stream.UnsynchronizedByteArrayOutputStream;
 
 /**
@@ -104,8 +105,25 @@ public final class MailMessageParser {
 
     private static final org.apache.commons.logging.Log LOG = org.apache.commons.logging.LogFactory.getLog(MailMessageParser.class);
 
+    private static final boolean WARN_ENABLED = LOG.isWarnEnabled();
+
     private static final int BUF_SIZE = 8192;
 
+    private static final Iterator<Entry<String, String>> EMPTY_ITER = new Iterator<Entry<String, String>>() {
+
+        public boolean hasNext() {
+            return false;
+        }
+
+        public Entry<String, String> next() {
+            throw new NoSuchElementException("Iterator is empty");
+        }
+
+        public void remove() {
+            // Nothing to do
+        }
+    };
+
     private static interface InlineDetector {
 
         public boolean isInline(String disposition, String fileName);
@@ -233,17 +251,16 @@ public final class MailMessageParser {
          */
         final MailPart mailPart = MailConfig.usePartModifier() ? MailConfig.getPartModifier().modifyPart(mailPartArg) : mailPartArg;
         /*
-         * Set part infos
+         * Set part information
          */
         int partCount = partCountArg;
         final String disposition = mailPart.containsContentDisposition() ? mailPart.getContentDisposition().getDisposition() : null;
         final long size = mailPart.getSize();
-        final String filename = getFileName(
-            mailPart.getFileName(),
-            getSequenceId(prefix, partCount),
-            mailPart.getContentType().getBaseType());
-        final ContentType contentType = mailPart.containsContentType() ? mailPart.getContentType() : new ContentType(
-            MIMETypes.MIME_APPL_OCTET);
+        final ContentType contentType =
+            mailPart.containsContentType() ? mailPart.getContentType() : new ContentType(MIMETypes.MIME_APPL_OCTET);
+        final String lcct = LocaleTools.toLowerCase(contentType.getBaseType());
+        final String filename = getFileName(mailPart.getFileName(), getSequenceId(prefix, partCount), lcct);
+
         /*
          * Parse part dependent on its MIME type
          */
@@ -253,7 +270,7 @@ public final class MailMessageParser {
          * final boolean isInline = ((disposition == null
          *     || disposition.equalsIgnoreCase(Part.INLINE)) && mailPart.getFileName() == null);
          */
-        if (contentType.isMimeType(MIMETypes.MIME_TEXT_PLAIN) || contentType.isMimeType(MIMETypes.MIME_TEXT_ENRICHED) || contentType.isMimeType(MIMETypes.MIME_TEXT_RICHTEXT) || contentType.isMimeType(MIMETypes.MIME_TEXT_RTF)) {
+        if (isText(lcct)) {
             if (isInline) {
                 final String content = readContent(mailPart, contentType);
                 final UUEncodedMultiPart uuencodedMP = new UUEncodedMultiPart(content);
@@ -304,12 +321,12 @@ public final class MailMessageParser {
                 if (!mailPart.containsSequenceId()) {
                     mailPart.setSequenceId(getSequenceId(prefix, partCount));
                 }
-                if (!handler.handleAttachment(mailPart, false, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+                if (!handler.handleAttachment(mailPart, false, lcct, filename, mailPart.getSequenceId())) {
                     stop = true;
                     return;
                 }
             }
-        } else if (contentType.isMimeType(MIMETypes.MIME_TEXT_HTM_ALL)) {
+        } else if (isHtml(lcct)) {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(getSequenceId(prefix, partCount));
             }
@@ -319,17 +336,17 @@ public final class MailMessageParser {
                     return;
                 }
             } else {
-                if (!handler.handleAttachment(mailPart, false, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+                if (!handler.handleAttachment(mailPart, false, lcct, filename, mailPart.getSequenceId())) {
                     stop = true;
                     return;
                 }
             }
-        } else if (contentType.isMimeType(MIMETypes.MIME_MULTIPART_ALL)) {
+        } else if (isMultipart(lcct)) {
             final int count = mailPart.getEnclosedCount();
             if (count == -1) {
                 throw new MailException(MailException.Code.INVALID_MULTIPART_CONTENT);
             }
-            final String mpId = getSequenceId(prefix, partCount);
+            final String mpId = null == prefix && !multipartDetected ? "" : getSequenceId(prefix, partCount);
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(mpId);
             }
@@ -348,21 +365,15 @@ public final class MailMessageParser {
                 final MailPart enclosedContent = mailPart.getEnclosedMailPart(i);
                 parseMailContent(enclosedContent, handler, mpPrefix, i + 1);
             }
-        } else if (contentType.isMimeType(MIMETypes.MIME_IMAGE_ALL)) {
+        } else if (isImage(lcct)) {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(getSequenceId(prefix, partCount));
             }
-            if (!handler.handleImagePart(
-                mailPart,
-                mailPart.getContentId(),
-                contentType.getBaseType(),
-                isInline,
-                filename,
-                mailPart.getSequenceId())) {
+            if (!handler.handleImagePart(mailPart, mailPart.getContentId(), lcct, isInline, filename, mailPart.getSequenceId())) {
                 stop = true;
                 return;
             }
-        } else if (contentType.isMimeType(MIMETypes.MIME_MESSAGE_RFC822)) {
+        } else if (isMessage(lcct)) {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(getSequenceId(prefix, partCount));
             }
@@ -377,7 +388,7 @@ public final class MailMessageParser {
                     return;
                 }
             }
-        } else if (TNEFUtils.isTNEFMimeType(mailPart.getContentType().toString())) {
+        } else if (TNEFUtils.isTNEFMimeType(lcct)) {
             try {
                 /*
                  * Here go with TNEF encoded messages. Since TNEF library is based on JavaMail API we are forced to use JavaMail-specific
@@ -426,7 +437,7 @@ public final class MailMessageParser {
                     try {
                         mp = ReadReceiptHandler.convert(message);
                     } catch (final RuntimeException e) {
-                        if (LOG.isWarnEnabled()) {
+                        if (WARN_ENABLED) {
                             LOG.warn("Invalid TNEF read receipt", e);
                         }
                         return;
@@ -450,8 +461,9 @@ public final class MailMessageParser {
                 final Attr attrBody = Attr.findAttr(message.getAttributes(), Attr.attBody);
                 if (attrBody != null) {
                     final TNEFBodyPart bodyPart = new TNEFBodyPart();
-                    bodyPart.setText((String) attrBody.getValue());
-                    bodyPart.setSize(((String) attrBody.getValue()).length());
+                    final String value = (String) attrBody.getValue();
+                    bodyPart.setText(value);
+                    bodyPart.setSize(value.length());
                     parseMailContent(MIMEMessageConverter.convertPart(bodyPart), handler, prefix, partCount++);
                 }
                 final MAPIProps mapiProps = message.getMAPIProps();
@@ -465,12 +477,12 @@ public final class MailMessageParser {
                         final byte[] decompressedBytes = TNEFUtils.decompressRTF(ris.toByteArray());
                         final String contentTypeStr;
                         {
-                            final String charset = CharsetDetector.detectCharset(new UnsynchronizedByteArrayInputStream(decompressedBytes));
-                            contentTypeStr = new StringBuilder(MIMETypes.MIME_TEXT_RTF).append("; charset=").append(charset).toString();
+                            // final String charset = CharsetDetector.detectCharset(new
+                            // UnsynchronizedByteArrayInputStream(decompressedBytes));
+                            contentTypeStr = "application/rtf";
                         }
                         /*
                          * Set content through a data handler to avoid further exceptions raised by unavailable DCH (data content handler)
-                         * for MIME type "text/rtf" when set by setContent() method
                          */
                         bodyPart.setDataHandler(new DataHandler(new MessageDataSource(decompressedBytes, contentTypeStr)));
                         bodyPart.setHeader(MessageHeaders.HDR_CONTENT_TYPE, contentTypeStr);
@@ -515,7 +527,7 @@ public final class MailMessageParser {
                             if (attachFilename != null) {
                                 final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
                                 cd.setFilenameParameter(attachFilename);
-                                bodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, cd.toString()));
+                                bodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(cd.toString()));
                             }
                             os.reset();
                             attachment.writeTo(os);
@@ -525,9 +537,8 @@ public final class MailMessageParser {
                             /*
                              * Nested message
                              */
-                            final MimeMessage nestedMessage = TNEFMime.convert(
-                                MIMEDefaultSession.getDefaultSession(),
-                                attachment.getNestedMessage());
+                            final MimeMessage nestedMessage =
+                                TNEFMime.convert(MIMEDefaultSession.getDefaultSession(), attachment.getNestedMessage());
                             os.reset();
                             nestedMessage.writeTo(os);
                             bodyPart.setDataHandler(new DataHandler(new MessageDataSource(os.toByteArray(), MIMETypes.MIME_MESSAGE_RFC822)));
@@ -541,7 +552,7 @@ public final class MailMessageParser {
                         if (!mailPart.containsSequenceId()) {
                             mailPart.setSequenceId(getSequenceId(prefix, partCount));
                         }
-                        if (!handler.handleAttachment(mailPart, isInline, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+                        if (!handler.handleAttachment(mailPart, isInline, lcct, filename, mailPart.getSequenceId())) {
                             stop = true;
                             return;
                         }
@@ -563,20 +574,20 @@ public final class MailMessageParser {
                         if (attachFilename != null) {
                             final ContentDisposition cd = new ContentDisposition(Part.ATTACHMENT);
                             cd.setFilenameParameter(attachFilename);
-                            bodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.fold(21, cd.toString()));
+                            bodyPart.setHeader(MessageHeaders.HDR_CONTENT_DISPOSITION, MIMEMessageUtility.foldContentDisposition(cd.toString()));
                         }
                         bodyPart.setSize(messageClass.getLength());
                         parseMailContent(MIMEMessageConverter.convertPart(bodyPart), handler, prefix, partCount++);
                     }
                 }
             } catch (final IOException tnefExc) {
-                if (LOG.isWarnEnabled()) {
+                if (WARN_ENABLED) {
                     LOG.warn(tnefExc.getMessage(), tnefExc);
                 }
                 if (!mailPart.containsSequenceId()) {
                     mailPart.setSequenceId(getSequenceId(prefix, partCount));
                 }
-                if (!handler.handleAttachment(mailPart, isInline, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+                if (!handler.handleAttachment(mailPart, isInline, lcct, filename, mailPart.getSequenceId())) {
                     stop = true;
                     return;
                 }
@@ -587,16 +598,16 @@ public final class MailMessageParser {
                 if (!mailPart.containsSequenceId()) {
                     mailPart.setSequenceId(getSequenceId(prefix, partCount));
                 }
-                if (!handler.handleAttachment(mailPart, isInline, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+                if (!handler.handleAttachment(mailPart, isInline, lcct, filename, mailPart.getSequenceId())) {
                     stop = true;
                     return;
                 }
             }
-        } else if (contentType.isMimeType(MIMETypes.MIME_MESSAGE_DELIVERY_STATUS) || contentType.isMimeType(MIMETypes.MIME_MESSAGE_DISP_NOTIFICATION) || contentType.isMimeType(MIMETypes.MIME_TEXT_RFC822_HDRS) || contentType.isMimeType(MIMETypes.MIME_TEXT_ALL_CARD) || contentType.isMimeType(MIMETypes.MIME_TEXT_ALL_CALENDAR)) {
+        } else if (isSpecial(lcct)) {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(getSequenceId(prefix, partCount));
             }
-            if (!handler.handleSpecialPart(mailPart, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+            if (!handler.handleSpecialPart(mailPart, lcct, filename, mailPart.getSequenceId())) {
                 stop = true;
                 return;
             }
@@ -604,7 +615,7 @@ public final class MailMessageParser {
             if (!mailPart.containsSequenceId()) {
                 mailPart.setSequenceId(getSequenceId(prefix, partCount));
             }
-            if (!handler.handleAttachment(mailPart, isInline, contentType.getBaseType(), filename, mailPart.getSequenceId())) {
+            if (!handler.handleAttachment(mailPart, isInline, lcct, filename, mailPart.getSequenceId())) {
                 stop = true;
                 return;
             }
@@ -674,7 +685,8 @@ public final class MailMessageParser {
         /*
          * HEADERS
          */
-        handler.handleHeaders(mail.getHeadersSize(), mail.getHeadersIterator());
+        final int headersSize = mail.getHeadersSize();
+        handler.handleHeaders(headersSize, headersSize > 0 ? mail.getHeadersIterator() : EMPTY_ITER);
     }
 
     private static final String PREFIX = "Part_";
@@ -692,8 +704,7 @@ public final class MailMessageParser {
         String filename = rawFileName;
         if ((filename == null) || isEmptyString(filename)) {
             final List<String> exts = MIMEType2ExtMap.getFileExtensions(baseMimeType.toLowerCase(Locale.ENGLISH));
-            final StringBuilder sb = new StringBuilder(PREFIX.length() + sequenceId.length() + 5).append(PREFIX).append(sequenceId).append(
-                '.');
+            final StringBuilder sb = new StringBuilder(16).append(PREFIX).append(sequenceId).append('.');
             if (exts == null) {
                 sb.append("dat");
             } else {
@@ -753,7 +764,7 @@ public final class MailMessageParser {
         } catch (final java.io.CharConversionException e) {
             // Obviously charset was wrong or bogus implementation of character conversion
             final String fallback = "US-ASCII";
-            if (LOG.isWarnEnabled()) {
+            if (WARN_ENABLED) {
                 LOG.warn(new StringBuilder("Character conversion exception while reading content with charset \"").append(charset).append(
                     "\". Using fallback charset \"").append(fallback).append("\" instead."), e);
             }
@@ -766,21 +777,28 @@ public final class MailMessageParser {
         if (mailPart.containsHeader(MessageHeaders.HDR_CONTENT_TYPE)) {
             String cs = contentType.getCharsetParameter();
             if (!CharsetDetector.isValid(cs)) {
+                StringBuilder sb = null;
                 if (null != cs) {
-                    LOG.warn(
-                        "Illegal or unsupported encoding in a message detected and monitored: \"" + cs + '"',
-                        new UnsupportedEncodingException(cs));
+                    sb = new StringBuilder(64).append("Illegal or unsupported encoding: \"").append(cs).append("\".");
                     mailInterfaceMonitor.addUnsupportedEncodingExceptions(cs);
                 }
-                if (contentType.isMimeType(MIMETypes.MIME_TEXT_ALL)) {
+                if (contentType.startsWith(PRIMARY_TEXT)) {
                     cs = CharsetDetector.detectCharset(mailPart.getInputStream());
+                    if (WARN_ENABLED && null != sb) {
+                        sb.append(" Using auto-detected encoding: \"").append(cs).append('"');
+                        LOG.warn(sb.toString());
+                    }
                 } else {
                     cs = MailProperties.getInstance().getDefaultMimeCharset();
+                    if (WARN_ENABLED && null != sb) {
+                        sb.append(" Using fallback encoding: \"").append(cs).append('"');
+                        LOG.warn(sb.toString());
+                    }
                 }
             }
             charset = cs;
         } else {
-            if (contentType.isMimeType(MIMETypes.MIME_TEXT_ALL)) {
+            if (contentType.startsWith(PRIMARY_TEXT)) {
                 charset = CharsetDetector.detectCharset(mailPart.getInputStream());
             } else {
                 charset = MailProperties.getInstance().getDefaultMimeCharset();
@@ -789,4 +807,120 @@ public final class MailMessageParser {
         return charset;
     }
 
+    private static final String PRIMARY_TEXT = "text/";
+
+    private static final String[] SUB_TEXT = { "plain", "enriched", "richtext", "rtf" };
+
+    /**
+     * Checks if content type matches one of text content types:
+     * <ul>
+     * <li><code>text/plain</code></li>
+     * <li><code>text/enriched</code></li>
+     * <li><code>text/richtext</code></li>
+     * <li><code>text/rtf</code></li>
+     * </ul>
+     * 
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches text; otherwise <code>false</code>
+     */
+    private static boolean isText(final String contentType) {
+        if (contentType.startsWith(PRIMARY_TEXT, 0)) {
+            final int off = PRIMARY_TEXT.length();
+            for (final String subtype : SUB_TEXT) {
+                if (contentType.startsWith(subtype, off)) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
+    private static final String PRIMARY_HTML = "text/htm";
+
+    /**
+     * Checks if content type matches <code>text/htm*</code> content type.
+     * 
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches <code>text/htm*</code>; otherwise <code>false</code>
+     */
+    private static boolean isHtml(final String contentType) {
+        return contentType.startsWith(PRIMARY_HTML, 0);
+    }
+
+    private static final String PRIMARY_MULTI = "multipart/";
+
+    /**
+     * Checks if content type matches <code>multipart/*</code> content type.
+     * 
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches <code>multipart/*</code>; otherwise <code>false</code>
+     */
+    private static boolean isMultipart(final String contentType) {
+        return contentType.startsWith(PRIMARY_MULTI, 0);
+    }
+
+    private static final String PRIMARY_IMAGE = "image/";
+
+    /**
+     * Checks if content type matches <code>image/*</code> content type.
+     * 
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches <code>image/*</code>; otherwise <code>false</code>
+     */
+    private static boolean isImage(final String contentType) {
+        return contentType.startsWith(PRIMARY_IMAGE, 0);
+    }
+
+    private static final String PRIMARY_RFC822 = "message/rfc822";
+
+    /**
+     * Checks if content type matches <code>message/rfc822</code> content type.
+     * 
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches <code>message/rfc822</code>; otherwise <code>false</code>
+     */
+    private static boolean isMessage(final String contentType) {
+        return contentType.startsWith(PRIMARY_RFC822, 0);
+    }
+
+    private static final String PRIMARY_MESSAGE = "message/";
+
+    private static final String[] SUB_SPECIAL1 = { "delivery-status", "disposition-notification" };
+
+    private static final String[] SUB_SPECIAL2 = { "rfc822-headers", "vcard", "x-vcard", "calendar", "x-vcalendar" };
+
+    /**
+     * Checks if content type matches one of special content types:
+     * <ul>
+     * <li><code>message/delivery-status</code></li>
+     * <li><code>message/disposition-notification</code></li>
+     * <li><code>text/rfc822-headers</code></li>
+     * <li><code>text/vcard</code></li>
+     * <li><code>text/x-vcard</code></li>
+     * <li><code>text/calendar</code></li>
+     * <li><code>text/x-vcalendar</code></li>
+     * </ul>
+     * 
+     * @param contentType The content type
+     * @return <code>true</code> if content type matches special; otherwise <code>false</code>
+     */
+    private static boolean isSpecial(final String contentType) {
+        if (contentType.startsWith(PRIMARY_TEXT, 0)) {
+            final int off = PRIMARY_TEXT.length();
+            for (final String subtype : SUB_SPECIAL2) {
+                if (contentType.startsWith(subtype, off)) {
+                    return true;
+                }
+            }
+        } else if (contentType.startsWith(PRIMARY_MESSAGE, 0)) {
+            final int off = PRIMARY_MESSAGE.length();
+            for (final String subtype : SUB_SPECIAL1) {
+                if (contentType.startsWith(subtype, off)) {
+                    return true;
+                }
+            }
+        }
+        return false;
+    }
+
 }
