@@ -104,9 +104,10 @@ import com.openexchange.mail.usersetting.UserSettingMail;
 import com.openexchange.mail.utils.DisplayMode;
 import com.openexchange.mail.uuencode.UUEncodedPart;
 import com.openexchange.session.Session;
+import com.openexchange.tools.TimeZoneUtils;
 
 /**
- * {@link JSONMessageHandler}
+ * {@link JSONMessageHandler} - Generates a JSON message representation considering user-sensitive data.
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -144,6 +145,8 @@ public final class JSONMessageHandler implements MailMessageHandler {
 
     private boolean textAppended;
 
+    private boolean textWasEmpty;
+
     private final boolean[] modified;
 
     /**
@@ -268,7 +271,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
 
     private TimeZone getTimeZone() {
         if (timeZone == null) {
-            timeZone = TimeZone.getTimeZone(UserStorage.getStorageUser(session.getUserId(), ctx).getTimeZone());
+            timeZone = TimeZoneUtils.getTimeZone(UserStorage.getStorageUser(session.getUserId(), ctx).getTimeZone());
         }
         return timeZone;
     }
@@ -394,10 +397,11 @@ public final class JSONMessageHandler implements MailMessageHandler {
     /**
      * These headers are covered by fields of {@link MailMessage}
      */
-    private static final Set<HeaderName> COVERED_HEADER_NAMES = new HashSet<HeaderName>(Arrays.asList(new HeaderName[] {
-        MessageHeaders.CONTENT_DISPOSITION, MessageHeaders.CONTENT_ID, MessageHeaders.CONTENT_TYPE, MessageHeaders.BCC, MessageHeaders.CC,
-        MessageHeaders.DATE, MessageHeaders.DISP_NOT_TO, MessageHeaders.FROM, MessageHeaders.X_PRIORITY, MessageHeaders.SUBJECT,
-        MessageHeaders.TO }));
+    private static final Set<HeaderName> COVERED_HEADER_NAMES =
+        new HashSet<HeaderName>(Arrays.asList(new HeaderName[] {
+            MessageHeaders.CONTENT_DISPOSITION, MessageHeaders.CONTENT_ID, MessageHeaders.CONTENT_TYPE, MessageHeaders.BCC,
+            MessageHeaders.CC, MessageHeaders.DATE, MessageHeaders.DISP_NOT_TO, MessageHeaders.FROM, MessageHeaders.X_PRIORITY,
+            MessageHeaders.SUBJECT, MessageHeaders.TO }));
 
     public boolean handleHeaders(final int size, final Iterator<Entry<String, String>> iter) throws MailException {
         if (size == 0) {
@@ -407,12 +411,13 @@ public final class JSONMessageHandler implements MailMessageHandler {
             final JSONObject hdrObject = new JSONObject();
             for (int i = 0; i < size; i++) {
                 final Map.Entry<String, String> entry = iter.next();
-                if (MessageHeaders.HDR_DISP_NOT_TO.equalsIgnoreCase(entry.getKey())) {
+                final String headerName = entry.getKey();
+                if (MessageHeaders.HDR_DISP_NOT_TO.equalsIgnoreCase(headerName)) {
                     /*
                      * This special header is handled through handleDispositionNotification()
                      */
                     continue;
-                } else if (MessageHeaders.HDR_X_PRIORITY.equalsIgnoreCase(entry.getKey())) {
+                } else if (MessageHeaders.HDR_X_PRIORITY.equalsIgnoreCase(headerName)) {
                     /*
                      * Priority
                      */
@@ -429,15 +434,28 @@ public final class JSONMessageHandler implements MailMessageHandler {
                         }
                     }
                     jsonObject.put(MailJSONField.PRIORITY.getKey(), priority);
-                } else if (MessageHeaders.HDR_X_MAILER.equalsIgnoreCase(entry.getKey())) {
-                    hdrObject.put(entry.getKey(), entry.getValue());
-                } else if (MessageHeaders.HDR_X_OX_VCARD.equalsIgnoreCase(entry.getKey())) {
+                } else if (MessageHeaders.HDR_X_MAILER.equalsIgnoreCase(headerName)) {
+                    hdrObject.put(headerName, entry.getValue());
+                } else if (MessageHeaders.HDR_X_OX_VCARD.equalsIgnoreCase(headerName)) {
                     jsonObject.put(MailJSONField.VCARD.getKey(), true);
-                } else if (MessageHeaders.HDR_X_OX_NOTIFICATION.equalsIgnoreCase(entry.getKey())) {
+                } else if (MessageHeaders.HDR_X_OX_NOTIFICATION.equalsIgnoreCase(headerName)) {
                     jsonObject.put(MailJSONField.DISPOSITION_NOTIFICATION_TO.getKey(), entry.getValue());
                 } else {
-                    if (!COVERED_HEADER_NAMES.contains(HeaderName.valueOf(entry.getKey()))) {
-                        hdrObject.put(entry.getKey(), decodeMultiEncodedHeader(entry.getValue()));
+                    if (!COVERED_HEADER_NAMES.contains(HeaderName.valueOf(headerName))) {
+                        if (hdrObject.has(headerName)) {
+                            final Object previous = hdrObject.get(headerName);
+                            if (previous instanceof JSONArray) {
+                                final JSONArray ja = (JSONArray) previous;
+                                ja.put(decodeMultiEncodedHeader(entry.getValue()));
+                            } else {
+                                final JSONArray ja = new JSONArray();
+                                ja.put(previous);
+                                ja.put(decodeMultiEncodedHeader(entry.getValue()));
+                                hdrObject.put(headerName, ja);
+                            }
+                        } else {
+                            hdrObject.put(headerName, decodeMultiEncodedHeader(entry.getValue()));
+                        }
                     }
                 }
             }
@@ -527,7 +545,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
             return true;
         }
         try {
-            if (contentType.isMimeType(MIMETypes.MIME_TEXT_ENRICHED) || contentType.isMimeType(MIMETypes.MIME_TEXT_RICHTEXT) || contentType.isMimeType(MIMETypes.MIME_TEXT_RTF)) {
+            if (contentType.startsWith(MIMETypes.MIME_TEXT_ENRICHED) || contentType.startsWith(MIMETypes.MIME_TEXT_RICHTEXT) || contentType.startsWith(MIMETypes.MIME_TEXT_RTF)) {
                 if (textAppended) {
                     if (DisplayMode.DISPLAY.equals(displayMode)) {
                         /*
@@ -584,14 +602,22 @@ public final class JSONMessageHandler implements MailMessageHandler {
             /*
              * Just usual plain text
              */
-            asPlainText(id, contentType.getBaseType(), HTMLProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode));
             if (textAppended) {
-                /*
-                 * A plain text message body has already been detected; append inline text as an attachment, too
-                 */
-                asAttachment(id, contentType.getBaseType(), plainTextContentArg.length(), fileName);
+                if (textWasEmpty) {
+                    final String content = HTMLProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode);
+                    asPlainText(id, contentType.getBaseType(), content);
+                    textWasEmpty = (null == content || 0 == content.length());
+                } else {
+                    /*
+                     * A plain text message body has already been detected; append inline text as an attachment, too
+                     */
+                    asAttachment(id, contentType.getBaseType(), plainTextContentArg.length(), fileName);
+                }
             } else {
+                final String content = HTMLProcessing.formatTextForDisplay(plainTextContentArg, usm, displayMode);
+                asPlainText(id, contentType.getBaseType(), content);
                 textAppended = true;
+                textWasEmpty = (null == content || 0 == content.length());
             }
             return true;
         } catch (final JSONException e) {
@@ -600,7 +626,8 @@ public final class JSONMessageHandler implements MailMessageHandler {
     }
 
     private String getHtmlDisplayVersion(final ContentType contentType, final String src) {
-        if (contentType.isMimeType(MIMETypes.MIME_TEXT_ENRICHED) || contentType.isMimeType(MIMETypes.MIME_TEXT_RICHTEXT)) {
+        final String baseType = contentType.getBaseType().toLowerCase(Locale.ENGLISH);
+        if (baseType.startsWith(MIMETypes.MIME_TEXT_ENRICHED) || baseType.startsWith(MIMETypes.MIME_TEXT_RICHTEXT)) {
             return HTMLProcessing.formatHTMLForDisplay(
                 ENRCONV.convert(src),
                 contentType.getCharsetParameter(),
@@ -609,7 +636,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 usm,
                 modified,
                 displayMode);
-        } else if (contentType.isMimeType(MIMETypes.MIME_TEXT_RTF)) {
+        } else if (baseType.startsWith(MIMETypes.MIME_TEXT_RTF)) {
             return HTMLProcessing.formatHTMLForDisplay(
                 RTF2HTMLConverter.convertRTFToHTML(src),
                 contentType.getCharsetParameter(),
@@ -632,8 +659,9 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 final Locale locale = UserStorage.getStorageUser(session.getUserId(), ctx).getLocale();
                 contentType = MIMEType2ExtMap.getContentType(new File(filename.toLowerCase(locale)).getName()).toLowerCase(locale);
             } catch (final Exception e) {
-                final Throwable t = new Throwable(
-                    new StringBuilder("Unable to fetch content/type for '").append(filename).append("': ").append(e).toString());
+                final Throwable t =
+                    new Throwable(
+                        new StringBuilder("Unable to fetch content/type for '").append(filename).append("': ").append(e).toString());
                 LOG.warn(t.getMessage(), t);
             }
             jsonObject.put(MailJSONField.CONTENT_TYPE.getKey(), contentType);
@@ -691,7 +719,7 @@ public final class JSONMessageHandler implements MailMessageHandler {
         /*
          * Determine if message is of MIME type multipart/alternative
          */
-        if (mp.getContentType().isMimeType(MIMETypes.MIME_MULTIPART_ALTERNATIVE) && bodyPartCount >= 2) {
+        if (mp.getContentType().startsWith(MIMETypes.MIME_MULTIPART_ALTERNATIVE) && bodyPartCount >= 2) {
             isAlternative = true;
             altId = id;
         } else if (null != altId && !id.startsWith(altId)) {
@@ -711,14 +739,17 @@ public final class JSONMessageHandler implements MailMessageHandler {
                 nestedMail = (MailMessage) content;
             } else if (content instanceof InputStream) {
                 try {
-                    nestedMail = MIMEMessageConverter.convertMessage(new MimeMessage(
-                        MIMEDefaultSession.getDefaultSession(),
-                        (InputStream) content));
+                    nestedMail =
+                        MIMEMessageConverter.convertMessage(new MimeMessage(MIMEDefaultSession.getDefaultSession(), (InputStream) content));
                 } catch (final MessagingException e) {
                     throw MIMEMailException.handleMessagingException(e);
                 }
             } else {
-                LOG.error("Ignoring nested message. Cannot handle part's content which should be a RFC822 message according to its content type: " + (null == content ? "null" : content.getClass().getSimpleName()));
+                final StringBuilder sb = new StringBuilder(128);
+                sb.append("Ignoring nested message.").append(
+                    "Cannot handle part's content which should be a RFC822 message according to its content type: ");
+                sb.append((null == content ? "null" : content.getClass().getSimpleName()));
+                LOG.error(sb.toString());
                 return true;
             }
             final JSONMessageHandler msgHandler = new JSONMessageHandler(accountId, null, null, displayMode, session, usm, ctx);
@@ -731,8 +762,11 @@ public final class JSONMessageHandler implements MailMessageHandler {
             /*
              * Filename (if present)
              */
-            if (mailPart.containsFileName() && mailPart.getFileName() != null) {
-                nestedObject.put(MailJSONField.ATTACHMENT_FILE_NAME.getKey(), mailPart.getFileName());
+            if (mailPart.containsFileName()) {
+                final String name = mailPart.getFileName();
+                if (null != name) {
+                    nestedObject.put(MailJSONField.ATTACHMENT_FILE_NAME.getKey(), name);
+                }
             }
             getNestedMsgsArr().put(nestedObject);
             return true;
