@@ -81,6 +81,8 @@ public final class MailAccountDescription implements Serializable {
 
     private String primaryAddress;
 
+    private String personal;
+
     private String spamHandler;
 
     private String trash;
@@ -191,6 +193,15 @@ public final class MailAccountDescription implements Serializable {
         return primaryAddress;
     }
 
+    /**
+     * Gets the personal.
+     * 
+     * @return The personal
+     */
+    public String getPersonal() {
+        return personal;
+    }
+
     /**
      * Gets the ID
      * 
@@ -489,6 +500,15 @@ public final class MailAccountDescription implements Serializable {
         this.primaryAddress = primaryAddress;
     }
 
+    /**
+     * Sets the personal.
+     * 
+     * @param personal The personal
+     */
+    public void setPersonal(final String personal) {
+        this.personal = personal;
+    }
+
     /**
      * Gets the name for default drafts folder.
      * 
