@@ -60,7 +60,7 @@ import com.openexchange.mailaccount.servlet.fields.MailAccountFields;
 import com.openexchange.mailaccount.servlet.fields.MailAccountGetSwitch;
 
 /**
- * {@link MailAccountWriter} - TODO Short description of this class' purpose.
+ * {@link MailAccountWriter} - Writes mail account as JSON data.
  * 
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
@@ -73,7 +73,7 @@ public final class MailAccountWriter {
     /**
      * Writes specified mail account to a JSON object.
      * 
-     * @param account The mail account to written from mail account's data
+     * @param account The mail account to write
      * @return A JSON object filled with
      * @throws JSONException If writing JSON fails
      */
@@ -99,6 +99,7 @@ public final class MailAccountWriter {
 
         json.put(MailAccountFields.NAME, account.getName());
         json.put(MailAccountFields.PRIMARY_ADDRESS, account.getPrimaryAddress());
+        json.put(MailAccountFields.PERSONAL, account.getPersonal());
         json.put(MailAccountFields.SPAM_HANDLER, account.getSpamHandler());
         // Folder names
         json.put(MailAccountFields.TRASH, account.getTrash());
@@ -136,9 +137,16 @@ public final class MailAccountWriter {
         return json;
     }
 
-    public static JSONArray writeArray(final MailAccount[] userMailAccounts, final List<Attribute> attributes) {
+    /**
+     * Writes specified attributes for each mail account contained in given array in an own JSON array surrounded by a super JSON array.
+     * 
+     * @param mailAccounts The mail accounts
+     * @param attributes The attributes
+     * @return A JSON array of JSON arrays for each account
+     */
+    public static JSONArray writeArray(final MailAccount[] mailAccounts, final List<Attribute> attributes) {
         final JSONArray rows = new JSONArray();
-        for (final MailAccount account : userMailAccounts) {
+        for (final MailAccount account : mailAccounts) {
             final MailAccountGetSwitch getter = new MailAccountGetSwitch(account);
             final JSONArray row = new JSONArray();
             for (final Attribute attribute : attributes) {
