@@ -62,9 +62,14 @@ import org.osgi.framework.BundleActivator;
 import org.osgi.framework.BundleContext;
 import org.osgi.framework.ServiceRegistration;
 import org.osgi.service.event.EventAdmin;
+import org.osgi.service.event.EventConstants;
+import org.osgi.service.event.EventHandler;
 import org.osgi.service.http.HttpService;
 import org.osgi.util.tracker.ServiceTracker;
+import com.openexchange.ajax.Folder;
 import com.openexchange.ajax.Infostore;
+import com.openexchange.ajax.customizer.folder.AdditionalFolderField;
+import com.openexchange.ajax.customizer.folder.osgi.FolderFieldCollector;
 import com.openexchange.ajax.requesthandler.AJAXRequestHandler;
 import com.openexchange.api2.ContactInterfaceFactory;
 import com.openexchange.api2.RdbContactInterfaceFactory;
@@ -110,6 +115,7 @@ import com.openexchange.groupware.contact.datahandler.ContactInsertDataHandler;
 import com.openexchange.groupware.contact.datasource.ContactDataSource;
 import com.openexchange.groupware.contact.internal.ContactInterfaceDiscoveryServiceImpl;
 import com.openexchange.groupware.datahandler.ICalInsertDataHandler;
+import com.openexchange.groupware.datahandler.ICalJSONDataHandler;
 import com.openexchange.groupware.delete.DeleteListener;
 import com.openexchange.groupware.importexport.importers.ExtraneousSeriesMasterRecoveryParser;
 import com.openexchange.groupware.infostore.InfostoreFacade;
@@ -121,11 +127,13 @@ import com.openexchange.groupware.tx.DBProvider;
 import com.openexchange.groupware.tx.osgi.WhiteboardDBProvider;
 import com.openexchange.groupware.update.UpdateTaskProviderService;
 import com.openexchange.groupware.update.UpdateTaskServiceTrackerCustomizer;
+import com.openexchange.groupware.update.tasks.MALPollCreateTableTask;
 import com.openexchange.i18n.I18nService;
 import com.openexchange.image.ImageService;
 import com.openexchange.login.LoginHandlerService;
 import com.openexchange.mail.api.MailProvider;
 import com.openexchange.mail.cache.MailAccessCacheEventListener;
+import com.openexchange.mail.cache.MailSessionEventHandler;
 import com.openexchange.mail.conversion.ICalMailPartDataSource;
 import com.openexchange.mail.conversion.VCardAttachMailDataHandler;
 import com.openexchange.mail.conversion.VCardMailPartDataSource;
@@ -164,6 +172,7 @@ import com.openexchange.spamhandler.SpamHandler;
 import com.openexchange.spamhandler.osgi.SpamHandlerServiceTracker;
 import com.openexchange.systemname.SystemNameService;
 import com.openexchange.systemname.internal.JVMRouteSystemNameImpl;
+import com.openexchange.threadpool.ThreadPoolService;
 import com.openexchange.timer.TimerService;
 import com.openexchange.tools.servlet.http.osgi.HttpServiceImpl;
 import com.openexchange.user.UserService;
@@ -192,14 +201,18 @@ public final class ServerActivator extends DeferredActivator {
      */
     private static final String STR_IDENTIFIER = "identifier";
 
-    private static final Class<?>[] NEEDED_SERVICES_ADMIN = {
-        ConfigurationService.class, CacheService.class, EventAdmin.class, TimerService.class, CalendarAdministrationService.class,
-        CalendarCollectionService.class };
+    private static final Class<?>[] NEEDED_SERVICES_ADMIN =
+        {
+            ConfigurationService.class, CacheService.class, EventAdmin.class, TimerService.class, ThreadPoolService.class,
+            CalendarAdministrationService.class, CalendarCollectionService.class
+        };
 
-    private static final Class<?>[] NEEDED_SERVICES_SERVER = {
-        ConfigurationService.class, CacheService.class, EventAdmin.class, SessiondService.class, SpringParser.class, JDOMParser.class,
-        TimerService.class, CalendarAdministrationService.class, AppointmentSqlFactoryService.class, CalendarCollectionService.class,
-        ReminderDeleteInterface.class };
+    private static final Class<?>[] NEEDED_SERVICES_SERVER =
+        {
+            ConfigurationService.class, CacheService.class, EventAdmin.class, SessiondService.class, SpringParser.class, JDOMParser.class,
+            TimerService.class, ThreadPoolService.class, CalendarAdministrationService.class, AppointmentSqlFactoryService.class,
+            CalendarCollectionService.class, ReminderDeleteInterface.class
+        };
 
     private final List<ServiceRegistration> registrationList;
 
@@ -312,7 +325,7 @@ public final class ServerActivator extends DeferredActivator {
          * Add service trackers
          */
         // Configuration service load
-        ServiceTracker confTracker = new ServiceTracker(context, ConfigurationService.class.getName(), new ConfigurationCustomizer(context));
+        final ServiceTracker confTracker = new ServiceTracker(context, ConfigurationService.class.getName(), new ConfigurationCustomizer(context));
         confTracker.open(); // We need this for {@link Starter#start()}
         serviceTrackerList.add(confTracker);
         // move this to the required services once the database component gets into its own bundle.
@@ -374,7 +387,8 @@ public final class ServerActivator extends DeferredActivator {
             context,
             FolderDeleteListenerService.class.getName(),
             new FolderDeleteListenerServiceTrackerCustomizer(context)));
-
+        
+        
         /*
          * Register EventHandler
          */
@@ -446,6 +460,10 @@ public final class ServerActivator extends DeferredActivator {
                 PublicationTargetDiscoveryService.class.getName(),
                 new PublicationTargetDiscoveryServiceTrackerCustomizer(context)));
 
+            // Folder Fields
+            
+            serviceTrackerList.add(new ServiceTracker(context, AdditionalFolderField.class.getName(), new FolderFieldCollector(context, Folder.getAdditionalFields())));
+            
             // Start up server the usual way
             starter.start();
         }
@@ -470,7 +488,12 @@ public final class ServerActivator extends DeferredActivator {
             ContextService.class,
             true), null));
         registrationList.add(context.registerService(SystemNameService.class.getName(), new JVMRouteSystemNameImpl(), null));
-        registrationList.add(context.registerService(MailService.class.getName(), new MailServiceImpl(), null));
+        {
+            registrationList.add(context.registerService(MailService.class.getName(), new MailServiceImpl(), null));
+            final Dictionary<Object, Object> serviceProperties = new Hashtable<Object, Object>(1);
+            serviceProperties.put(EventConstants.EVENT_TOPIC, MailSessionEventHandler.getTopics());
+            registrationList.add(context.registerService(EventHandler.class.getName(), new MailSessionEventHandler(), serviceProperties));
+        }
         registrationList.add(context.registerService(ImageService.class.getName(), ServerServiceRegistry.getInstance().getService(
             ImageService.class), null));
         // TODO: Register search service here until its encapsulated in an own bundle
@@ -480,6 +503,7 @@ public final class ServerActivator extends DeferredActivator {
         registrationList.add(context.registerService(LoginHandlerService.class.getName(), new TransportLoginHandler(), null));
         // Register table creation for mail account storage.
         registrationList.add(context.registerService(CreateTableService.class.getName(), new CreateMailAccountTables(), null));
+        registrationList.add(context.registerService(CreateTableService.class.getName(), new MALPollCreateTableTask(), null));
         // TODO: Register server's mail account storage here until its encapsulated in an own bundle
         registrationList.add(context.registerService(
             MailAccountStorageService.class.getName(),
@@ -521,6 +545,11 @@ public final class ServerActivator extends DeferredActivator {
             props.put(STR_IDENTIFIER, "com.openexchange.ical");
             registrationList.add(context.registerService(DataHandler.class.getName(), new ICalInsertDataHandler(), props));
         }
+        {
+            final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
+            props.put(STR_IDENTIFIER, "com.openexchange.ical.json");
+            registrationList.add(context.registerService(DataHandler.class.getName(), new ICalJSONDataHandler(), props));
+        }
         {
             final Dictionary<Object, Object> props = new Hashtable<Object, Object>();
             props.put(STR_IDENTIFIER, "com.openexchange.mail.vcard");
