@@ -58,13 +58,14 @@ import java.io.Serializable;
 import java.util.Arrays;
 import java.util.Collection;
 import java.util.Enumeration;
+import java.util.HashMap;
 import java.util.Iterator;
 import org.apache.commons.logging.Log;
 import org.apache.commons.logging.LogFactory;
 
 /**
- * Methods for easy handling of collections.
- * TODO use Collections in com.openexchange.tools.arrays.
+ * Methods for easy handling of collections. TODO use Collections in com.openexchange.tools.arrays.
+ * 
  * @author <a href="mailto:marcus@open-xchange.org">Marcus Klein</a>
  */
 public final class Collections {
@@ -81,6 +82,69 @@ public final class Collections {
         super();
     }
 
+    /**
+     * Strips the <tt>remove()</tt> functionality from an existing iterator.
+     * <p>
+     * Wraps the supplied iterator into a new one that will always throw an <tt>UnsupportedOperationException</tt> if its <tt>remove()</tt>
+     * method is called.
+     * 
+     * @param iterator The iterator to turn into an unmodifiable iterator.
+     * @return An iterator with no remove functionality.
+     */
+    public static <T> Iterator<T> unmodifiableIterator(final Iterator<T> iterator) {
+        if (iterator == null) {
+            throw new NullPointerException();
+        }
+
+        return new Iterator<T>() {
+
+            public boolean hasNext() {
+                return iterator.hasNext();
+            }
+
+            public T next() {
+                return iterator.next();
+            }
+
+            public void remove() {
+                throw new UnsupportedOperationException();
+            }
+        };
+    }
+
+    /**
+     * Creates a new {@link HashMap} instance.
+     * <p>
+     * Convenience method to substitute<br>
+     * <i> Map&lt;String, String&gt; m = new HashMap&lt;String, String&gt;(); </i><br>
+     * with<br>
+     * <i> Map&lt;String, String&gt; m = newHashMap(); </i>
+     * 
+     * @param <K> The key instances' type
+     * @param <V> The value instances' type
+     * @return A new {@link HashMap} instance
+     */
+    public static <K, V> HashMap<K, V> newHashMap() {
+        return new HashMap<K, V>();
+    }
+
+    /**
+     * Creates a new {@link HashMap} instance.
+     * <p>
+     * Convenience method to substitute<br>
+     * <i> Map&lt;String, String&gt; m = new HashMap&lt;String, String&gt;(initialCapacity); </i><br>
+     * with<br>
+     * <i> Map&lt;String, String&gt; m = newHashMap(initialCapacity); </i>
+     * 
+     * @param <K> The key instances' type
+     * @param <V> The value instances' type
+     * @param initialCapacity The initial capacity
+     * @return A new {@link HashMap} instance
+     */
+    public static <K, V> HashMap<K, V> newHashMap(final int initialCapacity) {
+        return new HashMap<K, V>(initialCapacity);
+    }
+
     /**
      * Finds the first element in a collection that satisfies the filter
      * 
