@@ -50,7 +50,6 @@
 package com.openexchange.tools;
 
 import java.io.PrintWriter;
-import java.io.StringWriter;
 import java.text.SimpleDateFormat;
 import java.util.Date;
 import java.util.Iterator;
@@ -312,13 +311,10 @@ public final class StringCollection {
         }
         final StringBuilder sb = new StringBuilder(arr.length * 5);
         sb.append('(');
-        for (int a = 0; a < arr.length; a++) {
-            if (a > 0) {
-                sb.append(',');
-                sb.append(arr[a]);
-            } else {
-                sb.append(arr[a]);
-            }
+        sb.append(arr[0]);
+        for (int a = 1; a < arr.length; a++) {
+            sb.append(',');
+            sb.append(arr[a]);
         }
         sb.append(')');
         return sb.toString();
@@ -573,7 +569,7 @@ public final class StringCollection {
     public static String getStackAsString() {
         final Throwable t = new Throwable();
         t.fillInStackTrace();
-        final StringWriter sw = new StringWriter();
+        final UnsynchronizedStringWriter sw = new UnsynchronizedStringWriter();
         final PrintWriter pw = new PrintWriter(sw, true);
         t.printStackTrace(pw);
         return sw.toString();
