@@ -318,13 +318,13 @@ public class OXFolderException extends OXException {
          */
         NO_EFFECTIVE_PERMISSION("Effective permission of folder %1$s could not be determined for user %2$s in context %3$s", Category.CODE_ERROR, 37),
         /**
-         * A SQL error occurred in context %1$s
+         * A SQL error occurred: %1$s
          */
-        SQL_ERROR("An SQL error occurred in context %1$s", Category.CODE_ERROR, 38),
+        SQL_ERROR("A SQL error occurred: %1$s", Category.CODE_ERROR, 38),
         /**
          * A DBPool error occurred in context %1$s
          */
-        DBPOOLING_ERROR("An SQL error occurred in context %1$s", Category.CODE_ERROR, 39),
+        DBPOOLING_ERROR("A DBPool error occurred in context %1$s", Category.CODE_ERROR, 39),
         /**
          * Delivered sequence id %1$s from database is less than allowed min. folder id of %2$s in context %3$s
          */
@@ -490,7 +490,19 @@ public class OXFolderException extends OXException {
         /**
          * Duplicate permission defined for group %1$s. Only one permission per group is allowed.
          */
-        DUPLICATE_GROUP_PERMISSION("Duplicate permission defined for group %1$s. Only one permission per group is allowed.", Category.USER_INPUT, 80);
+        DUPLICATE_GROUP_PERMISSION("Duplicate permission defined for group %1$s. Only one permission per group is allowed.", Category.USER_INPUT, 80),
+        /**
+         * Only the folder visibility permission is allowed to be changed for folder %1$s in context %2$s.
+         */
+        FOLDER_VISIBILITY_PERMISSION_ONLY("Only the folder visibility permission is allowed to be changed for folder %1$s in context %2$s.", Category.PERMISSION, 81),
+        /**
+         * Only individual user permissions, but no group permissions are allowed for folder %1$s in context %2$s.
+         */
+        NO_GROUP_PERMISSION("Only individual user permissions, but no group permissions are allowed for folder %1$s in context %2$s.", Category.PERMISSION, 82),
+        /**
+         * No individual user permissions are allowed for folder %1$s in context %2$s.
+         */
+        NO_INDIVIDUAL_PERMISSION("No individual user permissions are allowed for folder %1$s in context %2$s.", Category.PERMISSION, 83);
 
         /**
          * Message of the exception.
