@@ -253,11 +253,12 @@ final class OXFolderManagerImpl extends OXFolderManager {
             try {
                 final EffectivePermission p = parentFolder.getEffectiveUserPermission(user.getId(), userConfig, readCon);
                 if (!p.canCreateSubfolders()) {
-                    final OXFolderException fe = new OXFolderException(
-                        FolderCode.NO_CREATE_SUBFOLDER_PERMISSION,
-                        OXFolderUtility.getUserName(user.getId(), ctx),
-                        OXFolderUtility.getFolderName(parentFolder),
-                        Integer.valueOf(ctx.getContextId()));
+                    final OXFolderException fe =
+                        new OXFolderException(
+                            FolderCode.NO_CREATE_SUBFOLDER_PERMISSION,
+                            OXFolderUtility.getUserName(user.getId(), ctx),
+                            OXFolderUtility.getFolderName(parentFolder),
+                            Integer.valueOf(ctx.getContextId()));
                     if (p.getUnderlyingPermission().canCreateSubfolders()) {
                         fe.setCategory(Category.USER_CONFIGURATION);
                     }
@@ -276,7 +277,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                         Integer.valueOf(ctx.getContextId()));
                 }
             } catch (final SQLException e) {
-                throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
             } catch (final DBPoolingException e) {
                 throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
             }
@@ -340,7 +341,9 @@ final class OXFolderManagerImpl extends OXFolderManager {
          * Check if duplicate folder exists
          */
         try {
-            if (OXFolderSQL.lookUpFolder(folderObj.getParentFolderID(), folderObj.getFolderName(), folderObj.getModule(), readCon, ctx) != -1) {
+            final int parentFolderID = folderObj.getParentFolderID();
+            final String folderName = folderObj.getFolderName();
+            if (OXFolderSQL.lookUpFolder(parentFolderID, folderName, folderObj.getModule(), readCon, ctx) != -1) {
                 /*
                  * A duplicate folder exists
                  */
@@ -349,8 +352,9 @@ final class OXFolderManagerImpl extends OXFolderManager {
                     OXFolderUtility.getFolderName(parentFolder),
                     Integer.valueOf(ctx.getContextId()));
             }
+            OXFolderUtility.checki18nString(parentFolderID, folderName, user.getLocale(), ctx);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         }
@@ -375,7 +379,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 } catch (final DataTruncation e) {
                     throw parseTruncated(e, folderObj, TABLE_OXFOLDER_TREE);
                 } catch (final SQLException e) {
-                    throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                    throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
                 }
                 OXFolderUtility.checkSimilarNamedSharedFolder(diff, allSharedFolders, folderObj.getFolderName(), ctx);
             }
@@ -391,7 +395,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         try {
             fuid = OXFolderSQL.getNextSerial(ctx, writeCon);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         if (fuid < FolderObject.MIN_FOLDER_ID) {
             throw new OXFolderException(
@@ -410,7 +414,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DataTruncation e) {
             throw parseTruncated(e, folderObj, TABLE_OXFOLDER_TREE);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * Update cache with writable connection!
@@ -539,10 +543,12 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 }
                 if (FolderCacheManager.isEnabled()) {
                     fo.fill(FolderCacheManager.getInstance().getFolderObject(fo.getObjectID(), false, ctx, wc));
-                    /*
-                     * Update parent, too
-                     */
-                    FolderCacheManager.getInstance().loadFolderObject(fo.getParentFolderID(), ctx, wc);
+                    if (fo.getParentFolderID() > 0) {
+                        /*
+                         * Update parent, too
+                         */
+                        FolderCacheManager.getInstance().loadFolderObject(fo.getParentFolderID(), ctx, wc);
+                    }
                 } else {
                     fo.fill(FolderObject.loadFolderObjectFromDB(fo.getObjectID(), ctx, wc));
                 }
@@ -552,10 +558,17 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 if (CalendarCache.isInitialized()) {
                     CalendarCache.getInstance().invalidateGroup(ctx.getContextId());
                 }
-                try {
-                    new EventClient(session).modify(storageVersion, fo, getFolderFromMaster(fo.getParentFolderID()));
-                } catch (final EventException e) {
-                    LOG.warn("Update event could not be enqueued", e);
+                if (FolderObject.SYSTEM_MODULE != fo.getModule()) {
+                    try {
+                        new EventClient(session).modify(storageVersion, fo, FolderObject.loadFolderObjectFromDB(
+                            fo.getParentFolderID(),
+                            ctx,
+                            wc,
+                            true,
+                            false));
+                    } catch (final EventException e) {
+                        LOG.warn("Update event could not be enqueued", e);
+                    }
                 }
                 return fo;
             } finally {
@@ -619,7 +632,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         /*
          * Check if folder module is supposed to be updated
          */
-        if (folderObj.containsModule() && folderObj.getModule() != storageObj.getModule()) {
+        if (folderObj.containsModule() && folderObj.getModule() != storageObj.getModule() && FolderObject.SYSTEM_MODULE != storageObj.getModule()) {
             /*
              * Module update only allowed if known and folder is empty
              */
@@ -665,11 +678,13 @@ final class OXFolderManagerImpl extends OXFolderManager {
         OXFolderUtility.checkPermissionsAgainstSessionUserConfig(folderObj, userConfig, ctx);
         OXFolderUtility.checkFolderPermissions(folderObj, user.getId(), ctx);
         OXFolderUtility.checkPermissionsAgainstUserConfigs(folderObj, ctx);
+        OXFolderUtility.checkSystemFolderPermissions(folderObj.getObjectID(), folderObj.getNonSystemPermissionsAsArray(), user, ctx);
         if (FolderObject.PUBLIC == folderObj.getType()) {
             {
-                final OCLPermission[] removedPerms = OXFolderUtility.getPermissionsWithoutFolderAccess(
-                    folderObj.getNonSystemPermissionsAsArray(),
-                    storageObj.getNonSystemPermissionsAsArray());
+                final OCLPermission[] removedPerms =
+                    OXFolderUtility.getPermissionsWithoutFolderAccess(
+                        folderObj.getNonSystemPermissionsAsArray(),
+                        storageObj.getNonSystemPermissionsAsArray());
                 if (removedPerms.length > 0) {
                     new CheckPermissionOnRemove(session, writeCon, ctx).checkPermissionsOnUpdate(
                         folderObj.getObjectID(),
@@ -693,13 +708,15 @@ final class OXFolderManagerImpl extends OXFolderManager {
              * Rename: Check if duplicate folder exists
              */
             try {
-                final int folderId = OXFolderSQL.lookUpFolderOnUpdate(
-                    folderObj.getObjectID(),
-                    storageObj.getParentFolderID(),
-                    folderObj.getFolderName(),
-                    folderObj.getModule(),
-                    readCon,
-                    ctx);
+                final String folderName = folderObj.getFolderName();
+                final int folderId =
+                    OXFolderSQL.lookUpFolderOnUpdate(
+                        folderObj.getObjectID(),
+                        storageObj.getParentFolderID(),
+                        folderName,
+                        folderObj.getModule(),
+                        readCon,
+                        ctx);
                 if (folderId != -1 && folderId != folderObj.getObjectID()) {
                     /*
                      * A duplicate folder exists
@@ -708,8 +725,13 @@ final class OXFolderManagerImpl extends OXFolderManager {
                         readCon,
                         ctx).getFolderObject(storageObj.getParentFolderID())), Integer.valueOf(ctx.getContextId()));
                 }
+                /*
+                 * Check i18n strings, too
+                 */
+                final int parentFolderId = storageObj.getParentFolderID();
+                OXFolderUtility.checki18nString(parentFolderId, folderName, user.getLocale(), ctx);
             } catch (final SQLException e) {
-                throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
             } catch (final DBPoolingException e) {
                 throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
             }
@@ -718,11 +740,8 @@ final class OXFolderManagerImpl extends OXFolderManager {
          * This folder shall be shared to other users
          */
         if (folderObj.getType() == FolderObject.PRIVATE && folderObj.getPermissions().size() > 1) {
-            final Set<Integer> diff = OXFolderUtility.getShareUsers(
-                rename ? null : storageObj.getPermissions(),
-                folderObj.getPermissions(),
-                user.getId(),
-                ctx);
+            final Set<Integer> diff =
+                OXFolderUtility.getShareUsers(rename ? null : storageObj.getPermissions(), folderObj.getPermissions(), user.getId(), ctx);
             if (!diff.isEmpty()) {
                 final FolderObject[] allSharedFolders;
                 try {
@@ -744,7 +763,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 } catch (final DataTruncation e) {
                     throw parseTruncated(e, folderObj, TABLE_OXFOLDER_TREE);
                 } catch (final SQLException e) {
-                    throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                    throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
                 }
                 OXFolderUtility.checkSimilarNamedSharedFolder(
                     diff,
@@ -767,7 +786,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DataTruncation e) {
             throw parseTruncated(e, folderObj, TABLE_OXFOLDER_TREE);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -804,8 +823,8 @@ final class OXFolderManagerImpl extends OXFolderManager {
             final Tasks tasks = Tasks.getInstance();
             return readCon == null ? tasks.isFolderEmpty(ctx, folderId) : tasks.isFolderEmpty(ctx, readCon, folderId);
         } else if (module == FolderObject.CALENDAR) {
-            final AppointmentSQLInterface calSql = ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(
-                session);
+            final AppointmentSQLInterface calSql =
+                ServerServiceRegistry.getInstance().getService(AppointmentSqlFactoryService.class).createAppointmentSql(session);
             if (readCon == null) {
                 try {
                     return calSql.isFolderEmpty(user.getId(), folderId);
@@ -826,6 +845,8 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } else if (module == FolderObject.INFOSTORE) {
             final InfostoreFacade db = new InfostoreFacadeImpl(readCon == null ? new DBPoolProvider() : new StaticDBPoolProvider(readCon));
             return db.isFolderEmpty(folderId, ctx);
+        } else if (module == FolderObject.SYSTEM_MODULE) {
+            return true;
         } else {
             throw new OXFolderException(
                 FolderCode.UNKNOWN_MODULE,
@@ -864,13 +885,15 @@ final class OXFolderManagerImpl extends OXFolderManager {
          * Check for duplicate folder
          */
         try {
-            final int folderId = OXFolderSQL.lookUpFolderOnUpdate(
-                folderObj.getObjectID(),
-                storageObj.getParentFolderID(),
-                folderObj.getFolderName(),
-                storageObj.getModule(),
-                readCon,
-                ctx);
+            final String folderName = folderObj.getFolderName();
+            final int folderId =
+                OXFolderSQL.lookUpFolderOnUpdate(
+                    folderObj.getObjectID(),
+                    storageObj.getParentFolderID(),
+                    folderName,
+                    storageObj.getModule(),
+                    readCon,
+                    ctx);
             if (folderId != -1 && folderId != folderObj.getObjectID()) {
                 /*
                  * A duplicate folder exists
@@ -880,10 +903,15 @@ final class OXFolderManagerImpl extends OXFolderManager {
                     OXFolderUtility.getFolderName(new OXFolderAccess(readCon, ctx).getFolderObject(storageObj.getParentFolderID())),
                     Integer.valueOf(ctx.getContextId()));
             }
+            /*
+             * Check i18n strings, too
+             */
+            final int parentFolderId = storageObj.getParentFolderID();
+            OXFolderUtility.checki18nString(parentFolderId, folderName, user.getLocale(), ctx);
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * This folder shall be shared to other users
@@ -911,7 +939,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 } catch (final DataTruncation e) {
                     throw parseTruncated(e, folderObj, TABLE_OXFOLDER_TREE);
                 } catch (final SQLException e) {
-                    throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                    throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
                 }
                 OXFolderUtility.checkSimilarNamedSharedFolder(diff, allSharedFolders, folderObj.getFolderName(), ctx);
             }
@@ -926,7 +954,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DataTruncation e) {
             throw parseTruncated(e, folderObj, TABLE_OXFOLDER_TREE);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -965,14 +993,19 @@ final class OXFolderManagerImpl extends OXFolderManager {
          * Check for a duplicate folder in target folder
          */
         try {
-            if (OXFolderSQL.lookUpFolder(targetFolderId, storageSrc.getFolderName(), storageSrc.getModule(), readCon, ctx) != -1) {
+            final String folderName = storageSrc.getFolderName();
+            if (OXFolderSQL.lookUpFolder(targetFolderId, folderName, storageSrc.getModule(), readCon, ctx) != -1) {
                 throw new OXFolderException(
                     FolderCode.TARGET_FOLDER_CONTAINS_DUPLICATE,
                     OXFolderUtility.getFolderName(storageDest),
                     Integer.valueOf(ctx.getContextId()));
             }
+            /*
+             * Check i18n strings, too
+             */
+            OXFolderUtility.checki18nString(targetFolderId, folderName, user.getLocale(), ctx);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         }
@@ -1025,7 +1058,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 throw new OXFolderPermissionException(FolderCode.NO_EQUAL_MOVE, Integer.valueOf(ctx.getContextId()));
             }
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         }
@@ -1048,12 +1081,8 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 /*
                  * Count all moveable subfolders: TODO: Recursive check???
                  */
-                final int numOfMoveableSubfolders = OXFolderSQL.getNumOfMoveableSubfolders(
-                    storageSrc.getObjectID(),
-                    user.getId(),
-                    user.getGroups(),
-                    readCon,
-                    ctx);
+                final int numOfMoveableSubfolders =
+                    OXFolderSQL.getNumOfMoveableSubfolders(storageSrc.getObjectID(), user.getId(), user.getGroups(), readCon, ctx);
                 if (numOfMoveableSubfolders != storageSrc.getSubfolderIds(true, ctx).size()) {
                     throw new OXFolderPermissionException(
                         FolderCode.NO_SUBFOLDER_MOVE_ACCESS,
@@ -1063,7 +1092,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 }
             }
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         }
@@ -1075,7 +1104,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * Call SQL move
@@ -1085,7 +1114,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DataTruncation e) {
             throw parseTruncated(e, storageSrc, TABLE_OXFOLDER_TREE);
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         }
@@ -1100,7 +1129,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * Update last-modified time stamps
@@ -1112,7 +1141,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * Update OLD parent in cache, cause this can only be done here
@@ -1181,7 +1210,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
             } catch (final DBPoolingException e) {
                 throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
             } catch (final SQLException e) {
-                throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
             }
         }
         if (checkPermissions) {
@@ -1264,7 +1293,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
             } catch (final DBPoolingException e) {
                 throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
             } catch (final SQLException e) {
-                throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+                throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
             }
         }
         if (checkPermissions) {
@@ -1309,13 +1338,14 @@ final class OXFolderManagerImpl extends OXFolderManager {
          */
         final HashMap<Integer, HashMap<?, ?>> deleteableFolders;
         try {
-            deleteableFolders = gatherDeleteableFolders(fo.getObjectID(), user.getId(), userConfig, StringCollection.getSqlInString(
-                user.getId(),
-                user.getGroups()));
+            deleteableFolders =
+                gatherDeleteableFolders(fo.getObjectID(), user.getId(), userConfig, StringCollection.getSqlInString(
+                    user.getId(),
+                    user.getGroups()));
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * Remember folder type
@@ -1366,13 +1396,6 @@ final class OXFolderManagerImpl extends OXFolderManager {
                     false,
                     "del_oxfolder_tree",
                     "del_oxfolder_permissions"));
-                try {
-                    new EventClient(session).delete(fo);
-                } catch (final EventException e) {
-                    LOG.warn("Delete event could not be enqueued", e);
-                } catch (final ContextException e) {
-                    LOG.warn("Delete event could not be enqueued", e);
-                }
                 return fo;
             } finally {
                 if (create && wc != null) {
@@ -1382,18 +1405,18 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
-    @SuppressWarnings("unchecked")
     private void deleteValidatedFolders(final HashMap<Integer, HashMap<?, ?>> deleteableIDs, final long lastModified, final int type) throws OXException {
         final int deleteableIDsSize = deleteableIDs.size();
         final Iterator<Map.Entry<Integer, HashMap<?, ?>>> iter = deleteableIDs.entrySet().iterator();
         for (int i = 0; i < deleteableIDsSize; i++) {
             final Map.Entry<Integer, HashMap<?, ?>> entry = iter.next();
             final Integer folderID = entry.getKey();
-            final HashMap<Integer, HashMap<?, ?>> hashMap = (HashMap<Integer, HashMap<?, ?>>) entry.getValue();
+            final @SuppressWarnings("unchecked") HashMap<Integer, HashMap<?, ?>> hashMap =
+                (HashMap<Integer, HashMap<?, ?>>) entry.getValue();
             /*
              * Delete subfolders first, if any exist
              */
@@ -1453,7 +1476,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
         } catch (final DBPoolingException e) {
             throw new OXFolderException(FolderCode.DBPOOLING_ERROR, e, Integer.valueOf(ctx.getContextId()));
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
         /*
          * Process system permissions
@@ -1491,16 +1514,30 @@ final class OXFolderManagerImpl extends OXFolderManager {
             }
         }
         try {
-            Links.deleteAllFolderLinks(folderID, ctx.getContextId(), wc);
+            try {
+                Links.deleteAllFolderLinks(folderID, ctx.getContextId(), wc);
 
-            final ServerUserSetting sus = ServerUserSetting.getInstance(wc);
-            final Integer collectFolder = sus.getIContactCollectionFolder(ctx.getContextId(), user.getId());
-            if (null != collectFolder && folderID == collectFolder.intValue()) {
-                sus.setIContactColletion(ctx.getContextId(), user.getId(), false);
-                sus.setIContactCollectionFolder(ctx.getContextId(), user.getId(), null);
+                final ServerUserSetting sus = ServerUserSetting.getInstance(wc);
+                final Integer collectFolder = sus.getIContactCollectionFolder(ctx.getContextId(), user.getId());
+                if (null != collectFolder && folderID == collectFolder.intValue()) {
+                    sus.setIContactColletion(ctx.getContextId(), user.getId(), false);
+                    sus.setIContactCollectionFolder(ctx.getContextId(), user.getId(), null);
+                }
+            } catch (final SettingException e) {
+                throw new OXFolderException(e);
+            }
+            /*
+             * Propagate
+             */
+            final FolderObject fo =
+                FolderObject.loadFolderObjectFromDB(folderID, ctx, wc, true, false, "del_oxfolder_tree", "del_oxfolder_permissions");
+            try {
+                new EventClient(session).delete(fo);
+            } catch (final EventException e) {
+                LOG.warn("Delete event could not be enqueued", e);
+            } catch (final ContextException e) {
+                LOG.warn("Delete event could not be enqueued", e);
             }
-        } catch (final SettingException e) {
-            throw new OXFolderException(e);
         } finally {
             if (closeWriter) {
                 DBPool.closeWriterSilent(ctx, wc);
@@ -1516,7 +1553,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                 cSql.deleteAppointmentsInFolder(folderID, writeCon);
             }
         } catch (final SQLException e) {
-            throw new OXFolderException(FolderCode.SQL_ERROR, e, Integer.valueOf(ctx.getContextId()));
+            throw new OXFolderException(FolderCode.SQL_ERROR, e, e.getMessage());
         }
     }
 
@@ -1788,7 +1825,7 @@ final class OXFolderManagerImpl extends OXFolderManager {
                     readCon = DBPool.pickup(ctx);
                 } catch (final DBPoolingException e) {
                     LOG.error("A readable connection could not be fetched from pool", e);
-                    return new OXFolderException(OXFolderException.FolderCode.SQL_ERROR, exc, Integer.valueOf(ctx.getContextId()));
+                    return new OXFolderException(OXFolderException.FolderCode.SQL_ERROR, exc, exc.getMessage());
                 }
                 closeReadCon = true;
             }
@@ -1822,19 +1859,21 @@ final class OXFolderManagerImpl extends OXFolderManager {
         final OXFolderException fe;
         if (truncateds.length > 0) {
             final OXFolderException.Truncated truncated = truncateds[0];
-            fe = new OXFolderException(
-                OXFolderException.FolderCode.TRUNCATED,
-                exc,
-                sFields.toString(),
-                Integer.valueOf(truncated.getMaxSize()),
-                Integer.valueOf(truncated.getLength()));
+            fe =
+                new OXFolderException(
+                    OXFolderException.FolderCode.TRUNCATED,
+                    exc,
+                    sFields.toString(),
+                    Integer.valueOf(truncated.getMaxSize()),
+                    Integer.valueOf(truncated.getLength()));
         } else {
-            fe = new OXFolderException(
-                OXFolderException.FolderCode.TRUNCATED,
-                exc,
-                sFields.toString(),
-                Integer.valueOf(0),
-                Integer.valueOf(0));
+            fe =
+                new OXFolderException(
+                    OXFolderException.FolderCode.TRUNCATED,
+                    exc,
+                    sFields.toString(),
+                    Integer.valueOf(0),
+                    Integer.valueOf(0));
         }
         for (final OXFolderException.Truncated truncated : truncateds) {
             fe.addProblematic(truncated);
