@@ -1321,6 +1321,17 @@ public final class OXFolderSQL {
         }
     }
 
+    /**
+     * This method is used to generate identifier when creating a context.
+     * @param ctx context to create.
+     * @param con writable connection to the context database in transaction mode - autocommit is false.
+     * @return a unique identifier for a folder.
+     * @throws SQLException if generating this unique folder identifier fails.
+     */
+    public static int getNextSerialForAdmin(Context ctx, Connection con) throws SQLException {
+        return IDGenerator.getId(ctx, Types.FOLDER, con);
+    }
+
     static void hardDeleteOXFolder(final int folderId, final Context ctx, final Connection writeConArg) throws SQLException, DBPoolingException {
         Connection writeCon = writeConArg;
         boolean closeWrite = false;
