@@ -399,6 +399,10 @@ final class IoSocketHandler extends IoChainableHandler {
 	    
 		// write within current thread
 		if (isBypassingSelectorAllowed && dispatcher.isDispatcherInstanceThread()) {
+		    if (LOG.isLoggable(Level.FINE)) {
+		        LOG.fine("setWriteSelectionKeyNow (isDispatcherThread=true & bypassing=allowed)");
+		    }
+		    
 			boolean isKeyUpdated = dispatcher.setWriteSelectionKeyNow(this);
 			if (isKeyUpdated) {
 				dispatcher.flushKeyUpdate();   // required because it is running within dispatcher thread
@@ -453,7 +457,7 @@ final class IoSocketHandler extends IoChainableHandler {
 		} 
 
 		
-		if (immediate) {    
+		if (immediate || !isOpen()) {       
 			realClose();
 			
 		} else {
@@ -536,18 +540,14 @@ final class IoSocketHandler extends IoChainableHandler {
 
 	private ByteBuffer[] readSocket() throws IOException {
 		assert (Thread.currentThread().getName().startsWith(IoSocketDispatcher.DISPATCHER_PREFIX)) : "receiveQueue can only be accessed by the dispatcher thread";
+        assert (memoryManager instanceof IoUnsynchronizedMemoryManager);
 
-
-		ByteBuffer[] received = null;
-
-
-		int read = 0;
-		lastTimeReceivedMillis = System.currentTimeMillis();
-
-
+        
 		if (isOpen()) {
+	        ByteBuffer[] received = null;
 
-			assert (memoryManager instanceof IoUnsynchronizedMemoryManager);
+	        int read = 0;
+	        lastTimeReceivedMillis = System.currentTimeMillis();
 
 			ByteBuffer readBuffer = memoryManager.acquireMemoryStandardSizeOrPreallocated(8192);
 			int pos = readBuffer.position();
@@ -578,6 +578,9 @@ final class IoSocketHandler extends IoChainableHandler {
 				// end-of-stream has been reached -> throw an exception
 				case -1:
 					memoryManager.recycleMemory(readBuffer);
+					try {  
+					    channel.close();    // forces that isOpen() returns false
+					} catch (IOException ignore) { }
 					
 					ExtendedClosedChannelException cce = new ExtendedClosedChannelException(getId() + " channel has reached end-of-stream (maybe closed by peer) (bytesReveived=" + receivedBytes + ", bytesSend=" + sendBytes + ", lastTimeReceived=" + lastTimeReceivedMillis + ", lastTimeSend=" + lastTimeSentMillis + ")");
 					if (LOG.isLoggable(Level.FINE)) {
@@ -741,7 +744,6 @@ final class IoSocketHandler extends IoChainableHandler {
 		return "sendQueueSize=" + sendQueue.getSize() + ", countIncompleteWrites=" + 
 		       " sendBytes=" + sendBytes+ 
 		       ", reveivedBytes=" + receivedBytes + 
-		       ", dispatcherIsIdle=" + dispatcher.isIdling() +
 		       ", key=" + dispatcher.printSelectionKey(this) +
 		       ", isOpen=" + isOpen() +
 		       ", lastException=" + DataConverter.toString(lastException); 
@@ -934,7 +936,7 @@ final class IoSocketHandler extends IoChainableHandler {
 		}
         
         private void allocateWriteBuffer(int size) {
-        	if (IoProvider.isUseDirectWriteBuffer()) {
+        	if (IoProvider.isUseDirectWriteBuffer()) {        	
         		writeBuffer = ByteBuffer.allocateDirect(size);
         	} else {
         		writeBuffer = ByteBuffer.allocate(size);
@@ -989,7 +991,10 @@ final class IoSocketHandler extends IoChainableHandler {
                 } else {
                     return INCOMPLETE_WRITE_RESULT;
                 }
-    
+
+            } catch(ClosedChannelException cce)  {
+                isReusable = false;
+                return new ErrorWriteResult(handler, cce, buffersToWrite);
                 
             } catch(final IOException ioe)  {
             	isReusable = false;
@@ -1053,6 +1058,9 @@ final class IoSocketHandler extends IoChainableHandler {
    					return INCOMPLETE_WRITE_RESULT;
    				}
 
+            } catch(ClosedChannelException cce)  {
+                isReusable = false;
+                return new ErrorWriteResult(handler, cce, bufferToWrite);
 	
    			} catch(IOException ioe)  {
    				isReusable = false;
